/** ===========================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in
 *   the license agreement under which this software has been supplied.
 *   ==========================================================================
 */

/** ===========================================================================
 *   @file  Dmax_example.c
 *
 *
 *   @desc  DMAX CSL API Example for 3D Data Transfer.
 *
 * ============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows how to test the DMAX CSL in 3-Dimensional 
 *          Data Transfer.
 *      1. Initialize the DMAX module.
 *      2. Relocate Interrupt Vector Table by writing valid RAM location.
 *      3. Setup General Purpose 3D transfer structure with one Dimensional 
 *          EventSetup & ParameterSetup.
 *      4. Setup of the DMAX Interrupts for Transfer completion (INT8) &
 *          Transfer Failure (INT7) in setup_interrupts().
 *      5. Enable the StartTransfer to transfer the Data.
 *      6. If the srcData & dstData buffers has same data, then
 *          transfer success
 *      7. If the data varies between srcData & dstData then transfer fail.
 *=============================================================================
 *      
 *   <b> Test Procedure </b>
 *   @verbatim
 *      1. Configure the CCS setup to work with the emulator being used.
 *         Refer CCS manual for setup configuration
 *      2. Load required GEL file depending on the board used
 *      3. Open project dmax_example.pjt
 *      4. Build the project and load the .out file of the project.
 *      5. The test can be executed from the main().
 *          
 *   @endverbatim
 *       
 *   
 * ============================================================================
 */

/* ============================================================================
 *  Revision History
 *  ===============
 *  21-Mar-2005 asr File Created.
 *
 * ============================================================================
 */

#include "Dmax_example.h"

/* Globals */

/* Variable to check the Transfer Complete Interrupt generated */
Uint32  dmaxTcValue = TC_PASS;

/* Interrupt handle */
CSL_IntcHandle              hIntc;
CSL_IntcEventEnableState    eventStat;
CSL_IntcDispatcherContext   intcDispatcherContext;

/* DMAX */
CSL_DmaxObj                     dmaxEvent;
CSL_DmaxHandle                  hDmax;
CSL_DmaxHwSetup                 hwSetup;
CSL_DmaxGPTransferEventSetup    gpxfrEventSetup;
CSL_DmaxGPXFRParameterSetup     gpxfrParameterSetup;

/* Data buffers */
Uint32  srcData[DMAX_DATA_TRANSFER_COUNT];
Uint32  dstData[DMAX_DATA_TRANSFER_COUNT];

/* status variable */
CSL_Status status=CSL_SOK;
/**
 * ============================================================================
 *   @func   main
 *
 *   @desc
 *     This is the main routine for the file.
 *
 * @arg 
 *  NONE
 *
 * @return
 *  NONE
 * ============================================================================
*/
void main (
    void
)
{
    status = dmax_3d_data_transfer();
    
    /* Checking for the DMAX Application Fail or Pass */
    if ((status == CSL_SOK) && (dmaxTcValue == TC_PASS)) {
        printf ("\nDmax CSL Example Application PASSED\n");
    }
    else {
        printf ("\nDmax CSL Example Application FAILED\n");
    }
    
}

/**
 * ============================================================================
 *   @func   dmax_3d_data_transfer
 *
 *   @desc
 *      This routine will setup the values for the 3D data transfer. And verify
 *      once the data is transfered.
 *
 * @arg 
 *      NONE
 *
 * @return
 *      CSL_Status
 * ============================================================================
*/
CSL_Status dmax_3d_data_transfer( 
    void
)
{
    Uint32      i = 0;
    CSL_Status  status;
    Uint32      response;

    /* 
     * fillMem will store the default value incrementing by one 
     * in each location of the srcData. And in the dstData location
     * constant default value is stored.
     */
    response = fillMem ((Uint32) srcData, 
        DMAX_DATA_TRANSFER_COUNT, SRC_DATA_DEFAULT, FILL_INC);
    if (response == ERROR_FILL) {
        status = ERROR_FILL;
        return status;
    }

    response = fillMem ((Uint32) dstData,
        DMAX_DATA_TRANSFER_COUNT, DST_DATA_DEFAULT, FILL_CONST);
    if (response == ERROR_FILL) {
        status = ERROR_FILL;
        return status;
    }

    CSL_sysInit();
    /* Initialize DMAX CSL module */
    status = CSL_dmaxInit (NULL);

    if (status != CSL_SOK) {
        return status;
    }

    /*Relocating Interrupt Vector Table */
    CSL_intcSetVectorPtr (ISTP_VECTOR_VALUE);

    /* Low Priority Event1 */
    dmaxEvent.eventUid = CSL_DMAX_LOPRIORITY_EVENT1_UID;

    /* Low Priority Parameter entry0 */
    dmaxEvent.paramUid = CSL_DMAX_LOPRIORITY_PARAMETERENTRY0_UID;

    /* DMAX Handle by calling CSL_dmaxOpen Call */
    hDmax = CSL_dmaxOpen (&dmaxEvent, CSL_DMAX, NULL, &status);

    if (status != CSL_SOK || (hDmax == (CSL_DmaxHandle) CSL_DMAX_BADHANDLE)) {
        status = CSL_ESYS_BADHANDLE;
        return status;
    }

    /* Quantam Transfer Size Limit not more than 4 elements */
    gpxfrEventSetup.qtsl    = CSL_DMAX_EVENT2_QTSL_MOVE4_ELE;
    /* Transfer Complete Code will set in DTCR0/DTCR1 Register */
    gpxfrEventSetup.tcc     = CSL_DMAX_EVENT2_TCC_RESETVAL;
    /* Alternate Transfer mode Disable */
    gpxfrEventSetup.atcint  = CSL_DMAX_EVENT2_ATCINT_DISABLE;
    /* Transfer Complete Interrupt Enable */
    gpxfrEventSetup.tcint   = CSL_DMAX_EVENT2_TCINT_ENABLE;
    /* No Reload after transfer is completed */
    gpxfrEventSetup.rload   = CSL_DMAX_EVENT2_RLOAD_DISABLE;
    /* Counter Configuration */
    gpxfrEventSetup.cc      = CSL_DMAX_EVENT2_CC_COUNT2_15_COUNT1_8_COUNT0_8;
    /* 32-bit Element Size */
    gpxfrEventSetup.esize   = CSL_DMAX_EVENT2_ESIZE_32BIT;
    /* Pointer to Transfer Entry */
    gpxfrEventSetup.pte     = hDmax->paramPtr;
    /* General purpose Event Type */
    gpxfrEventSetup.etype   = CSL_DMAX_EVENT2_ETYPE_GENERALXFR;
    gpxfrEventSetup.paramSetup = &gpxfrParameterSetup;

    /* Number of bytes of data to be transfer in 1-Dimension */
    gpxfrParameterSetup.count0  = DMAX_DATA_TRANSFER_COUNT;
    /* Number of bytes of data to be transfer in 2-Dimension */
    gpxfrParameterSetup.count1  = COUNT1;
    /* Number of bytes of data to be transfer in 3-Dimension */
    gpxfrParameterSetup.count2  = COUNT2;
    /* Source Address Index0 Increment */
    gpxfrParameterSetup.srcIndex0   = SRC_INDEX0;
    /* Destination Address Index0 Increment */
    gpxfrParameterSetup.dstIndex0   = DST_INDEX0;
    /* Source Address Index1 Increment */
    gpxfrParameterSetup.srcIndex1   = SRC_INDEX1;
    /* Destination address Index1 increment */
    gpxfrParameterSetup.dstIndex1   = DST_INDEX1;
    /* Source address Index2 increment */
    gpxfrParameterSetup.srcIndex2   = SRC_INDEX2;
    /* Destination address Index2 increment */
    gpxfrParameterSetup.dstIndex2   = DST_INDEX2;
    /* Source Reload Address - 0 */
    gpxfrParameterSetup.srcReloadAddr0 = (Uint32) srcData;
    /* Destination Reload Address - 0 */
    gpxfrParameterSetup.dstReloadAddr0 = (Uint32) dstData;
    /* Source Reload Address - 1 */
    gpxfrParameterSetup.srcReloadAddr1 = SRC_ADDR1;
    /* Destination Reload Address - 1 */
    gpxfrParameterSetup.dstReloadAddr1 = DST_ADDR1;

    /* Rising Edge polarity */
    hwSetup.polarity = CSL_DMAX_POLARITY_RISING_EDGE;

    /* High Event priority */
    hwSetup.priority    = CSL_DMAX_EVENT_HI_PRIORITY;
    hwSetup.eventSetup  = (CSL_DmaxEventSetup *) & gpxfrEventSetup;

    /* DMAX CSL HwSetup */
    status = CSL_dmaxHwSetup (hDmax, &hwSetup);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }

    /* Setting up the DMAX Interrupts */
    status = setup_interrupts ();
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }

    /* DMAX Event1 Event Enable */
    status = CSL_dmaxHwControl (hDmax, CSL_DMAX_CMD_EVENTENABLE, NULL);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }


    /* start data transfer */
    status = CSL_dmaxHwControl (hDmax, CSL_DMAX_CMD_STARTASYNCTRANSFER, NULL);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }

    /* checking TCC bit */
    status =
        CSL_dmaxGetHwStatus (hDmax, CSL_DMAX_QUERY_GET_TCC, (void *) &response);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }

    /* 
     * After the data transfered the TCC bit will get set.Polling for
     * TCC bit, (i.e.) if bit get set Data transfer Done sucessfully.
     */
    while (!response) {
        status =
            CSL_dmaxGetHwStatus (hDmax, CSL_DMAX_QUERY_GET_TCC,
            (void *) &response);
        if (status != CSL_SOK) {
            dmax_error_exit ();
            return status;
        }
    }

    /* 
     * Checking that the INT8 ISR got triggered and also checking
     * that the source Data is presented in the Destination Data
     */
    if (response != 1) {
        printf ("Error - CPPUINT 8 Set, But TCC not set!\n");
    }
    else {
        for (i = 0; i < DMAX_DATA_TRANSFER_COUNT; i++) {
            if (srcData[i] != dstData[i]) {
                dmax_error_exit ();
                status = CSL_ESYS_FAIL;
                return status;
            }
        }
    }

    /* Clearing the TCC bit */
    status = CSL_dmaxHwControl (hDmax, CSL_DMAX_CMD_CLEARTCC, NULL);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }

    /* Getting the TCC bit value */
    status =
        CSL_dmaxGetHwStatus (hDmax, CSL_DMAX_QUERY_GET_TCC, (void *) &response);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }

    /* Checking the value of the TCC bit i.e cleared or not */
    if (response != 0) {
        printf ("Clear TCC Bit failed!\n");
    }
    else {
        printf ("Clear TCC bit Passed!\n");
    }

    /* Closing DMAX Handle */
    status = CSL_dmaxClose (hDmax);
    if (status != CSL_SOK) {
        return status;
    }
    return status;
}

/**
*******************************************************************************
*   @func   fillMem( Uint32 start_location, Uint32 length,
*                       Uint32 fill_value, Uint8 fill_type )
*
*   @desc   Fills a memory location with a pattern as requested.
*           Beginning at 'start_location', 'length' words (32-bit) are filled,
*           starting with 'fill_value'.  After the initial value, the
*           other memory locations are filled with either a constant
*           value, incrementing values, or decrementing values.
*
*   @arg    Uint32 start_location : Memory location to start filling.
*           Uint32 length : Number of bytes to fill.
*           Uint32 fill_value : 32-bit value to start filling with.
*           Uint8 fill_type : Type of fill:
*                           FILL_CONST, FILL_INC, FILL_DEC
*
*   @return Uint32 flag : PASS for a success
*           ERROR_TEST for a failure
*******************************************************************************
*/
Uint32 fillMem (
    Uint32 start_location,
    Uint32 length,
    Uint32 fill_value,
    Uint32 fill_type
)
{
    Uint32                  *loc;
    Uint32                   i;

    loc = (Uint32 *) start_location;

    for (i = 0; i < length; i++) {
        if (fill_type == FILL_CONST) {
            *loc = fill_value;
            /* Check that value was written correctly */
            if (*loc != fill_value)
                return ERROR_FILL;
        }
        else if (fill_type == FILL_INC) {
            *loc = (Uint32) (fill_value + i);
            /* Check that value was written correctly */
            if (*loc != (Uint32) (fill_value + i))
                return ERROR_FILL;
        }
        else if (fill_type == FILL_DEC) {
            *loc = (Uint32) (fill_value - i);
            /* Check that value was written correctly */
            if (*loc != (Uint32) (fill_value - i))
                return ERROR_FILL;
        }
        else { /* Error if non-valid fill type */
            return ERROR_FILL;
        }
        loc++;
    }

    return PASS;
}

/**
*******************************************************************************
* @func setup_interrupts
*
* @desc Setting up the Interrupts
*
* @arg  
*       NONE
*
* @return
*       CSL_Status
*******************************************************************************
*/
CSL_Status setup_interrupts (
    void
)
{
    CSL_IntcObj                 intcObj;
    CSL_IntcGlobalEnableState   state;
    CSL_IntcEventHandlerRecord  isrRec;
    CSL_IntcContext             intcContext;

    CSL_Status                  status;

    /* Initialize the intc CSL modules with zeros  */
    memset (&intcContext, 0, sizeof (CSL_IntcContext));
    memset (&intcDispatcherContext, 0, sizeof (CSL_IntcDispatcherContext));

    /* Interrupt Initialization */
    status = CSL_intcInit (&intcContext);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }

    status = CSL_intcDispatcherInit (&intcDispatcherContext);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }


    /* Install handler for DMAX INT8 Interrupt */
    hIntc = CSL_intcOpen (&intcObj,
        CSL_INTC_EVENTID_DMAXEVTOUT1, NULL, &status);

    if ((hIntc == NULL) || (status != CSL_SOK)) {
        status = CSL_ESYS_BADHANDLE;
        dmax_error_exit();
        return status ;
    }

    isrRec.handler = intr08;
    /* As no arguments assigning zero(0) value */
    isrRec.arg = (void *) 0x0;
    /*Plugging ISR in Event Handler */
    CSL_intcPlugEventHandler (hIntc, &isrRec);
    /* Enabling DMAXEVTOUT1 Event */
    status = CSL_intcEventEnable (CSL_INTC_EVENTID_DMAXEVTOUT1, &eventStat);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }

    /* Install handler for DMAX INT07 interrupt */
    hIntc = CSL_intcOpen (&intcObj,
        CSL_INTC_EVENTID_DMAXEVTOUT0, NULL, &status);

    if ((hIntc == NULL) || (status != CSL_SOK)) {
        status = CSL_ESYS_BADHANDLE;
        return status;
    }

    isrRec.handler = intr07;
    /* As no arguments assigning zero(0) value */
    isrRec.arg = (void *) 0x0;

    /* Plugging ISR in Event Handler */
    CSL_intcPlugEventHandler (hIntc, &isrRec);

    /* DMAXEVTOUT0 Event Enable */
    status = CSL_intcEventEnable (CSL_INTC_EVENTID_DMAXEVTOUT0, &eventStat);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }

    /* Enabling Non-Maskable Interrupt */
    status = CSL_intcEventEnable (CSL_INTC_EVENTID_NMI, &eventStat);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }

    /* Enabling Global Enable bit in Control Status Register (CSR) */
    status = CSL_intcGlobalEnable (&state);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }

    /* Closing INTC Handle */
    status = CSL_intcClose (hIntc);
    if (status != CSL_SOK) {
        dmax_error_exit ();
        return status;
    }
    return status;
} /* End of setup_interrupts() */

/**
*******************************************************************************
* @func intr08
*
* @arg  
*   NONE
*
* @desc Interrupt Service Routine, this will get triggered if the
*       data transfer is success.
*
*
* @return
*   NONE
*******************************************************************************
*/

void intr08 (
)
{
    dmaxTcValue = TC_PASS;
}

/**
*******************************************************************************
* @func intr07
*
* @arg  
*   NONE
*
* @desc Interrupt Service Routine, this will get triggered if the
*       data transfer fails
*
*
* @return
*   NONE
*******************************************************************************
*/


void intr07 (
)
{
    dmaxTcValue = TC_FAIL;
}

/**
*******************************************************************************
* @func dmax_error_exit
*
* @arg  
*   NONE
* @desc This function closes the DMAX module on error occurence
*
*
* @return
*   NONE
*******************************************************************************
*/
void dmax_error_exit (
    void
)
{
    CSL_Status  status;
    status = CSL_SOK;
    
    status = CSL_dmaxClose (hDmax);
    if (status != CSL_SOK) {
        status = status;
    }
    
    return;
    
}
