/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  Pllc_example.c
 *
 *   
 *   @desc  Example of PLLC	module CSL
 * =============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows how to test the PLLC
 *      1. Initalize the PLLC hardware setup data structure with default values
 *      2. Intialize PLLC module
 *      3. Set new values for divider3
 *      4. Set the value using hardware control command
 *      5. Read and verify the new values using hardware query
 *      6. Close the module
 *==============================================================================
 *      
 *   <b> Test Procedure </b>
 *   @verbatim
 *      1. Configure the CCS setup to work with the emulator being used.
 *         Refer CCS manual for setup configuration.
 *      2. Load required GEL file depending on the board used.
 *      3. Launch CCS window.
 *      4. Open project pllc_example.pjt.
 *      5. Build the project and load the .out file of the project.
 *      6. The test can be executed from the main().
 *          
 *   @endverbatim
 *       
 *   
 * =============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  12-may-2005 Ganesh K  File created.
 *
 * =============================================================================
 */

#include "Pllc_example.h"

/* PLLC module handle structure */
CSL_PllcHandle           hPllc = NULL;

/* Variable to count the test failure */
Uint32                   pllcTestFail = PLLC_TEST_PASSED;

/*
 * =============================================================================
 *  @func   main
 *
 *  @desc
 *     This is the main routine for the file.
 *
 *  @arg
 *      NONE
 *  
 *  @return
 *      NONE
 * =============================================================================
*/
void
main (
    void
)
{
    /* Perform the test */
    pllc_csl_example_test ();

    /* Check for errors in test */
    if (pllcTestFail == PLLC_TEST_PASSED) {
        printf ("\nPllc CSL Example Test PASSED\n");
    }
    else {
        printf ("\nPllc CSL Example Test FAILED\n");
    }
}

/*
 * =============================================================================
 *  @func   pllc_csl_example_test
 *
 *  @desc
 *     This is the test routine which write, read and verify divider3 value.
 *
 *  @arg
 *      NONE
 *  
 *  @return
 *      NONE
 * =============================================================================
*/
void
pllc_csl_example_test (
    void
)
{
    CSL_PllcObj              pllcObj;
    CSL_Status               status;
    CSL_PllcHwSetup          hwSetup = CSL_PLLC_HWSETUP_DEFAULTS;
    CSL_PllcDivCntrl         arg;
    CSL_PllcDivCntrl         response;

    CSL_sysInit();
    /* Initialize the pllc CSL module */
    status = CSL_pllcInit (NULL);
    if (status != CSL_SOK) {
        pllcTestFail++;
        printf ("PLLC: Initialization... Failed.\n");
        printf ("\tReason: CSL_pllcInit failed [Status: %d] \n ", status);
        return;
    }
    else {
        printf ("PLLC: Module Initialization... Passed.\n");
    }

    /* Open the pllc CSL module */
    hPllc = CSL_pllcOpen (&pllcObj, CSL_PLLC, NULL, &status);
    if ((hPllc == NULL) || (status != CSL_SOK)) {
        pllcTestFail++;
        printf ("PLLC: Opening the instance ... Failed\n");
        return;
    }
    else {
        printf ("PLLC: Open valid instance... Passed.\n");
    }

    /* Setup PLLC hardware parameters */
    status = CSL_pllcHwSetup (hPllc, &hwSetup);
    if (status != CSL_SOK) {
        pllcTestFail++;
        printf ("PLLC: Setup of  the module ... Failed\n");
        pllc_error_exit ();
        return;
    }
    else {
        printf ("PLLC: Setup of  the module ... Passed.\n");
    }

    /*  Divider 3 Setup structure intialization */
    arg.divNum = CSL_PLLC_DIV3;
    arg.divControl.divEnable = CSL_PLLC_PLLDIV_ENABLE;
    arg.divControl.pllDivRatio = PLLC_DIV3_RATIO_NEW_VAL;
    
    /* Set the new value */
    status = CSL_pllcHwControl (hPllc, CSL_PLLC_CMD_DIV_CONTROL, &arg);
    if (status != CSL_SOK) {
        pllcTestFail++;
        printf ("PLLC: Hardware Command set Div3 ... Failed\n");
        pllc_error_exit ();
        return;
    }
    else {
        printf ("PLLC: Hardware Command set Div3 ... Passed\n");
    }

    /* Get divider 3 status */
    response.divNum = CSL_PLLC_DIV3;
    status =
        CSL_pllcGetHwStatus (hPllc, CSL_PLLC_QUERY_DIVIDER_STATE, &response);
    if (status != CSL_SOK) {
        pllcTestFail++;
        printf ("PLLC: Hardware Query Div3 ... Failed\n");
        pllc_error_exit ();
        return;
    }
    else {
        printf ("PLLC: Hardware Query Div3 ... Passed\n");
    }

    /* Check for divider enable and divder ratio */
    if ((response.divControl.divEnable != CSL_PLLC_PLLDIV_ENABLE) ||
        (response.divControl.pllDivRatio != PLLC_DIV3_RATIO_NEW_VAL)) {
        pllcTestFail++;
        printf ("PLLC: Hardware set Div3 ... Failed\n");
    }
    else {
        printf ("PLLC: Hardware set Div3 ... Passed\n");
    }

    /* Check closing the module */
    status = CSL_pllcClose (hPllc);
    if (status != CSL_SOK) {
        pllcTestFail++;
        printf ("PLLC: Close the instance ... Failed\n");
    }
    else {
        printf ("PLLC: Close valid instance... Passed.\n");
    }

    return;
}

/*
 * =============================================================================
 *  @func   pllc_error_exit
 *
 *  @desc
 *     This calls the module close function in case of error 
 *
 *  @arg
 *      NONE
 *  
 *  @return
 *      NONE
 * =============================================================================
 */
void
pllc_error_exit (
    void
)
{
    CSL_Status               status;

    /* Check closing the module */
    status = CSL_pllcClose (hPllc);
    if (status != CSL_SOK) {
        pllcTestFail++;
        printf ("PLLC: Close Pllc instance... Failed\n");
    }
    else {
        printf ("PLLC: Close Pllc instance... Passed\n");
    }
}
