/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  I2c_example.c
 *
 *
 *   @desc  Example of using the I2C module CSL
 *
 * =============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows usage of I2C CSL api
 *      1. Initalize the I2C hardware setup data structure with required values
 *      2. Intialize I2C module
 *      3. Intilaize the PLLC module
 *      4. Intialize the mode register of I2C for data transfer.
 *      5. Transfer the data 
 *      6. Receive and verify; steps 5 and 6 are done till all the data    
 *         are transfered
 *      7. Stop the transmission
 *      8. Close the modules
 *==============================================================================
 *      
 *   <b> Test Procedure </b>
 *   @verbatim
 *      1. Configure the CCS setup to work with the emulator being used
 *      2. Please refer CCS manual for setup configuration and loading 
 *         proper GEL file
 *      3. Launch CCS window
 *      4. Open project I2c_example.pjt
 *      5. Build the project and load the .out file of the project.
 *      6. The test can be executed from the main().
 *          
 *   @endverbatim
 *       
 *   
 * =============================================================================
 */


/* =============================================================================
 *  Revision History
 *  ===============
 *  08-mar-2005 Ramitha Mathew  File created.
 *
 * =============================================================================
 */

#include "I2c_example.h"



/* Handle for the I2C instance */
CSL_I2cHandle            hI2c;
/* Handle for the PLLC instance */
CSL_PllcHandle           hPllc;
/* I2C Hardware setup structure */
CSL_I2cHwSetup           i2cSetup;
CSL_I2cObj               i2cObj;
/* I2C clock setup structure */
CSL_I2cClkSetup          clkSetup = {
                            CSL_I2C_CLOCK_PRESCALAR,
                            CSL_I2C_CLOCK_CLKL,
                            CSL_I2C_CLOCK_CLKH
                            };
/*Transmit buffer */
Uint8                    xmtBuf[DATA_LEN];
/* Receive buffer */
Uint8                    rcvBuf[DATA_LEN];

/* Variable used to track the results*/
Uint32                   i2cTestFail = 0;


/*
 * =============================================================================
 *   @func   main
 *  
 *   @arg
 *      NONE
 *
 *   @desc
 *     This is the main routine for the file.
 *
 *   @return
 *      NONE
 *
 * =============================================================================
 */
void main (
    void
)
{
    /* Routine performs the I2C loop back */
    i2c_csl_example_test ();
    if (i2cTestFail == I2C_TEST_PASSED) {
        printf ("\nI2c CSL Example Test PASSED\n");
    }
    else {
        printf ("\nI2c CSL Example Test FAILED\n");
    }

}

/*
 * =============================================================================
 *   @func  i2c_csl_example_test
 *  
 *   @arg
 *      NONE
 *
 *   @desc
 *      This is routine which perform loop back for I2C.
 *
 *   @return
 *      NONE
 *
 * =============================================================================
 */
void i2c_csl_example_test (
    void
)
{
    Uint16                   response, cmdArg, dataLen;
    CSL_I2cHwSetup           i2cSetup;
    CSL_I2cClkSetup          clkSetup;
    CSL_Status               status = CSL_SOK;
    Uint16                   counter;

    /* setup the i2c parameters */
    i2cSetup.mode           = CSL_I2C_MODE_MASTER;
    i2cSetup.dir            = CSL_I2C_DIR_TRANSMIT;
    i2cSetup.addrMode       = CSL_I2C_ADDRSZ_SEVEN;
    i2cSetup.sttbyteen      = CSL_I2C_STB_ENABLE;
    i2cSetup.ownaddr        = CSL_I2C_SLAVE_ADDR;
    i2cSetup.ackMode        = CSL_I2C_ACK_ENABLE;
    i2cSetup.runMode        = CSL_I2C_FREE_MODE_DISABLE;
    i2cSetup.repeatMode     = CSL_I2C_REPEAT_MODE_DISABLE;
    i2cSetup.loopBackMode   = CSL_I2C_DLB_ENABLE;
    i2cSetup.freeDataFormat = CSL_I2C_FDF_DISABLE;
    i2cSetup.resetMode      = CSL_I2C_IRS_ENABLE;
    i2cSetup.xrdym          = CSL_I2C_BCM_DISABLE;
    i2cSetup.inten          = (Uint16) INTR_DISABLE;
    clkSetup.prescalar      = CSL_I2C_CLOCK_PRESCALAR;
    clkSetup.clklowdiv      = CSL_I2C_CLOCK_CLKL;
    clkSetup.clkhighdiv     = CSL_I2C_CLOCK_CLKH;
    i2cSetup.clksetup       = &clkSetup;

    /* initializes the transmit and receive buffer */
    for (counter = 0; counter < DATA_LEN; counter++) {
        xmtBuf[counter] = (Uint8) counter;
        rcvBuf[counter] = (Uint8) 0;
    }

    /* Clear local data structures */
    memset (&i2cObj, 0, sizeof (CSL_I2cObj));

    CSL_sysInit();

    /* Initialize I2C module */
    if (CSL_SOK != CSL_i2cInit (NULL)) {
        printf ("I2C: Initialization... Failed.\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    /* Open the I2C instance 0 */
    hI2c = CSL_i2cOpen (&i2cObj, CSL_I2C_0, NULL, &status);
    if (status != CSL_SOK || hI2c == NULL) {
        printf ("I2C: Open... Failed\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    /* Do I2C hardware setup */
    if (CSL_SOK != CSL_i2cHwSetup (hI2c, &i2cSetup)) {
        printf ("I2C: Hardware setup... Failed.\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }


    /* Enable I2C */
    status = CSL_i2cHwControl (hI2c, CSL_I2C_CMD_ENABLE, NULL);
    if (status != CSL_SOK) {
        printf ("I2C: Hardware control command for enable...Failed.\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    /* Waiting till I2C is taken out of reset */
    do {
        CSL_i2cGetHwStatus (hI2c, CSL_I2C_QUERY_RDONE, &response);
    } while (response != CSL_I2C_RESET_DONE);

    /* Set PLLC module */
    status = i2cSetupCPUCLK ();
    if (status != CSL_SOK) {
        printf ("I2C: i2c clk setup using pllc...Failed.\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    /* set no of bytes to be sent */
    dataLen = DATA_LEN;
    cmdArg  = DATA_LEN;
    CSL_i2cSetDataCount (hI2c, &cmdArg);

    /* Poll for Bus busy */
    if (FALSE == pollStatus (COMPARE_VAL0,
            CSL_I2C_ICSTR_BUS_BUSY_CHECK, CSL_I2C_DEFAULT_WAIT_TIME)) {
        printf ("I2C: Bus Busy Check....Failed.\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    /* Set data to send */
    status = CSL_i2cWrite (hI2c, xmtBuf);
    if (status != CSL_SOK) {
        printf ("I2C: I2c Write...Failed.\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    /* Setting the Start Bit */
    status = CSL_i2cHwControl (hI2c, CSL_I2C_CMD_START, NULL);
    if (status != CSL_SOK) {
        printf ("I2C: Hardware control command for start...Failed.\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }
    /* Setting the Stop Bit */
    status = CSL_i2cHwControl (hI2c, CSL_I2C_CMD_STOP, NULL);
    if (status != CSL_SOK) {
        printf ("I2C: Hardware control command for stop...Failed.\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    for (counter = 0; counter < (dataLen - 1); counter++) {
        /* Poll for Data received */
        if (FALSE == pollStatus (COMPARE_VAL1, \
                CSL_I2C_ICSTR_RX_RDY_CHECK, CSL_I2C_DEFAULT_WAIT_TIME)) {
            printf ("I2C: Receive Ready Check[1]....Failed.\n");
            i2cTestFail++;
            i2c_error_exit ();
            return;
        }

        /* Check if data has been received */
        status = CSL_i2cRead (hI2c, &rcvBuf[counter]);
        if (status != CSL_SOK) {
            printf ("I2C: i2c read...Failed.\n");
            i2cTestFail++;
            i2c_error_exit ();
            return;
        }
        
        /* Verifying the received data */
        if (xmtBuf[counter] != rcvBuf[counter]) {
            printf ("I2C: Compare between the data transmitted and \
                         received....Failed\n.");
            i2cTestFail++;
            i2c_error_exit ();
            return;
        }


        /* check if Data receive status bit is reset */
        if (FALSE == pollStatus (COMPARE_VAL0, \
                CSL_I2C_ICSTR_RX_RDY_CHECK, CSL_I2C_DEFAULT_WAIT_TIME)) {
            printf ("I2C: Receive Ready Check[0]....Failed.\n");
            i2cTestFail++;
            i2c_error_exit ();
            return;
        }

        /* Send data */
        if ((counter + 1) < (dataLen - 1)) {
            status = CSL_i2cWrite (hI2c, &xmtBuf[counter + 1]);
            if (status != CSL_SOK) {
                printf ("I2C: i2c write...Failed.\n");
                i2cTestFail++;
                i2c_error_exit ();
                return;
            }
        }
    }

    /* Send last byte */
    status = CSL_i2cWrite (hI2c, &xmtBuf[dataLen - 1]);
    if (status != CSL_SOK) {
        printf ("I2C: i2c write...Failed.\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    /* Poll for Data received */
    if (FALSE == pollStatus (COMPARE_VAL1, \
            CSL_I2C_ICSTR_RX_RDY_CHECK, CSL_I2C_DEFAULT_WAIT_TIME)) {
        printf ("I2C: Receive Ready Check[1]....Failed\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    /* verify the data Received */
    status = CSL_i2cRead (hI2c, &rcvBuf[counter]);
    if (status != CSL_SOK) {
        printf ("I2C: i2c read...Failed.\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    /* Verifying the received data */
    if (xmtBuf[counter] != rcvBuf[counter]) {
        printf ("I2C: Compare between the data transmitted and" \
                         "received....Failed\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    /* Stop the transmission */
    if (CSL_i2cHwControl (hI2c, CSL_I2C_CMD_STOP, NULL) != CSL_SOK) {
        printf ("I2C: Hardware control command for stopping...Failed\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    /* Close the opened instance */
    if (CSL_i2cClose (hI2c) != CSL_SOK) {
        printf ("I2C: Close....Failed\n");
        i2cTestFail++;
        i2c_error_exit ();
        return;
    }

    return;
}

/*
 * =============================================================================
 *   @func  i2cSetupCPUCLK
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     It uses PLLC controller APIs to set the clock.
 *
 *   @return
 *      status  - The status of the function
 *
 *
 * =============================================================================
 */
CSL_Status i2cSetupCPUCLK (
    void
)
{

    CSL_Status               status = CSL_SOK;
    CSL_PllcObj              pllcObj;
    CSL_PllcDivCntrl         pllDivControl;

    status = CSL_pllcInit (NULL);
    if (status != CSL_SOK) {
        printf ("PLLC: pllc init...Failed.\n");
        pllc_error_exit ();
        return status;
    }

    memset (&pllcObj, 0, sizeof (CSL_PllcObj));

    hPllc = CSL_pllcOpen (&pllcObj, CSL_PLLC, NULL, &status);
    if (status != CSL_SOK || hPllc == NULL) {
        printf ("PLLC: Open... Failed\n");
        pllc_error_exit ();
        return status;
    }

    /* Pll divider2 for I2C*/
    pllDivControl.divNum = CSL_PLLC_DIV2;

    /* divider2 is enabled */
    pllDivControl.divControl.divEnable = CSL_PLLC_PLLDIV_ENABLE;
    
    /* divider2 ratio set to divide by 4 */
    pllDivControl.divControl.pllDivRatio = CSL_I2C_TEST_PLL_DIVIDER_DIV4;

    /* pllc setup */
    status = CSL_pllcHwControl ( hPllc, 
                                 CSL_PLLC_CMD_DIV_CONTROL, 
                                 &pllDivControl);
    if (status != CSL_SOK) {
        printf ("PLLC: HwSetup... Failed\n");
        pllc_error_exit ();
        return status;
    }

    status = CSL_pllcClose (hPllc);
    if (status != CSL_SOK) {
        printf ("PLLC: Close... Failed\n");
        pllc_error_exit ();
        return status;
    }

    return status;
}


/*
 * =============================================================================
 *   @func   pollStatus
 *   
 *   @arg    status         - compare value
 *           mask           - holds the value which decides the switch case to
 *                            be executed
 *           timeOut        - Timeout value
 *
 *   @desc
 *     This API will poll for I2C register status till time out occur
 *
 *   @return  Bool
 *
 * =============================================================================
 */
Bool pollStatus (
    Uint32      status,
    Uint32      mask,
    int         timeOut
)
{
    Uint16      response;
        
    switch(mask) {
        case CSL_I2C_ICSTR_RX_RDY_CHECK:
            CSL_i2cGetHwStatus (hI2c, CSL_I2C_QUERY_RX_RDY, &response); 
            while (((Uint16)status != response) && (timeOut > 0)) {
                CSL_i2cGetHwStatus (hI2c, CSL_I2C_QUERY_RX_RDY, &response);
                timeOut--;          
            }
            break;
            
        case CSL_I2C_ICSTR_BUS_BUSY_CHECK:
            CSL_i2cGetHwStatus (hI2c, CSL_I2C_QUERY_BUS_BUSY, &response);   
            while (((Uint16)status != response) && (timeOut > 0)) {
                CSL_i2cGetHwStatus (hI2c, CSL_I2C_QUERY_BUS_BUSY, &response);
                timeOut--;          
            }
            break;
            
        default:
            break;      
        
    }

    if (0 == timeOut) {
        return FALSE;
    }
    else {
        return TRUE;
    }
}

/*
 * =============================================================================
 *   @func   i2c_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the i2c module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void i2c_error_exit (
    void
)
{
    CSL_i2cClose (hI2c);
}

/*
 * =============================================================================
 *   @func   pllc_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the pllc module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void pllc_error_exit (
    void
)
{
    CSL_pllcClose (hPllc);
}
