/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/* =============================================================================
 *   @file  I2c_example.h
 *
 *   @desc  Example header file to I2C.
 * =============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  12-may-2005 Ramitha M  File created.
 *
 * =============================================================================
 */

#ifndef _I2C_EXAMPLE_H_
#define _I2C_EXAMPLE_H_

#ifdef __cplusplus
extern "C"
{
#endif
#include <soc.h>
#include <string.h>
#include <stdio.h>
#include <csl_i2c.h>
#include <csl_i2cAux.h>
#include <csl_pllc.h>

/* 
 * For every error the error count variable is increased. So count will be 
 * zero when there is no error, So test passed.
 */
#define I2C_TEST_PASSED                         0x0

/* Number of bytes to be transmitted or received */
#define DATA_LEN 24

/* Address to be programmed as own address for I2C */
#define CSL_I2C_SLAVE_ADDR                      0x05

/* The third argument passed in the function pollStatus */
#define CSL_I2C_DEFAULT_WAIT_TIME               (2000)

/* Check for Receive ready */
#define CSL_I2C_ICSTR_RX_RDY_CHECK              0x0

/* Check for Bus Busy */
#define CSL_I2C_ICSTR_BUS_BUSY_CHECK            0x1

/*
 * cpu clk frequency = 585.824MHz
 * I2C input frequncy = 585.824MHz/4 = 146.456MHz (Obtained after PLLC division)
 * I2C Module frequency = I2C input frequency/(IPSC + 1)
 * where IPSC is the I2C Prescalar register value, here it is 17
 * Hence I2C Module frequency approximately 8MHz
 * Now Master Clk  Frequency = I2C Module frequency/((ICCL + 6) + ( ICCH + 6))
 * where ICCL[= 34] is I2C Clock Divider Low register and ICCH[=34] is  
 * I2C Clock Divider Low register
 * Hence Master Clk  Frequency = 100KHz
 */

#define CSL_I2C_CLOCK_PRESCALAR     (17)
#define CSL_I2C_CLOCK_CLKL          (34)
#define CSL_I2C_CLOCK_CLKH          (34)

#define INTR_DISABLE                0x0

/*
 * To set the PLL divider value. To divide by four set three
 */
#define CSL_I2C_TEST_PLL_DIVIDER_DIV4      3

/* 
 * In function  pollStatus() the ICSTR register value is masked
 * with the second argument passed(eg:CSL_I2C_ICSTR_RX_RDY_CHECK) and compared
 * with the the following COMPARE macros
 */

/* 
 * Used for checking whether Bus Busy bit =0(ie bus is free) and 
 * RXRDY(receive ready) bit = 0(ie Data received is read) 
 */
#define COMPARE_VAL0                0x0

/* Used for checking whether RXRDY(receive ready) bit = 1 ie data received */
#define COMPARE_VAL1                0x1

/*
 * =============================================================================
 *   @func  i2c_csl_example_test
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *      This is the test routine which perform loop back test.
 *
 *   @return
 *      NONE
 *
 * =============================================================================
 */
extern void i2c_csl_example_test (
    void
);

/*
 * =============================================================================
 *   @func  i2cSetupCPUCLK
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     It uses PLLC controller APIs to set the clock.
 *
 *   @return
 *      status  - The status of the function
 *
 *
 * =============================================================================
 */
extern CSL_Status i2cSetupCPUCLK (
    void
);


/*
 * =============================================================================
 *   @func   pollStatus
 *   
 *   @arg    status         - compare value
 *           mask           - holds the value which decides the switch case to
 *                            be executed
 *           timeOut        - Timeout value
 *
 *   @desc
 *     This API will poll for I2C register status till time out occur
 *
 *   @return  Bool
 *
 * =============================================================================
 */
extern Bool pollStatus (
    Uint32  status,
    Uint32  mask,
    int     timeOut
);

/*
 * =============================================================================
 *   @func   i2c_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the i2c module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
extern void i2c_error_exit (
    void
);

/*
 * =============================================================================
 *   @func   pllc_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the pllc module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
extern void pllc_error_exit (
    void
);


#ifdef __cplusplus
}
#endif


#endif /* _I2C_EXAMPLE_H_ */
