/** ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  Uhpi_example.c
 *
 *   @desc  Example of using the UHPI module CSL
 *
 * =============================================================================
 *   @n <b> Test Description </b>
 *   @n This example contains an UHPI Initialization and also setting value and
 *      read back the register value.
 *      1. Initialize device config registers required for the test
 *      2. Set uhpi to openuhpi, word addressing, full word transfer, muxed mode
 *          non paged memory access mode
 *      3. Enable UHPI peripheral
 *      4. Setting the GPINT_EN0 bit in GPINT Control Register.
 *      5. Reading back the GPINT_EN0 bit in GPINT Control Register.
 *      6. compare both set value and read back value of the GPINT control
 *          register bit.
 *      7. If it's equal TEST PASS or else TEST FAIL.
 * ============================================================================
 *      
 *   <b> Test Procedure </b>
 *   @verbatim
 *      1. Configure the CCS setup to work with the emulator being used.
 *         Refer CCS manual for setup configuration
 *      2. Load required GEL file depending on the board used
 *      3. Open project uhpi_example.pjt
 *      4. Build the project and load the .out file of the project.
 *      5. The test can be executed from the main().
 *          
 *   @endverbatim
 *       
 *   
 * ============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  21-Mar-2005 asr File Created.
 *
 * =============================================================================
 */

#include "csl_uhpi.h"
#include "csl_chip.h"
#include "stdio.h"

#define CSL_UHPI_MSB        0x0
#define CSL_UHPI_UMB        0x0
#define CSL_UHPI_CFG        0x0
#define CSL_UHPI_CFG_FULL   0x8
#define CSL_UHPI_CFG_EN     0x9
#define UHPI_TEST_PASSED    0x0

/* UHPI Handle Initialize to NULL */
CSL_UhpiHandle           hUhpi = (CSL_UhpiHandle) NULL;
/* CSL status */
CSL_Status               status;

Uint32                   response;

/* forward decleration */
void uhpi_error_exit (
    void
);

CSL_Status uhpi_test(
    void
);
/*
 * ============================================================================
 *   @func   main
 *
 *   @desc
 *     This is the main routine for the file.
 *
 *  @arg  
 *      NONE
 *
 *  @return
 *      NONE
 * ============================================================================
*/
void main (
)
{
    status = uhpi_test();
    /* Comparing the HwStatus return value with the HwControl set value */
    if (response == CSL_UHPI_GPINT_EN0 && status == CSL_SOK) {
        printf ("UHPI CSL example test passed\n");
    }
    else {
        printf ("UHPI CSL example test Failed\n");
    }
}

/*
 * ============================================================================
 *   @func   uhpi_test
 *
 *   @desc
 *     This function will initialize the UHPI module and also write and read
 *      back the value from the UHPI register.
 *
 *  @arg  
 *      NONE
 *
 *  @return
 *      NONE
 * ============================================================================
*/

CSL_Status uhpi_test(
    void
)
{
    CSL_UhpiObj              uhpiObj;
    Uint32                   arg = CSL_UHPI_GPINT_EN0;

    CSL_sysInit();

    /* Initialiaze device config registers related to HPI */
    status = CSL_uhpiInit (NULL);
    if (status != CSL_SOK) {
        uhpi_error_exit ();
        return status;
    }

    /* Open the uhpi CSL module */
    hUhpi = CSL_uhpiOpen (&uhpiObj, CSL_UHPI, NULL, &status);
    if ((hUhpi == NULL) || (status != CSL_SOK)) {
        printf ("\nTEST FAILED\nERROR:CSL_UHPI open failed");
        uhpi_error_exit ();
        status = CSL_ESYS_BADHANDLE;
        return status;
    }

    /* 
       Configure HPI to openhpi, no byte addressing, 
       half word transfer, non mux mode, and paged memory 
     */

    /* Configure upper 16 bits of destination address */
    /* Upper 8 bits */
    CSL_chipWriteReg (CSL_CHIP_REG_CFGHPIAMSB, CSL_UHPI_MSB);

    /* Upper middle 8 bits */
    CSL_chipWriteReg (CSL_CHIP_REG_CFGHPIAUMB, CSL_UHPI_UMB);

    /* Ensure that HPIENA bit is 0 */
    CSL_chipWriteReg (CSL_CHIP_REG_CFGHPI, CSL_UHPI_CFG);

    /* Configure HPI */
    CSL_chipWriteReg (CSL_CHIP_REG_CFGHPI, CSL_UHPI_CFG_FULL);

    /* Enable HPI */
    CSL_chipWriteReg (CSL_CHIP_REG_CFGHPI, CSL_UHPI_CFG_EN);

    /* Setting the GPINT_EN0 bit in GPINT Control Register */
    CSL_uhpiHwControl (hUhpi, CSL_UHPI_CMD_GPINT_SET, (void *) &arg);

    /* Getting the value GPINT_EN0 bit in GPINT Control Register */
    status = CSL_uhpiGetHwStatus (hUhpi, CSL_UHPI_QUERY_GPINT_EN0, &response);
    if (status != CSL_SOK) {
        uhpi_error_exit ();
        return status;
    }
    return status;
}

/******************************************************************************
* @func uhpi_error_exit
*
* @desc Error in executing the example. As error is occurred closing the UHPI
*       handle and returning.
*
* @arg  
*   NONE
*
* @return
*   NONE
******************************************************************************/
void uhpi_error_exit (
    void
)
{
    status = CSL_uhpiClose (hUhpi);
    if (status != CSL_SOK) {
        status = status;
    }
        return;
}
