/** ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  Mcasp_example.c
 *
 *
 *   @desc  Example of McASP LoopBack Test.
 *
 * =============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows how to test the McASP in LoopBack Mode.
 *  1. Initialize McASP & DMAX Module.
 *  2. Relocate the Interrupt Vector Table by writing valid RAM location.
 *  3. Setup the DMAX Interrupts for Transfer complete (INT8) &
 *      Transfer Failure (INT7) in setup_interrupts().
 *  4. Initialize the dmaxEvent with MCASP0TX & MCASP0RX EventIds and Param0, 
 *      Param1 ParameterIDs.
 *  5. Setup the values in 3-Dimensional EventSetup & ParameterSetup
 *      for Tx & Rx.
 *  6. Enable the Tx ,Rx Events and Mode.
 *  7. Takeout both Transmit & Receive Serializer out of reset.
 *  8. verify all Transmit buffers are serviced.
 *  9. Take both Transmit & Receive state Machine out of reset.
 *  10. Wait for Data transfer to happen.
 *  11. Once the Data is transfered, Transfer Complete Interrupt will set the
 *      varaibles of the xmtDone & rcvDone variables and comes out of the loop.
 *  12. Compare srcData & dstData, if both src & dst has same then transfer
 *      success
 *  13. If the data varies in srcData & dstData then transfer fail.
 *==============================================================================
 *      
 *   <b> Test Procedure </b>
 *   @verbatim
 *  1. Configure the CCS setup to work with the emulator being used.
 *     Refer CCS manual for setup configuration
 *  2. Load required GEL file depending on the board used
 *  3. Open project mcasp_example.pjt
 *  4. Build the project and load the .out file of the project.
 *  5. The test can be executed from the main().
 *          
 *   @endverbatim
 *       
 *   
 * ===========================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  21-Mar-2005 asr File Created.
 *
 * =============================================================================
 */

#include "mcasp_example.h"

/* Variable to check the Transfer Complete Interrupt generated */
Uint32  dmaxTcValue     = TC_PASS;

/* Global Handles */
CSL_McaspHandle          hMcasp;

/* McASP handle to work with a McASP instance */
CSL_McaspObj             mcaspObj; 

/*DMAX Global Gandles */
CSL_DmaxObj              dmaxEventTx;     /* DMAX Event Object    */
CSL_DmaxObj              dmaxEventRx;     /* DMAX Event Object    */
CSL_DmaxHandle           hDmaxTx;       /* DMAX Tx Handle       */
CSL_DmaxHandle           hDmaxRx;       /* DMAX Rx Handle       */
CSL_DmaxHwSetup          hwSetupTx;     /* DMAX Tx Hardware Setup */
CSL_DmaxHwSetup          hwSetupRx;     /* DMAX Rx Hardware setup */

/* General Purpose Transfer Event Setup */
CSL_DmaxGPTransferEventSetup gpxfrEventSetup; 

/* General purpose Parameter Setup */
CSL_DmaxGPXFRParameterSetup gpxfrParameterSetup;

/* Status variable */
CSL_Status                  status=CSL_SOK;

/* source & Destination Data buffers */
Uint32                   srcData[TOTAL_RCV_DATA * NUM_RCV_SERIALIZER];
Uint32                   dstData[TOTAL_RCV_DATA * NUM_RCV_SERIALIZER];
volatile Uint32          xmtDone = 0;
volatile Uint32          rcvDone = 0;

/* Interrupt handle */
CSL_IntcHandle              hIntc;
CSL_IntcEventEnableState    eventStat;
CSL_IntcDispatcherContext   intcDispatcherContext;

/*
 * ============================================================================
 *   @func   main
 *
 *   @desc
 *     This is the main routine for the file.
 *
 *  @arg 
 *      NONE
 *
 *  @return
 *      NONE
 * ============================================================================
*/
void main (
    void
)
{

    status = mcasp_loopback_example();
    /* printing whether test is passed or Fail */
    if ((status != CSL_SOK) && (dmaxTcValue == TC_PASS)) {
        printf ("McASP CSL Example Test Failed\n");
    }
    else {
        printf ("McASP CSL Example Test Passed\n");
    }
}

/**
 * ============================================================================
 *   @func   mcasp_loopback_example
 *
 *   @desc
 *      This routine will setup the values for McASP Tx and Rx in LoopBack Mode. 
 *      And verify the data once the data is transfered.
 *
 * @arg 
 *      NONE
 *
 * @return
 *      CSL_Status
 * ============================================================================
*/
CSL_Status mcasp_loopback_example(
    void
)
{
    /* Number of Data that should be transfered */
    Uint32                   length;
    /* Variable to enable the loopback */
    Bool                     loopBackEnable = 0;
    /* setting up the hardware config with default values */
    CSL_McaspHwSetup         mcaspHwCfg = CSL_MCASP_HWSETUP_DEFAULTS;
    Uint32                   rtdm = CSL_MCASP_RTDM_RTDMS_MASK;
    Uint32                   xtdm = CSL_MCASP_XTDM_XTDMS_MASK;
    /* receive clock */
    CSL_McaspHwSetupDataClk  rcvClk;
    /* transmit clock */
    CSL_McaspHwSetupDataClk  xmtClk;
    /* Mask variable */
    CSL_BitMask16            mask;
    /* transmit data */
    Bool                     xData;
    Uint32                   response, i = 0;

    length = TOTAL_RCV_DATA * NUM_RCV_SERIALIZER;

    CSL_sysInit();
    	
    /* McASP Module Initilization */
    status = CSL_mcaspInit (NULL);

    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* DMAX Initilization */
    status = CSL_dmaxInit (NULL);

    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /*ISTP to point to the base of IVT */
    CSL_intcSetVectorPtr (ISTP_VECTOR_VALUE);

    /* Open the McASP Instance */
    hMcasp = CSL_mcaspOpen (&mcaspObj, CSL_MCASP_0, NULL, &status);

    if ((hMcasp == NULL) || (status != CSL_SOK)) {
        printf ("\nTEST FAILED\nERROR:CSL_MCASP_0 open failed");
        status = CSL_ESYS_BADHANDLE;
        return status;
    }

    /* FillMem will store the default value incrementing by one 
     * in each location of the srcData. And in the dstData location
     * constant default value is stored.
     */
    response = fillMem ((Uint32) srcData, length, SRC_DATA_DEFAULT, FILL_INC);
    if (response == ERROR_FILL) {
        mcasp_error_exit ();
        status = ERROR_FILL;
        return status;
    }
    
    /* FillMem will store the default value incrementing by one 
     * in each location of the srcData. And in the dstData location
     * constant default value is stored.
     */
    response = fillMem ((Uint32) dstData, length, DST_DATA_DEFAULT, \
                                                FILL_CONST);
    if (response == ERROR_FILL) {
        mcasp_error_exit ();
        status = ERROR_FILL;
        return status;
    }

    /* MCASP0 TX DMAX REQ paramters */
    dmaxEventTx.eventUid = CSL_DMAX_HIPRIORITY_MCASP0TX_UID;
    dmaxEventTx.paramUid = CSL_DMAX_HIPRIORITY_PARAMETERENTRY0_UID;

    /* Getting the DMAX Handle by calling CSL_dmaxOpen() */
    hDmaxTx = CSL_dmaxOpen (&dmaxEventTx, CSL_DMAX, NULL, &status);

    if (status != CSL_SOK || (hDmaxTx == (CSL_DmaxHandle) CSL_DMAX_BADHANDLE)) {
        mcasp_error_exit ();
        status = CSL_DMAX_BADHANDLE;
        return status;
    }

    /* DMAX for data transfer on MCASP0TX DMA REQ - 2D General Purpose Transfer */

    /* Quantam Transfer Size Limit not more than 4 elements */
    gpxfrEventSetup.qtsl    = CSL_DMAX_EVENT2_QTSL_MOVE16_ELE;
    
    /* Transfer Complete Code will set in DTCR0/DTCR1 Register */
    gpxfrEventSetup.tcc     = CSL_DMAX_EVENT2_TCC_RESETVAL;
    
    /* Alternate Transfer mode Disable */
    gpxfrEventSetup.atcint  = CSL_DMAX_EVENT2_ATCINT_DISABLE;
    
    /* Transfer Complete Interrupt Enable */
    gpxfrEventSetup.tcint   = CSL_DMAX_EVENT2_TCINT_ENABLE;
    
    /* No Reload after transfer is completed */
    gpxfrEventSetup.rload   = CSL_DMAX_EVENT2_RLOAD_DISABLE;
    
    /* Counter Configuration */
    gpxfrEventSetup.cc      = CSL_DMAX_EVENT2_CC_COUNT2_15_COUNT1_8_COUNT0_8;
    
    /* 32-bit Element Size */
    gpxfrEventSetup.esize   = CSL_DMAX_EVENT2_ESIZE_32BIT;
    
    /* Pointer to Transfer Entry */
    gpxfrEventSetup.pte     = hDmaxTx->paramPtr;
    
    /* General purpose Event Type */
    gpxfrEventSetup.etype   = CSL_DMAX_EVENT2_ETYPE_GENERALXFR;
    
    /* storing the parameterSetup address in the EventSetup structure
     * of paramSetup variable
     */
    gpxfrEventSetup.paramSetup = &gpxfrParameterSetup;

    /* Number of bytes of data to be transfer in 1-Dimension */
    gpxfrParameterSetup.count0 = NUM_RCV_SERIALIZER;
    
    /* Number of bytes of data to be transfer in 2-Dimension */
    gpxfrParameterSetup.count1 = NUM_TDM_SLOT;
    
    /* Number of bytes of data to be transfer in 3-Dimension */
    gpxfrParameterSetup.count2 = COUNT2;
    
    /* Source Address Index0 Increment */
    gpxfrParameterSetup.srcIndex0 = TX_SRC_INDEX0;
    
    /* Destination Address Index0 Increment */
    gpxfrParameterSetup.dstIndex0 = TX_DST_INDEX0;
    
    /* Source Address Index1 Increment */
    gpxfrParameterSetup.srcIndex1 = TX_SRC_INDEX1;
    
    /* Destination address Index1 increment */
    gpxfrParameterSetup.dstIndex1 = TX_DST_INDEX1;
    
    /* Source address Index2 increment */
    gpxfrParameterSetup.srcIndex2 = TX_SRC_INDEX2;
    
    /* Destination address Index2 increment */
    gpxfrParameterSetup.dstIndex2 = TX_DST_INDEX2;
    
    /* Source Reload Address - 0 */
    gpxfrParameterSetup.srcReloadAddr0 = (Uint32) srcData;
    
    /* Destination Reload Address - 0 */
    gpxfrParameterSetup.dstReloadAddr0 = (Uint32) MCASP0_TXBUF_ADDR;
    
    /* Source Reload Address - 1 */
    gpxfrParameterSetup.srcReloadAddr1 = SRC_ADDR1;
    
    /* Destination Reload Address - 1 */
    gpxfrParameterSetup.dstReloadAddr1 = DST_ADDR1;
    
    /* Rising Edge polarity */
    hwSetupTx.polarity = CSL_DMAX_POLARITY_RISING_EDGE;

    /* High Event priority */
    hwSetupTx.priority = CSL_DMAX_EVENT_HI_PRIORITY;
    
    /* storing the EventSetup address in the Handle eventsetup variable */
    hwSetupTx.eventSetup = (CSL_DmaxEventSetup *) & gpxfrEventSetup;

    status = CSL_dmaxHwSetup (hDmaxTx, &hwSetupTx);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Event Enable */
    status = CSL_dmaxHwControl (hDmaxTx, CSL_DMAX_CMD_EVENTENABLE, NULL);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* MCASP0 RX DMAX REQ paramters */
    dmaxEventRx.eventUid = CSL_DMAX_HIPRIORITY_MCASP0RX_UID;
    dmaxEventRx.paramUid = CSL_DMAX_HIPRIORITY_PARAMETERENTRY1_UID;

    hDmaxRx = CSL_dmaxOpen (&dmaxEventRx, CSL_DMAX, NULL, &status);

    if (status != CSL_SOK || (hDmaxRx == (CSL_DmaxHandle) CSL_DMAX_BADHANDLE)) {
        mcasp_error_exit ();
        status = CSL_DMAX_BADHANDLE;
        return status;
    }

    /* DMAX for data transfer on MCASP0RX DMA REQ-1D General Purpose Transfer */

    /* Quantam Transfer Size Limit not more than 4 elements */
    gpxfrEventSetup.qtsl    = CSL_DMAX_EVENT2_QTSL_MOVE16_ELE;
    
    /* Transfer Complete Code will set in DTCR0/DTCR1 Register */
    gpxfrEventSetup.tcc     = CSL_DMAX_EVENT2_TCC_RESETVAL;
    
    /* Alternate Transfer mode Disable */
    gpxfrEventSetup.atcint  = CSL_DMAX_EVENT2_ATCINT_DISABLE;
    
    /* Transfer Complete Interrupt Enable */
    gpxfrEventSetup.tcint   = CSL_DMAX_EVENT2_TCINT_ENABLE;
    
    /* No Reload after transfer is completed */
    gpxfrEventSetup.rload   = CSL_DMAX_EVENT2_RLOAD_DISABLE;
    
    /* Counter Configuration */
    gpxfrEventSetup.cc      = CSL_DMAX_EVENT2_CC_COUNT2_15_COUNT1_8_COUNT0_8;
    
    /* 32-bit Element Size */
    gpxfrEventSetup.esize   = CSL_DMAX_EVENT2_ESIZE_32BIT;
    
    /* Pointer to Transfer Entry */
    gpxfrEventSetup.pte     = hDmaxRx->paramPtr;
    
    /* General purpose Event Type */
    gpxfrEventSetup.etype   = CSL_DMAX_EVENT2_ETYPE_GENERALXFR;
    
    gpxfrEventSetup.paramSetup = &gpxfrParameterSetup;
    /* Number of bytes of data to be transfer in 1-Dimension */
    
    gpxfrParameterSetup.count0 = COUNT0;
    /* Number of bytes of data to be transfer in 2-Dimension */
    
    gpxfrParameterSetup.count1 = COUNT1;
    /* Number of bytes of data to be transfer in 3-Dimension */
    
    gpxfrParameterSetup.count2 = COUNT2;
    /* Source Address Index0 Increment */
    
    gpxfrParameterSetup.srcIndex0 = RX_SRC_INDEX0;
    /* Destination Address Index0 Increment */
    
    gpxfrParameterSetup.dstIndex0 = RX_DST_INDEX0;
    /* Source Address Index1 Increment */
    
    gpxfrParameterSetup.srcIndex1 = RX_SRC_INDEX1;
    /* Destination address Index1 increment */
    
    gpxfrParameterSetup.dstIndex1 = RX_DST_INDEX1;
    /* Source address Index2 increment */
    
    gpxfrParameterSetup.srcIndex2 = RX_SRC_INDEX2;
    /* Destination address Index2 increment */
    
    gpxfrParameterSetup.dstIndex2 = RX_DST_INDEX2;
    /* Source Reload Address - 0 */
    
    gpxfrParameterSetup.srcReloadAddr0 = (Uint32) MCASP0_RXBUF_ADDR;
    /* Destination Reload Address - 0 */
    
    gpxfrParameterSetup.dstReloadAddr0 = (Uint32) dstData;
    /* Source Reload Address - 1 */
    
    gpxfrParameterSetup.srcReloadAddr1 = SRC_ADDR1;
    /* Destination Reload Address - 1 */
    
    gpxfrParameterSetup.dstReloadAddr1 = DST_ADDR1;

    /* Rising Edge polarity */
    hwSetupRx.polarity = CSL_DMAX_POLARITY_FALLING_EDGE;

    /* High Event priority */
    hwSetupRx.priority = CSL_DMAX_EVENT_HI_PRIORITY;
    hwSetupRx.eventSetup = (CSL_DmaxEventSetup *) & gpxfrEventSetup;

    status = CSL_dmaxHwSetup (hDmaxRx, &hwSetupRx);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Event Enable */
    status = CSL_dmaxHwControl (hDmaxRx, CSL_DMAX_CMD_EVENTENABLE, NULL);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Setting the McASP Registers with Reset Values */
    mcaspHwCfg.glb.dlbMode  = CSL_MCASP_DLBCTL_ORD_MASK;
    mcaspHwCfg.rx.mask      = CSL_MCASP_RMASK_RMASK_MASK;
    mcaspHwCfg.rx.fmt       = CSL_MCASP_RFMT_RSSZ_MASK;
    mcaspHwCfg.rx.frSyncCtl = CSL_MCASP_AFSRCTL_FSRM_MASK | TDM_SLOTS_VALUE;
    mcaspHwCfg.rx.tdm       = CSL_MCASP_RTDM_RTDMS_MASK;
    mcaspHwCfg.tx.mask      = CSL_MCASP_XMASK_XMASK_MASK;
    mcaspHwCfg.tx.fmt       = CSL_MCASP_XFMT_XSSZ_MASK;
    mcaspHwCfg.tx.frSyncCtl = CSL_MCASP_AFSXCTL_FSXM_MASK | TDM_SLOTS_VALUE;
    mcaspHwCfg.tx.tdm       = CSL_MCASP_XTDM_XTDMS_MASK;
    mcaspHwCfg.emu          = CSL_MCASP_PWRDEMU_FREE_OFF;

    /* Program McASP control registers and wait for 2 clock cycles */
    status = CSL_mcaspHwSetup (hMcasp, &mcaspHwCfg);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Configuring RTDM slots */
    status = CSL_mcaspHwControl (hMcasp, CSL_MCASP_CMD_CONFIG_RTDM_SLOT, &rtdm);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }
    /* configuring Transmit TDM slots */
    status = CSL_mcaspHwControl (hMcasp, CSL_MCASP_CMD_CONFIG_XTDM_SLOT, &xtdm);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* setting up the transmit clock */
    xmtClk.clkSetupClk = CSL_MCASP_ACLKXCTL_CLKXM_MASK;
    xmtClk.clkChk = CSL_MCASP_XCLKCHK_RESETVAL;
    xmtClk.clkSetupHiClk = HCLKRCTL_DIV_INTER_FALL;
    /* setting up the transmit clock values */
    status = CSL_mcaspHwControl (hMcasp, CSL_MCASP_CMD_CLK_SET_XMT, &xmtClk);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* setting up the receive clock */
    rcvClk.clkSetupClk = CSL_MCASP_ACLKRCTL_RESETVAL;
    rcvClk.clkChk = CSL_MCASP_RCLKCHK_RESETVAL;
    rcvClk.clkSetupHiClk = HCLKRCTL_DIV_INTER_FALL;
    /* setting up the receive clock values */
    status = CSL_mcaspHwControl (hMcasp, CSL_MCASP_CMD_CLK_SET_RCV, &rcvClk);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Enable digital loop back mode */
    loopBackEnable = TRUE;
    status = CSL_mcaspHwControl (hMcasp, CSL_MCASP_CMD_DLB_ON, &loopBackEnable);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }
    /* setting up the DMAX INT7 & INT8 interrupts */
    status = setup_Interrupts ();
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Take receive serial clock, high frequency clock and
     * serializer out of reset
     */
    mask = CSL_MCASP_GBLCTL_RCLKRST_MASK |
        CSL_MCASP_GBLCTL_RHCLKRST_MASK | CSL_MCASP_GBLCTL_RSRCLR_MASK;
    CSL_mcaspResetCtrl (hMcasp, mask);

    /* Take transmit serial clock, high frequency clock and
     * serializer out of reset 
     */
    mask = CSL_MCASP_GBLCTL_XCLKRST_MASK |
        CSL_MCASP_GBLCTL_XHCLKRST_MASK | CSL_MCASP_GBLCTL_XSRCLR_MASK;
    CSL_mcaspResetCtrl (hMcasp, mask);

    /* Verify all transmit buffers are serviced */
    while (!(CSL_mcaspGetHwStatus (hMcasp, CSL_MCASP_QUERY_XSTAT_XDATA,
                &xData)));

    /* Take transmit and receive state machine out of reset          */
    status =
        CSL_mcaspHwControl (hMcasp, CSL_MCASP_CMD_ACTIVATE_SM_RCV_XMT, NULL);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Take transmit and receive frame sync out of reset             */
    status =
        CSL_mcaspHwControl (hMcasp, CSL_MCASP_CMD_ACTIVATE_FS_RCV_XMT, NULL);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Wait for Data Transfer to happen
     * These flags are set by the DMA  
     * interrupt when the transfers are
     * complete
     */

    while (!xmtDone);
    while (!rcvDone);

    /* check srcData & dstData data are same */
    for (i = 0; i < length; i++) {
        if (srcData[i] != dstData[i]) {
            mcasp_error_exit ();
            status = CSL_ESYS_FAIL;
            return status;
        }
    }

    /* Close McASP Handle */
    status = CSL_mcaspClose (hMcasp);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }
    /* Close DMAX Tx Handle */
    status = CSL_dmaxClose (hDmaxTx);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }
    /* Close DMAX Rx Handle */
    status = CSL_dmaxClose (hDmaxRx);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    return status;
}

/******************************************************************************
* @func setup_Interrupts
*
* @desc Setting up the DMAX INT7 & INT8 Interrupts.
*
* @arg  
*   NONE
*
* @return
*   CSL_Status
*
*******************************************************************************
*/
CSL_Status setup_Interrupts (
    void
)
{
    /* Interrupt Object */
    CSL_IntcObj                 intcObj;
    /* Globla Bit Enable state */
    CSL_IntcGlobalEnableState   state;
    /* Event Handler which holds ISR information */
    CSL_IntcEventHandlerRecord  isrRec;
    /* Interrupt Context */
    CSL_IntcContext             intcContext;

    /* Initialize the intc CSL modules with zeros  */
    memset (&intcContext, 0, sizeof (CSL_IntcContext));
    memset (&intcDispatcherContext, 0, sizeof (CSL_IntcDispatcherContext));

    /* Interrupt Initialization */
    status = CSL_intcInit (&intcContext);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }
    CSL_intcDispatcherInit (&intcDispatcherContext);

    /* Install handler for DMAX INT8 Interrupt */
    hIntc = CSL_intcOpen (&intcObj,
        CSL_INTC_EVENTID_DMAXEVTOUT1, NULL, &status);

    if ((hIntc == NULL) || (status != CSL_SOK)) {
        mcasp_error_exit ();
        status = CSL_ESYS_BADHANDLE;
        return status;
    }
    isrRec.handler = intr08;

    /* As no arguments assigning zero(0) value */
    isrRec.arg = (void *) 0x0;

    /*Plugging ISR in Event Handler */
    CSL_intcPlugEventHandler (hIntc, &isrRec);

    /* Enabling DMAXEVTOUT1 Event */
    status = CSL_intcEventEnable (CSL_INTC_EVENTID_DMAXEVTOUT1, &eventStat);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Install handler for DMAX INT07 interrupt */
    hIntc = CSL_intcOpen (&intcObj,
        CSL_INTC_EVENTID_DMAXEVTOUT0, NULL, &status);

    if ((hIntc == NULL) || (status != CSL_SOK)) {
        mcasp_error_exit ();
        status = CSL_ESYS_BADHANDLE;
        return status;
    }

    isrRec.handler = intr07;

    /* As no arguments assigning zero(0) value */
    isrRec.arg = (void *) 0x0;

    /* Plugging ISR in Event Handler */
    CSL_intcPlugEventHandler (hIntc, &isrRec);

    /* DMAXEVTOUT0 Event Enable */
    status = CSL_intcEventEnable (CSL_INTC_EVENTID_DMAXEVTOUT0, &eventStat);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Enabling Non-Maskable Interrupt */
    status = CSL_intcEventEnable (CSL_INTC_EVENTID_NMI, &eventStat);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Enabling Global Enable bit in Control Status Register (CSR) */
    status = CSL_intcGlobalEnable (&state);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }

    /* Closing INTC handle */
    status = CSL_intcClose (hIntc);
    if (status != CSL_SOK) {
        mcasp_error_exit ();
        return status;
    }
    
    return status;
}

/******************************************************************************
* @func intr08
*
* @desc Interrupt Service Routine, this will get triggered if the
*       data transfer is Success. This function will clear the TCC bit 
*       of the DECT0/1 register.
*
* @arg  
*   NONE
*
* @return
*   NONE
*
*******************************************************************************
*/
void
intr08 ()
{
    CSL_Status  status;

    /* To avoid CCS warnings */
    status = status;

    /* Clearing the TCC bit */
    if (xmtDone) {
        status = CSL_dmaxHwControl (hDmaxRx, CSL_DMAX_CMD_CLEARTCC, NULL);
        rcvDone = 1;
    }
    else {
        status = CSL_dmaxHwControl (hDmaxTx, CSL_DMAX_CMD_CLEARTCC, NULL);
        xmtDone = 1;
    }
    dmaxTcValue = TC_PASS;
}

/******************************************************************************
* @func intr07
*
* @desc Interrupt Service Routine, this will get triggered if the
*       data transfer fails
*
* @arg  
*   NONE
*
* @return
*   NONE
*
*******************************************************************************
*/

void
intr07 ()
{
    dmaxTcValue = TC_FAIL;
}

/******************************************************************************
* @func     fillMem( Uint32 start_location, Uint32 length,
*                      Uint32 fill_value, Uint8 fill_type )  
*
* @desc     Fills a memory location with a pattern as requested. 
*           Beginning at 'start_location', 'length' words (32-bit) are filled,
*           starting with 'fill_value'.  After the initial value, the
*           other memory locations are filled with either a constant
*           value, incrementing values, or decrementing values.
*
* @arg      Uint32 start_location : Memory location to start filling.
*           Uint32 length : Number of bytes to fill.
*           Uint32 fill_value : 32-bit value to start filling with.
*           Uint8 fill_type : Type of fill: 
*                              FILL_CONST, FILL_INC, FILL_DEC
*
* @returns  Uint32 flag : PASS for a success
*                          ERROR_TEST for a failure
*******************************************************************************
*/
Uint32 fillMem (
    Uint32 start_location,
    Uint32 length,
    Uint32 fill_value,
    Uint32 fill_type
)
{
    Uint32  *loc;
    Uint32  i;

    loc = (Uint32 *) start_location;

    for (i = 0; i < length; i++) {

        if (fill_type == FILL_CONST) {
            *loc = fill_value;
            /* Check that value was written correctly */
            if (*loc != fill_value)
                return ERROR_FILL;
        }
        else if (fill_type == FILL_INC) {
            *loc = (Uint32) (fill_value + i);
            /* Check that value was written correctly */
            if (*loc != (Uint32) (fill_value + i))
                return ERROR_FILL;
        }
        else if (fill_type == FILL_DEC) {
            *loc = (Uint32) (fill_value - i);
            /* Check that value was written correctly */
            if (*loc != (Uint32) (fill_value - i))
                return ERROR_FILL;
        }
        else {                  /* Error if non-valid fill type */
            return ERROR_FILL;
        }

        loc++;
    }

    return PASS;
}

/******************************************************************************
* @func mcasp_error_exit
*
* @desc Error in executing the example. As error is occered closing the McASP
*       handle and returning.
*
* @arg  
*   NONE
*
* @return
*   NONE
******************************************************************************/

void mcasp_error_exit (
    void
)
{
    status = CSL_mcaspClose (hMcasp);
    if (status != CSL_SOK) {
        status = status;
    }
    return;
}
