/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  Rti_example.c
 *
 *
 *   @desc  Example of using the RTI module CSL
 *
 * =============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows how to use rti csl.
 * =============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows how to test the RTI CSL
 *      1. Initalize the interrupt required with proper ISR
 *      2. Intilaize the PLLC module
 *      3. Intialize RTI depending on the test number for various interrupt
 *      4. Start the counter
 *      5. Verify that interrupts are generated at intervals
 *      7. Stop the counter
 *      8. Close the module
 *==============================================================================
 *      
 *   <b> Test Procedure </b>
 *   @verbatim
 *      1. Configure the CCS setup to work with the emulator being used
 *      2. Please refer CCS manual for setup configuration and loading 
 *          proper GEL file
 *      3. Launch CCS window
 *      4. Open project Rti_example.pjt
 *      5. Build the project and load the .out file of the project.
 *      6. The test can be executed from the main().
 *          
 *   @endverbatim
 *       
 *   
 * =============================================================================
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  09-mar-2005 Ramitha Mathew  File created.
 *
 * =============================================================================
 */
 

#include "Rti_example.h"

/* Handle for the real time interrupt instance */
static CSL_RtiHandle     hRti;
/* Handle for Pllc */
static CSL_PllcHandle    hPllc;
/* Handle for INTC */
static CSL_IntcHandle    hIntc;

/* Flag indicating the completion of execution of ISR */
volatile Uint32          compInt0Event;


Uint32                   rtiTestFail = 0;

/*
 * =============================================================================
 *   @func   main
 *
 *   @desc
 *     main of test 
 * =============================================================================
 */
void main (
    void
)
{
    /* relocating the Interrupt Vector Table */
    CSL_intcSetVectorPtr (DEST_ADDR);

    /* This routine illustrates the RTI usage */
    rti_csl_example_test ();
    if (rtiTestFail == RTI_TEST_PASSED) {
        printf ("\nRti CSL Example Test PASSED\n");
    }
    else {
        printf ("\nRti CSL Example Test FAILED\n");
    }

}

/*
 * =============================================================================
 *   @func   rti_csl_example_test
 *
 *   @arg
 *      NONE
 *
 *   @desc
 *     Example test routine which calls test function and intialize ISR 
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void rti_csl_example_test (
    void
)
{
    /* variables for installing handler for Rti interrupts */
    CSL_IntcObj                 intcObj;
    CSL_IntcEventEnableState    state;
    CSL_IntcEventHandlerRecord  isrRec;
    CSL_Status                  status = CSL_SOK;    
    CSL_IntcDispatcherContext   intcDispatcherContext;
    CSL_IntcContext             intcContext;

    CSL_sysInit();

    /* Enable interface clock to the real time interrupt */
    status = pllcSysClock2Enable ();
    if (status != CSL_SOK) {
        printf ("RTI: clk setup using pllc....failed\n");
        rtiTestFail++;
        return;
    }

    memset (&intcContext, 0, sizeof (CSL_IntcContext));
    memset (&intcDispatcherContext, 0, sizeof (CSL_IntcDispatcherContext));

    /* Interrupt Initialization */
    status = CSL_intcInit (&intcContext);
    if (status != CSL_SOK) {
        printf ("RTI: intc init....failed\n");
        rtiTestFail++;
        return;
    }

    status = CSL_intcDispatcherInit (&intcDispatcherContext);
    if (status != CSL_SOK) {
        printf ("RTI: intc Dispatcher init....failed\n");
        rtiTestFail++;
        return;
    }
    
    /* disabling Global Interrupt */
    status = CSL_intcGlobalDisable (&state);
    if (status != CSL_SOK) {
        printf ("RTI: intc Global Disable....failed\n");
        rtiTestFail++;
        return;
    }

    /* Install handler for Rti compare interrupt0 */
    hIntc = CSL_intcOpen (&intcObj, \
        CSL_INTC_EVENTID_RTI_INT_REQ0, NULL, &status);
    if ((status != CSL_SOK) || (hIntc == NULL)) {
        printf ("RTI: intc open....failed\n");
        rtiTestFail++;
        return;
    }

    /* Assigning the ISR */
    isrRec.handler = comp0Isr;
    /* No argument is passed to the ISR */
    isrRec.arg = (void *) 0x0;

    CSL_intcPlugEventHandler (hIntc, &isrRec);

    /* Enable the cpu interrupt 4 */
    status = CSL_intcEventEnable (CSL_INTC_EVENTID_RTI_INT_REQ0, &state);
    if (status != CSL_SOK) {
        printf ("RTI: intc event enable....failed\n");
        rtiTestFail++;
        intc_error_exit ();
        return;
    }
   

    /* Enabling non-maskable interrupt */
    status = CSL_intcEventEnable (CSL_INTC_EVENTID_NMI, &state);
    if (status != CSL_SOK) {
        printf ("RTI: intc nmi event enable....failed\n");
        rtiTestFail++;
        intc_error_exit ();
        return;
    }

    status = CSL_intcGlobalEnable (&state);
    if (status != CSL_SOK) {
        printf ("RTI: intc global enable....failed\n");
        rtiTestFail++;
        intc_error_exit ();
        return;
    }

    status = CSL_intcClose (hIntc);
    if (status != CSL_SOK) {
        printf ("RTI: intc close....failed\n");
        rtiTestFail++;
        return;
    }

    example_test ();
    

}

/*
 * =============================================================================
 *   @func   example_test
 *
 *   @arg
 *      NONE
 *
 *   @desc
 *     This routine shows the usage of RTI
 *
 *   @return
 *      NONE
 *
 * =============================================================================
 */
void example_test (
    void
)
{
    CSL_RtiObj               rtiObj;
    CSL_Status               status = CSL_SOK;
    CSL_RtiHwSetup           hwSetup = CSL_RTI_HWSETUP_DEFAULTS;
    CSL_RtiHwSetup           hwSetupRead;
    Uint16                   count = 0;

    /* clear local data structures */
    memset (&rtiObj, 0, sizeof (CSL_RtiObj));
    memset (&hwSetup, 0, sizeof (CSL_RtiHwSetup));
    memset (&hwSetupRead, 0, sizeof (CSL_RtiHwSetup));

    /* Initalize the RTI csl module */
    status = CSL_rtiInit (NULL);
    if (status != CSL_SOK) {
        printf ("RTI: rti init....failed\n");
        rtiTestFail++;
        return;
    }
    
    /* Open csl module */
    hRti = CSL_rtiOpen (&rtiObj, CSL_RTI, NULL, &status);
    if ((status != CSL_SOK) || (hRti == NULL)) {
        printf ("RTI: rti open....failed\n");
        rtiTestFail++;
        return;
    }

    /* Setup hardware parameters */       
   
    hwSetup.blk0ExtnCntl                    = CSL_RTI_CAPTURE_EVENT_SOURCE1;
    hwSetup.blk1ExtnCntl                    = CSL_RTI_CAPTURE_EVENT_SOURCE1;   
    hwSetup.compareUpCntrs.compareUpCntr0   = UC_COMP_VALUE;   
    hwSetup.compVal.comp0Val                = COMPARE0_VALUE;
    hwSetup.compVal.comp1Val                = COMPARE1_VALUE;
    hwSetup.compVal.comp2Val                = COMPARE2_VALUE;
    hwSetup.compVal.comp3Val                = COMPARE3_VALUE;
    hwSetup.updateCompVal.updateComp0Val    = UPDATECOMPARE_VALUE;
    hwSetup.updateCompVal.updateComp1Val    = UPDATECOMPARE_VALUE;
    hwSetup.updateCompVal.updateComp2Val    = UPDATECOMPARE_VALUE;
    hwSetup.updateCompVal.updateComp3Val    = UPDATECOMPARE_VALUE;   
    hwSetup.preLoadWatchdog                 = PRELOAD_VALUE;    
        
    /* Enable compIntr0 alone */
    hwSetup.intConfig.compIntr0En       = TRUE;
    hwSetup.intConfig.compIntr1En       = FALSE;
    hwSetup.intConfig.compIntr2En       = FALSE;
    hwSetup.intConfig.compIntr3En       = FALSE;

    /* Stop Rti Block0 counters */
    status = CSL_rtiHwControl (hRti, CSL_RTI_CMD_STOP_BLOCK0, NULL);
    if (status != CSL_SOK) {
        printf ("RTI: rti stop blk cmd....failed\n");
        rtiTestFail++;
        rti_error_exit ();
        return;
    }

    /* Setup rti module */
    status = CSL_rtiHwSetup (hRti, &hwSetup);
    if (status != CSL_SOK) {
        printf ("RTI: rti hwsetup....failed\n");
        rtiTestFail++;
        rti_error_exit ();
        return;
    }

    /* verify the hwsetup configuration */
    status = CSL_rtiGetHwSetup (hRti, &hwSetupRead);
    if (status != CSL_SOK) {
        printf ("RTI: rti getHwsetup....failed\n");
        rtiTestFail++;
        rti_error_exit ();
        return;
    }

    /* Start Rti Block0 counters */
    status = CSL_rtiHwControl (hRti, CSL_RTI_CMD_START_BLOCK0, NULL);
    if (status != CSL_SOK) {
        rtiTestFail++;
        printf ("RTI: rti start blk cmd....failed\n");
        rti_error_exit ();
        return;
    }

    
    /* Checking for periodic compare interrupt0 generation.
     * The rti interrupt is expected to be generated five times
     */
    compInt0Event = FALSE;
    for (count = 5; count != 0; count--) {
        /* Waiting for the interrupt */
        while (compInt0Event != TRUE);            
        printf ("RTI: compare interrupt0 generated \n");
            
        compInt0Event = FALSE;
    }  

    /* stop counter */
    status = CSL_rtiHwControl (hRti, CSL_RTI_CMD_STOP_BLOCK0, NULL);
    if (status != CSL_SOK) {
        rtiTestFail++;
        printf ("RTI: rti stop blk0 cmd....failed\n");
        rti_error_exit ();
        return;
    }

    status = CSL_rtiClose (hRti);
    if (status != CSL_SOK) {
        rtiTestFail++;
        printf ("RTI: rti close....failed\n");
        rti_error_exit ();
        return;
    }
    return;
}

/*
 * =============================================================================
 *   @func   pllcSysClock2Enable
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function enables the input clock to the RTI
 *     
 *   @return
 *      status
 *
 * =============================================================================
 */

CSL_Status pllcSysClock2Enable (
    void
)
{

    CSL_PllcObj              pllcObj;
    CSL_PllcHwSetup          hwSetup;
    CSL_Status               status = CSL_SOK;

    /* Initialize the pllc CSL module */
    status = CSL_pllcInit (NULL);
    if (status != CSL_SOK) {
        printf ("PLLC: pllc init...Failed.\n");
        pllc_error_exit ();
        return status;
    }


    /* Open the pllc CSL module */
    hPllc = CSL_pllcOpen (&pllcObj, CSL_PLLC, NULL, &status);
    if (status != CSL_SOK || hPllc == NULL) {
        printf ("PLLC: Open... Failed\n");
        pllc_error_exit ();
        return status;
    }

    /* setup pllc hardware parameters */
    hwSetup.pllcMode = CSL_PLLC_BYPASS;
    /* divider2 is enabled */
    hwSetup.div2Enable.divEnable = CSL_PLLC_PLLDIV_ENABLE;
    /* divider2 ratio set to divide by 4 */
    hwSetup.div2Enable.pllDivRatio = CSL_PLLC_DIV3;

    /* pllc setup */
    status = CSL_pllcHwSetup (hPllc, &hwSetup);
    if (status != CSL_SOK) {
        printf ("PLLC: HwSetup... Failed\n");
        pllc_error_exit ();
        return status;
    }

    /* Check closing the module */
    status = CSL_pllcClose (hPllc);
    

    return status;
}


/*
 * =============================================================================
 *   @func   comp0Isr
 *
 *   @arg
 *      NONE
 *
 *   @desc
 *     This is the ISR comp0Isr is used for verifying Compare interrupt 0  
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void comp0Isr ()
{
    Bool          intEvent;
    CSL_Status    status;

    /* To remove warnings */
    status = status;
    /* Read the interrupt flag register */
    status = CSL_rtiGetHwStatus (hRti, CSL_RTI_QUERY_INT0_STATUS, &intEvent);

    if (intEvent == TRUE) {
        compInt0Event = TRUE;
    }

    /* Clear the interrupt */
    status = CSL_rtiHwControl (hRti, CSL_RTI_CMD_CLEAR_INT0, &intEvent);

}


/*
 * =============================================================================
 *   @func   rti_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the rti module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void rti_error_exit (
    void
)
{
    CSL_rtiClose (hRti);
}


/*
 * =============================================================================
 *   @func   pllc_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the pllc module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void pllc_error_exit (
    void
)
{
    CSL_pllcClose (hPllc);
}


/*
 * =============================================================================
 *   @func   intc_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the intc module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void intc_error_exit (
    void
)
{
    CSL_intcClose (hIntc);
}
