/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  Spi_example.c
 *
 *
 *   @desc  Example of SPI CSL module
 *
 *
 * =============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows how to use SPI csl.
 * =============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows how to test the SPI CSL
 *      1. Intialize the PLLC module    
 *      2. Intialize SPI with required setup for the test
 *      3. Transmit and receive the data in polling mode
 *      4. Verify data received
 *      5. Close the module
 *==============================================================================
 *      
 *   <b> Test Procedure </b>
 *   @verbatim
 *      1. Configure the CCS setup to work with the emulator being used.
 *         Refer CCS manual for setup configuration.
 *      2. Load required GEL file depending on the board used.
 *      3. Launch CCS window.
 *      4. Open project spi_example.pjt
 *      5. Build the project and load the .out file of the project.
 *      6. The test can be executed from the main().
 *          
 *   @endverbatim
 *       
 *   
 * =============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  07-Mar-2005 GaneshK  File created.
 *
 * =============================================================================
 */

#include "Spi_example.h"

/* Handle for the SPI instance */
CSL_SpiHandle            hSpi;

/* SPI data declarations */
CSL_SpiCptData           RxData;

CSL_SpiHwSetup           hwSetup;
CSL_SpiHwSetupPriFmt     priFmt0, priFmt1, priFmt2, priFmt3;

CSL_SpiHwSetupGen        spiGen = CSL_SPI_HWSETUP_GEN_DEFAULTS;
CSL_SpiHwSetupPri        spiPri = CSL_SPI_HWSETUP_PRI_DEFAULTS;
CSL_SpiHwSetupCpt        spiCpt = CSL_SPI_HWSETUP_CPT_DEFAULTS;
CSL_SpiHwSetupPins       spiPins = CSL_SPI_HWSETUP_PINS_DEFAULTS;

/* Variable to count the test failure */
Uint32                   spiTestFail = SPI_TEST_PASSED;

/*
 * =============================================================================
 *  @func   main
 *
 *  @desc
 *     This is the test main
 *
 *  @arg
 *      NONE
 *  
 *  @return
 *      NONE
 * =============================================================================
*/
void
main (
    void
)
{
    CSL_PllcHandle           hPllc;
    CSL_Status               status;
    CSL_PllcObj              pllcObj;
    CSL_PllcHwSetup          hwSetup;

    CSL_sysInit();

    /* Intialize PLLC module */
    status = CSL_pllcInit (NULL);

    /* Intialize the PLLC obj structure to zero */
    memset (&pllcObj, 0, sizeof (CSL_PllcObj));

    /* Get handle for PLLC Module */
    hPllc = CSL_pllcOpen (&pllcObj, CSL_PLLC, NULL, &status);
    if ((status != CSL_SOK) || (hPllc == NULL)) {
        spiTestFail++;
        printf ("SPI: Opening PLLC instance... Failed.\n");
        return;
    }
    else {
        printf ("SPI: Opening PLLC instance... Passed.\n");
    }

    /* 
     * Put PLLC in By pass Mode
     * Enable divider 2
     * divider 2 ratio set to divide by 2 
     */
    hwSetup.pllcMode = CSL_PLLC_BYPASS;
    hwSetup.div2Enable.divEnable = CSL_PLLC_PLLDIV_ENABLE;
    hwSetup.div2Enable.pllDivRatio = SPI_PLLC_DIV_RATIO;

    /* pllc setup */
    status = CSL_pllcHwSetup (hPllc, &hwSetup);
    if (status != CSL_SOK) {
        spiTestFail++;
        printf ("SPI: PLLC Hardware setup ... Failed.\n");
        return;
    }
    else {
        printf ("SPI: PLLC Hardware setup ... Passed.\n");
    }

    /* Close PLLC module */
    status = CSL_pllcClose (hPllc);
    if (status != CSL_SOK) {
        spiTestFail++;
        printf ("SPI: PLLC Close instance ... Failed.\n");
        return;
    }
    else {
        printf ("SPI: PLLC Close instance ... Passed.\n");
    }

    /* Perform the SPI Loop Back Test */
    spi_csl_example_test ();

    /* Check for errors */
    if (spiTestFail == SPI_TEST_PASSED) {
        printf ("\nCSL SPI example Test PASSED \n");
    }
    else {
        printf ("\nCSL SPI example Test FAILED \n");
    }

    return;
}

/*
 * =============================================================================
 *  @func   spi_csl_example_test
 *
 *  @desc
 *     This is the test routine which transmit and verify data in loop back mode
 *
 *  @arg
 *      NONE
 *  
 *  @return
 *      NONE
 * =============================================================================
*/
void
spi_csl_example_test (
    void
)
{
    CSL_SpiObj               spiObj;
    CSL_Status               status;
    Uint16                   TxData = SPI_TX_DATA;
    Uint8                    flagStatus = 0;
    /* Clear local data structures */
    memset (&spiObj, 0, sizeof (CSL_SpiObj));

    /* Initialize SPI module */
    status = CSL_spiInit (NULL);
    if (status != CSL_SOK) {
        spiTestFail++;
        printf ("SPI: Initialization... Failed.\n");
        printf ("\tReason: CSL_spiInit failed. [status = 0x%x].\n", status);
        return;
    }
    else {
        printf ("SPI: Initialization... Passed.\n");
    }

    hSpi = CSL_spiOpen (&spiObj, CSL_SPI_1, NULL, &status);
    if ((status != CSL_SOK) || (hSpi == NULL)) {
        spiTestFail++;
        printf ("SPI: Opening instance... Failed.\n");
        printf
            ("\tReason: Error opening the instance. [status = 0x%x, hSpi = 0x%x]\n",
            status, hSpi);
        return;
    }
    else {
        printf ("SPI: Opening instance... Passed.\n");
    }

    /* Reset SPI */
    status = CSL_spiHwControl (hSpi, CSL_SPI_CMD_PRI_RESET, NULL);
    if (status != CSL_SOK) {
        spiTestFail++;
        printf ("SPI: CSL_spiHwControl - CSL_SPI_CMD_RESET... Failed.\n");
        printf ("\tReason: Error while resetting SPI. [status = 0x%x]\n",
            status);
        spi_error_exit ();
        return;
    }
    else {
        printf ("SPI: CSL_spiHwControl - CSL_SPI_CMD_RESET... Passed.\n");
    }

    /* Set SIMO & SOMI to Functional Pins */
    spiPins.func = SPI_PINCTRL_SPIFUNC_3PIN;
    /* Intialize the SPI hardware setpu structure */
    spiPri.fmt[0] = &priFmt0;
    spiPri.fmt[1] = &priFmt1;
    spiPri.fmt[2] = &priFmt2;
    spiPri.fmt[3] = &priFmt3;
    hwSetup.genPtr = &spiGen;
    hwSetup.priPtr = &spiPri;
    hwSetup.cptPtr = &spiCpt;
    hwSetup.pinsPtr = &spiPins;


    /* set SPI parameters to test loopback functionality */

    /* Set SPI to Master mode */
    hwSetup.genPtr->opMode = CSL_SPI_OPMOD_MASTER;

    /* set char lenth to 16 bit */
    priFmt0.charLen = SPI_DATA_FMT_CHARLEN_16BIT;

    /* set shift direction to LSB first */
    priFmt0.shiftDir = CSL_SPI_SHDIR_LSBFIRST;

	priFmt0.preScale = 7;

    hwSetup.genPtr->enaHiZ = CSL_SPI_ENAHIZ_YES;

    status = CSL_spiHwSetup (hSpi, &hwSetup);
    if (status != CSL_SOK) {
        spiTestFail++;
        printf ("SPI: HW Setup... Failed.\n");
        printf ("\tReason: Error while SPI Hw Setup. [status = 0x%x]\n",
            status);
        spi_error_exit ();
        return;
    }
    else {
        printf ("SPI: HW Setup... Passed.\n");
    }

    /* set SPI to loopback mode */
    CSL_FINST (hSpi->regs->SPIGCR1, SPI_SPIGCR1_LOOPBACK, ENABLE);

    /* Data Word 0 Selected */
    CSL_spiHwControl (hSpi, CSL_SPI_CMD_CPT_WRITE1, 0);

    /* Reset SPI */
    status = CSL_spiHwControl (hSpi, CSL_SPI_CMD_PRI_RESET, NULL);
    if (status != CSL_SOK) {
        spiTestFail++;
        printf ("SPI: CSL_spiHwControl - CSL_SPI_CMD_RESET... Failed.\n");
        printf ("\tReason: Error while resetting SPI. [status = 0x%x]\n",
            status);
        spi_error_exit ();
        return;
    }
    else {
        printf ("SPI: Reset... Passed.\n");
    }

    /* enable SPI for Data transfer */
    status = CSL_spiHwControl (hSpi, CSL_SPI_CMD_XFER_ENABLE, NULL);
    if (status != CSL_SOK) {
        spiTestFail++;
        printf ("SPI: CSL_spiHwControl - CSL_SPI_CMD_XFER_ENABLE... Failed.\n");
        spi_error_exit ();
        return;
    }
    else {
        printf ("SPI: Transfer enable ... Passed.\n");
    }

    /* Write trasmit data to DATA0 register */
    status = CSL_spiHwControl (hSpi, CSL_SPI_CMD_CPT_WRITE0, &TxData);
    if (status != CSL_SOK) {
        spiTestFail++;
        printf ("SPI: CSL_spiHwControl - CSL_SPI_CMD_CPT_WRITE0... Failed.\n");
        spi_error_exit ();
        return;
    }
    else {
        printf ("SPI: Transfering data ... Passed.\n");
    }

    do {
        CSL_spiGetHwStatus (hSpi, CSL_SPI_QUERY_EVT_STATUS,&flagStatus);
    } while ((flagStatus & SPI_CHK_RX_MASK) != SPI_RX_FLG_SET);


    status = CSL_spiHwControl (hSpi, CSL_SPI_CMD_CPT_READ, &RxData);
    if (status != CSL_SOK) {
        spiTestFail++;
        printf ("SPI: CSL_spiHwControl - CSL_SPI_CMD_CPT_READ... Failed.\n");
        spi_error_exit ();
        return;
    }
    else {
        printf ("SPI: Reading received data ... Passed.\n");
    }


    if (TxData == RxData.data) {
        printf ("SPI: Loopback Test... Passed.\n");
    }
    else {
        spiTestFail++;
        printf ("SPI: Loopback Test... Failed.\n");
    }

    /* Close the SPI Module */
    status = CSL_spiClose (hSpi);
    if (status != CSL_SOK) {
        spiTestFail++;
        printf ("SPI: Close the instance ... Failed\n");
    }
    else {
        printf ("SPI: Close valid instance... Passed.\n");
    }

    return;
}

/*
 * =============================================================================
 *  @func   spi_error_exit
 *
 *  @desc
 *     This calls the module close function in case of error 
 *
 *  @arg
 *      NONE
 *  
 *  @return
 *      NONE
 * =============================================================================
 */
void
spi_error_exit (
    void
)
{
    CSL_Status               status;

    /* Check closing the module */
    status = CSL_spiClose (hSpi);
    if (status != CSL_SOK) {
        spiTestFail++;
        printf ("SPI: Close Spi instance... Failed\n");
    }
    else {
        printf ("SPI: Close Spi instance... Passed\n");
    }
}
