/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  Icache_example.c
 *
 *   
 *   @desc  Example of using the ICACHE module CSL 
 * 
 *
 * =============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows how to test the ICACHE.
 *     1. The function first initializes and opens the 
 *        L1P I-cache module. 
 *     2. The function configures the cache for 
 *        default H/w setup using hwSetup function.       
 *     3. The function queries the  cache configuration
 *        parameter present in the MEMCSR registers using 
 *        status query commands and verifies their value against
 *        the expected values.
 *     4. Enables the I-cache using hardware control command
 *        Caches the function computeSum().Overwrites computeSum()
 *        in memory with computeDiff() instructions.
 *     5. Cache Block invalidation using hardware control command.
 *        Invalidates computeSum().Verified by calling computeSum()
 *        and expecting the difference.
 *        
 *     
 *==============================================================================
 *      
 <b> Test Procedure </b>
 *   @verbatim
 *      1. Configure the CCS setup to work with the emulator being used
 *      2. Please refer CCS manual for setup configuration and loading 
 *          proper GEL file
 *      3. Launch CCS window
 *      4. Open project Icache_example.pjt
 *      5. Build the project and load the .out file of the project.
 *      6. The test can be executed from the main().
 *          
 *   @endverbatim
 *       
 *   
 * =============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  08-mar-2005 Ramitha Mathew  File created.
 *
 * =============================================================================
 */
 
 
#include "Icache_example.h"
#include <soc.h>
#include <csl_icache.h>
#include <stdio.h>


/* Variables used to track the Test results*/
Uint32              icacheTestFail = 0;

CSL_IcacheHandle    hIcache = NULL;

/*
 * =============================================================================
 *   @func  main
 *
 *   @arg
 *      NONE
 *
 *   @desc
 *      main function to call parent test function 
 *
 *   @return
 *      NONE
 *
 * =============================================================================
 */

void main (
    void
)
{
    /* This routine illustrates the ICACHE usage */
    icache_csl_example_test ();
    if (icacheTestFail == ICACHE_TEST_PASSED) {
        printf ("\nIcache CSL Example Test PASSED\n");
    }
    else {
        printf ("\nIcache CSL Example Test FAILED\n");
    }
}

/*
 * =============================================================================
 *   @func   icache_csl_example_test
 *
 *   @arg
 *      NONE
 *
 *   @desc
 *     This function tests the combination of hardware 
 *     control and query commands. Various steps performed
 *     under this test subcategory are follows:
 *
 *     1. The function first initializes and opens the 
 *        L1P I-cache module. 
 *     2. The function configures the cache for 
 *        default H/w setup using hwSetup function.       
 *     3. The function queries the  cache configuration
 *        parameter present in the MEMCSR registers using 
 *        status query commands and verifies their value against
 *        the expected values.
 *     4. Enables the I-cache using hardware control command
 *        Caches the function computeSum().Overwrites computeSum()
 *        in memory with computeDiff() instructions.
 *     5. Cache Block invalidation using hardware control command.
 *        Invalidates computeSum().Verified by calling computeSum()
 *        and expecting the difference.If result obtained is the 
 *        difference the test has passed
 *     
 *    @return
 *      NONE
 *
 * =============================================================================
 */
void icache_csl_example_test (
    void
)
{
    CSL_IcacheObj            icacheObj;
    /* 
     * Function pointers used for copying a function from one memory
     * to another memory space
     */
    Uint32                   *f1, *f2;
    CSL_Status               status;
    CSL_IcacheHwSetup        hwSetup = CSL_ICACHE_HWSETUP_DEFAULTS;
    /* Start address for icache invalidation */
    CSL_IcacheAddr           startAddr = NULL;
    /* The numbers passed to the compute functions as arguments */
    Uint32                   num1 = 10;
    Uint32                   num2 = 20;
    /* Holds the result of evaluation */
    Uint32                   result = 0;
    /* Number of words for assembly instructions for the compute functions */
    Uint32                   count = 0;
    CSL_IcacheCount          size = 10;
    CSL_IcacheCount          blockSize = 40;
    /* Priority setting for icache */
    CSL_IcachePrio           prio;
    /* Temporary function pointer */
    void                    *temp;

    CSL_sysInit();
    /* Initialize the L1P I-cache CSL */
    status = CSL_icacheInit (NULL);
    if (status != CSL_SOK) {
        icacheTestFail++;
        printf ("ICACHE: Opening instance ... failed\n");
        return;
    }

    /* Open the L1P I-cache Instance. */
    hIcache = CSL_icacheOpen (&icacheObj, CSL_ICACHE, NULL, &status);
    if ((status != CSL_SOK) || (hIcache == NULL)) {
        icacheTestFail++;
        printf ("ICACHE: Opening instance ... failed\n");
        return;
    }


    /* Call hardware setup function to setup hardware */
    status = CSL_icacheHwSetup (hIcache, &hwSetup);
    if (status != CSL_SOK) {
        icacheTestFail++;
        printf ("ICACHE: H/W setup ... failed\n");
        icache_error_exit ();
        return;
    }

    /* verifying prio using status query */
    status = CSL_icacheGetHwStatus (hIcache, CSL_ICACHE_QUERY_PRIO,
        (void *) &prio);

    if ((status != CSL_SOK) || (prio != CSL_ICACHE_PRIO_CSP)) {
        printf ("ICACHE: Prio query ... failed\n");
        icacheTestFail++;
        icache_error_exit ();
        return;

    }

    /* Enabling the cache */
    status = CSL_icacheHwControl (hIcache, CSL_ICACHE_CMD_CACHE_ENABLE, NULL);
    if (status != CSL_SOK) {
        printf ("ICACHE: cache enable cmd ... failed\n");
        icacheTestFail++;
        icache_error_exit ();
        return;
    }

    /* calling computeSum() for first time to get it cached  */
    result = computeSum (num2, num1);
    if (result != (num2 + num1)) {
        icacheTestFail++;
        icache_error_exit ();
        return;
    }


    /* overwriting the computeSum() memory locations with computeDiff */
    temp = (void *) computeSum;
    f1   = (Uint32 *) temp;
    temp = (void *) computeDiff;
    f2   = (Uint32 *) temp;

    /* overwriting the computeSum() memory locations with computeDiff */
    for (count = 0; count < (Uint32) size; count++) {
        (f1)[count] = (f2)[count];
    }

    /* Checking Cache Block Invalidation functionality */

    /* Loading the start address of block to be invalidated */

    status = CSL_icacheHwControl (hIcache, CSL_ICACHE_CMD_INV_STARTADDR,
        (void *) computeSum);
    if (status != CSL_SOK) {
        printf ("ICACHE: start address cmd... failed\n");
        icacheTestFail++;
        icache_error_exit ();
        return;
    }


    /* veryfying using the query command */
    status = CSL_icacheGetHwStatus (hIcache, CSL_ICACHE_QUERY_INV_STARTADDR,
        (void *) &startAddr);
    if ((status != CSL_SOK) || (startAddr != (CSL_IcacheAddr) computeSum)) {
        printf ("ICACHE: start address query... failed\n");
        icacheTestFail++;
        icache_error_exit ();
        return;
    }

    /* Loading the invalidate byte count */
    status = CSL_icacheHwControl (hIcache, CSL_ICACHE_CMD_INV_BYTECNT,
        (void *) &blockSize);
    if (status != CSL_SOK) {
        printf ("ICACHE: bytecnt cmd... failed\n");
        icacheTestFail++;
        icache_error_exit ();
        return;
    }


    /* waiting for invalidation to be complete */
    do {
        CSL_icacheGetHwStatus (hIcache, CSL_ICACHE_QUERY_INV_WORDCNT,
            (void *) &size);
    } while (size != 0);

    /* verifying the invalidation */
    /* calling the computeSum from memory which is replaced with computeDiff */
    result = computeSum (num2, num1);
    if (result != (num2 - num1)) {
        icacheTestFail++;
        icache_error_exit ();
        return;
    }
}

/*
 * =============================================================================
 *  @func   computeSum
 *
 *  @arg
 *      NONE
 *
 *  @desc
 *     This is routine computes the sum of the two numbers inputted
 *  
 *  @return
 *      NONE
 * =============================================================================
 */

Uint32 computeSum (
    Uint32  num2,
    Uint32  num1
)
{
    return ((Uint32) num2 + num1);
}

/*
 * =============================================================================
 *  @func   computeDiff
 *
 *  @arg
 *      NONE
 *
 *  @desc
 *     This is routine computes the difference of the two numbers inputted
 *  
 *  @return
 *      NONE
 * =============================================================================
 */
int computeDiff (
    Uint32  num2,
    Uint32  num1
)
{
    asm (" nop");
    asm (" nop");
    return ((Uint32) (num2 - num1));
}


/*
 * =============================================================================
 *   @func   icache_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the icache module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void icache_error_exit (
    void
)
{
    CSL_icacheClose (hIcache);
}
