/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  Intc_example.c
 *
 *
 *   @desc  Example of using the INTC module CSL
 *
 * =============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows how to use intc csl.
 * =============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows how to test the INTC CSL
 *    	1. Initalize the interrupt required with proper ISR
 *		2. Intilaize the PLLC module
 *		3. Intialize RTI.
 *		4. RTI Compare interrupt0 is intialized to use dispatcher.
		5. RTI Compare interrupt1 is intialized not to use dispatcher.
 *		4. Start the counter
 *		5. Verify interrupts are generated at intervals
 *		7. Stop the counter
 *		8. Close the module
 *==============================================================================
 *      
 *   <b> Test Procedure </b>
 *   @verbatim
  *      1. Configure the CCS setup to work with the emulator being used.
 *         Refer CCS manual for setup configuration
 *       2. Load required GEL file depending on the board used
 *       3. Launch CCS window
 *       4. Open project Intc_example.pjt
 *       5. Build the project and load the .out file of the project.
 *       6. The test can be executed from the main().
 *          
 *   @endverbatim
 *       
 *   
 * =============================================================================
 */ 

/* =============================================================================
 *  Revision History
 *  ===============
 *  09-mar-2005 Ramitha Mathew  File created.
 *
 * =============================================================================
 */

#include "Intc_example.h"



/* Handle for the real time interrupt instance */
static CSL_RtiHandle           	hRti;
/* Handle for the INTC */
static CSL_IntcHandle           hIntc;
/* Handle for the PLLC */
static CSL_PllcHandle           hPllc;

/* Flag indicating execution of ISR */
volatile Uint32        			compInt0Event;
volatile Uint32        			compInt1Event;

/* Variable which checks the test failures */
Uint32  						intcTestFail = 0;


/*
 * =============================================================================
 *   @func   main
 *
 *	 @arg
 *		NONE
 *
 *   @desc
 *     main of test 
 *
 *	 @return
 *		NONE
 *
 * =============================================================================
 */
void main (
	void
)
{
   /* relocating the Interrupt Vector Table */
 	CSL_intcSetVectorPtr(DEST_ADDR);

 	/* This routine illustrates the INTC usage */
	intc_csl_example_Test();

	if (intcTestFail == INTC_TEST_PASSED) {
        printf ("\nIntc CSL Example Test PASSED\n");
    }
    else {
        printf ("\nIntc CSL Example Test FAILED\n");
    }

}

/*
 * =============================================================================
 *   @func   intc_csl_example_Test
 *
 *	 @arg
 *		NONE
 *
 *   @desc
 *     Example test routine which calls test function and intialize ISR 
 *
 *	@return
 *		NONE
 *
 * =============================================================================
 */
void intc_csl_example_Test(
	void
)
{
    /* variables for installing handler for Rti interrupts */
    CSL_IntcObj                   intcObj;    
    CSL_IntcEventEnableState      state;
    CSL_IntcEventHandlerRecord    isrRec;       
    CSL_Status                    status = CSL_SOK;  
    
    /* interrupt variables decalation */
	CSL_IntcDispatcherContext     intcDispatcherContext;
	CSL_IntcContext               intcContext;
    
    /* Enable interface clock to the real time interrupt */
    status = pllcSysClock2Enable ();
    if (status != CSL_SOK) {
        printf ("INTC: clk setup using pllc....failed\n");
        intcTestFail++;
        return;
    }

	memset (&intcContext, 0, sizeof(CSL_IntcContext));
    memset (&intcDispatcherContext, 0, sizeof(CSL_IntcDispatcherContext));
    
    /* Interrupt Initialization */
    status = CSL_intcInit(&intcContext); 
    if (status != CSL_SOK) {
        printf ("INTC: init....failed\n");
        intcTestFail++;
        return;
    }
    
    status = CSL_intcDispatcherInit(&intcDispatcherContext);
    if (status != CSL_SOK) {
        printf ("INTC: intc Dispatcher init....failed\n");
        intcTestFail++;
        return;
    }
    
    /* disabling Global Interrupt */    
    status = CSL_intcGlobalDisable(&state);
    if (status != CSL_SOK) {
        printf ("INTC: intc Global Disable....failed\n");
        intcTestFail++;
        return;
    }
    
    /* Install handler for Rti compare interrupt0 */
    hIntc = CSL_intcOpen(&intcObj, CSL_INTC_EVENTID_RTI_INT_REQ0 , 
                        NULL, &status);
    if ((status != CSL_SOK) || (hIntc == NULL)) {
        printf ("INTC: intc open....failed\n");
        intcTestFail++;
        return;
    }
    
    /* Assigning the ISR */
    isrRec.handler = comp0Isr;
    /* No argument is passed to the ISR */
    isrRec.arg = (void *)0x0; 
    
    CSL_intcPlugEventHandler(hIntc, &isrRec);    
    
    /* Enable the cpu interrupt 4 */
    status = CSL_intcEventEnable(CSL_INTC_EVENTID_RTI_INT_REQ0, &state);
    if (status != CSL_SOK) {
        printf ("INTC: intc event enable....failed\n");
        intcTestFail++;
        intc_error_exit ();
        return;
    }

    /* For Rti compare interrupt1 */
    hIntc = CSL_intcOpen(&intcObj, CSL_INTC_EVENTID_RTI_INT_OVL_REQ   , 
                        NULL, &status);
    if ((status != CSL_SOK) || (hIntc == NULL)) {
        printf ("INTC: intc open....failed\n");
        intcTestFail++;
        intc_error_exit ();
        return;
    }

    /* Directly adding the isr address to the fetch packet */
    status = CSL_intcHookIsr(hIntc->eventId, (Uint32)comp1Isr);
    if (status != CSL_SOK) {
        printf ("INTC: intc Hooking of isr....failed\n");
        intcTestFail++;
        intc_error_exit ();
        return;
    }
    
    /* Enable the cpu interrupt 5 */
    status = CSL_intcEventEnable(CSL_INTC_EVENTID_RTI_INT_OVL_REQ, &state); 
    if (status != CSL_SOK) {
        printf ("INTC: intc event enable....failed\n");
        intcTestFail++;
        intc_error_exit ();
        return;
    }


    /* Enabling non-maskable interrupt */
    status = CSL_intcEventEnable(CSL_INTC_EVENTID_NMI, &state); 
    if (status != CSL_SOK) {
        printf ("INTC: intc nmi event enable....failed\n");
        intcTestFail++;
        intc_error_exit ();
        return;
    }
	
	status = CSL_intcGlobalEnable(&state);
	if (status != CSL_SOK) {
        printf ("INTC: intc global enable....failed\n");
        intcTestFail++;
        intc_error_exit ();
        return;
    }
    
    status = CSL_intcClose (hIntc);   

    
    example_test(1);
    example_test(2);
   

}

/*
 * =============================================================================
 *   @func   example_test
 *
 *   @arg
 *		testNum     - The number of the test to be tested
 *
 *   @desc
 *     Test routine which performs different test depending on the test number
 *
 *   @return
 *      NONE
 *
 * =============================================================================
 */
void example_test (
	Uint16 testNum
)
{
	CSL_RtiObj      	rtiObj;
	CSL_Status      	status = CSL_SOK;
    CSL_RtiHwSetup     	hwSetup= CSL_RTI_HWSETUP_DEFAULTS;
    CSL_RtiHwSetup     	hwSetupRead;
    Uint16				count = 0;
        
    /* clear local data structures */
    memset (&rtiObj, 0, sizeof(CSL_RtiObj));
    memset (&hwSetup, 0, sizeof(CSL_RtiHwSetup));
    memset (&hwSetupRead, 0, sizeof(CSL_RtiHwSetup));
    
    /* Initalize the RTI csl module */
    status = CSL_rtiInit(NULL);
    if (status != CSL_SOK) {
        printf ("INTC: rti init....failed\n");
        intcTestFail++;
        return;
    }
    
    
    /* Open csl module */
    hRti = CSL_rtiOpen(&rtiObj, CSL_RTI, NULL, &status);
    if ((status != CSL_SOK) || (hRti == NULL)) {
        printf ("INTC: rti open....failed\n");
        intcTestFail++;
        return;
    }
    
    
    /* Setup hardware parameters */
    hwSetup.blk0ExtnCntl                    = CSL_RTI_CAPTURE_EVENT_SOURCE1;
    hwSetup.blk1ExtnCntl                    = CSL_RTI_CAPTURE_EVENT_SOURCE1;   
    hwSetup.compareUpCntrs.compareUpCntr0   = UC_COMP_VALUE;   
    hwSetup.compVal.comp0Val                = COMPARE0_VALUE;
    hwSetup.compVal.comp1Val                = COMPARE1_VALUE;
    hwSetup.compVal.comp2Val                = COMPARE2_VALUE;
    hwSetup.compVal.comp3Val                = COMPARE3_VALUE;
    hwSetup.updateCompVal.updateComp0Val    = UPDATECOMPARE_VALUE;
    hwSetup.updateCompVal.updateComp1Val    = UPDATECOMPARE_VALUE;
    hwSetup.updateCompVal.updateComp2Val    = UPDATECOMPARE_VALUE;
    hwSetup.updateCompVal.updateComp3Val    = UPDATECOMPARE_VALUE;   
    hwSetup.preLoadWatchdog                 = PRELOAD_VALUE;
    
	switch (testNum) {
	 	case 1:
	 		/* Enable compIntr0 alone */
			hwSetup.intConfig.compIntr0En = TRUE;
			hwSetup.intConfig.compIntr1En = FALSE;
			hwSetup.intConfig.compIntr2En = FALSE;
			hwSetup.intConfig.compIntr3En = FALSE;
	    	break;
	    	
		case 2:
			/* Enable compIntr1 alone */
			hwSetup.intConfig.compIntr0En = FALSE;
			hwSetup.intConfig.compIntr1En = TRUE;
			hwSetup.intConfig.compIntr2En = FALSE;
			hwSetup.intConfig.compIntr3En = FALSE;
			break;      
       
    }

    /* Stop Rti Block0 counters */
    status = CSL_rtiHwControl (hRti, CSL_RTI_CMD_STOP_BLOCK0, NULL);
    if (status != CSL_SOK) {
        printf ("INTC: rti stop blk cmd....failed\n");
        intcTestFail++;
        rti_error_exit ();
        return;
    }
    
    /* Setup rti module */
    status = CSL_rtiHwSetup (hRti, &hwSetup);
    if (status != CSL_SOK) {
        printf ("INTC: rti hwsetup....failed\n");
        intcTestFail++;
        rti_error_exit ();
        return;
    }


   
    /* verify the hwsetup configuration */
    status = CSL_rtiGetHwSetup(hRti, &hwSetupRead);
    if (status != CSL_SOK) {
        printf ("INTC: rti getHwsetup....failed\n");
        intcTestFail++;
        rti_error_exit ();
        return;
    }
    
    /* Start Rti Block0 counters */
    status = CSL_rtiHwControl (hRti, CSL_RTI_CMD_START_BLOCK0, NULL);
    if (status != CSL_SOK) {
        intcTestFail++;
        printf ("INTC: rti start blk cmd....failed\n");
        rti_error_exit ();
        return;
    }
    
	
	switch (testNum) {
		case 1:	
    		/* check for periodic compare interrupt0 generation */
            compInt0Event = FALSE;
            for (count = 5; count != 0; count--) {
                /* Waiting for the interrupt */
                while (compInt0Event != TRUE);            
                printf ("INTC: RTI compare interrupt0 generated \n");
                    
                compInt0Event = FALSE;
            }
            break;

		case 2:
			/* check for periodic compare interrupt1 generation */
            compInt1Event = FALSE;
            for (count = 5; count != 0; count--) {
                /* Waiting for the interrupt */
                while (compInt1Event != TRUE);
                printf ("INTC: RTI compare interrupt1 generated \n");
                compInt1Event = FALSE;
            }
            break;
	}

   /* stop counter */
    status = CSL_rtiHwControl (hRti, CSL_RTI_CMD_STOP_BLOCK0, NULL);
    if (status != CSL_SOK) {
        intcTestFail++;
        printf ("INTC: RTI rti stop blk0 cmd....failed\n");
        rti_error_exit ();
        return;
    }

   
    status = CSL_rtiClose(hRti);
        
    return;
} 

/*
 * =============================================================================
 *   @func   pllcSysClock2Enable
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function enables the input clock to the RTI
 *     
 *   @return
 *      status
 *
 * =============================================================================
 */

CSL_Status pllcSysClock2Enable (
    void
)
{	
    CSL_PllcObj              pllcObj;
    CSL_PllcHwSetup      	 hwSetup;
    CSL_Status               status = CSL_SOK;
        
    /* Initialize the pllc CSL module */
    status = CSL_pllcInit(NULL);
    if (status != CSL_SOK) {
        printf ("INTC: pllc init...Failed.\n");
        pllc_error_exit ();
        return status;
    }


    /* Open the pllc CSL module */
    hPllc = CSL_pllcOpen (&pllcObj, CSL_PLLC, NULL, &status);
    if (status != CSL_SOK || hPllc == NULL) {
        printf ("INTC: PLLC Open... Failed\n");
        pllc_error_exit ();
        return status;
	}
            
    /* setup pllc hardware parameters */
    hwSetup.pllcMode = CSL_PLLC_BYPASS;
    /* divider 2 is enabled */
	hwSetup.div2Enable.divEnable = CSL_PLLC_PLLDIV_ENABLE;  
	/* divider 2 ratio set to divide by 4 */
    hwSetup.div2Enable.pllDivRatio   = CSL_PLLC_DIV3;  
        
    /* pllc setup */
    status = CSL_pllcHwSetup(hPllc, &hwSetup);
    if (status != CSL_SOK) {
        printf ("INTC: PLLC HwSetup... Failed\n");
        pllc_error_exit ();
        return status;
    }
              
    /* Check closing the module */
    status = CSL_pllcClose (hPllc);

    return status;
}   


/*
 * =============================================================================
 *   @func   comp0Isr
 *
 *   @arg
 *		NONE
 *
 *   @desc
 *     This is the ISR comp0Isr used for verifying Compare interrupt 0
 *
 *   @return
 *		NONE
 *
 * =============================================================================
 */
void comp0Isr ()
{
    Bool          intEvent;
    CSL_Status    status;
    
    /* To remove warnings */
    status = status;
    
    /* Read the interrupt flag register */
    status = CSL_rtiGetHwStatus (hRti, CSL_RTI_QUERY_INT0_STATUS, &intEvent);
    if (intEvent == TRUE) {
        compInt0Event = TRUE;  
    }  
      
    /* Clear the interrupt */
    status = CSL_rtiHwControl (hRti, CSL_RTI_CMD_CLEAR_INT0, &intEvent);
}

/*
 * =============================================================================
 *   @func   comp1Isr
 *
 *   @arg
 *		NONE
 *
 *   @desc
 *     This is the ISR comp1Isr used for verifying Compare interrupt1
 *
 *   @return
 *		NONE 
 *
 * =============================================================================
 */
interrupt void comp1Isr ()    
{
    Bool          intEvent;
    CSL_Status    status;
    
    /* To remove warnings */
    status = status;
    
    /* Read the interrupt flag register */
    status = CSL_rtiGetHwStatus (hRti, CSL_RTI_QUERY_INT1_STATUS, &intEvent);
    
    if (intEvent == TRUE) {
        compInt1Event = TRUE;  
    }    
    
    /* Clear the interrupt */
    status = CSL_rtiHwControl (hRti, CSL_RTI_CMD_CLEAR_INT1, &intEvent);
}


/*
 * =============================================================================
 *   @func   rti_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the rti module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void rti_error_exit (
    void
)
{
    CSL_rtiClose (hRti);
}


/*
 * =============================================================================
 *   @func   pllc_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the pllc module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void pllc_error_exit (
    void
)
{
    CSL_pllcClose (hPllc);
}


/*
 * =============================================================================
 *   @func   intc_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the intc module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void intc_error_exit (
    void
)
{
    CSL_intcClose (hIntc);
}
