/*  ============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_dmaxGetBaseAddress.c
 *
 *    @brief File for functional layer of CSL API @a CSL_dmaxGetBaseAddress()
 *
 *  Description
 *    - The @a CSL_dmaxGetBaseAddress() function definition & it's associated functions
 *
 *  Modification 1
 *    - Modified on: 10/03/2005
 *    - Reason: created the sources
 * 
 *    @author asr.

 *
 */


#include <soc.h>
#include <csl_dmax.h>

/** ============================================================================
 *   @n@b CSL_dmaxGetBaseAddress
 *
 *   @b Description
 *   @n  Function to get the base address of the peripheral instance.
 *       This function is used for getting the base address of the peripheral
 *       instance. This function will be called inside the CSL_dmaxOpen()
 *       function call. This function is open for re-implementing if the user 
 *		 wants to modify the base address of the peripheral object to point to 
 *		 a different location and there by allow CSL initiated write/reads into 
 *		 peripheral MMRss go to an alternate location.
 *
 *   @b Arguments
 *   @verbatim
 
            dmaxNum        Specifies the instance of the DMAX to be opened.
            pDmaxParam     Module specific parameters.   
            pBaseAddress   Pointer to baseaddress structure containing base
                           address details.

     @endverbatim
 *
 *   <b> Return Value </b> CSL_Status
 *   @li                   CSL_OK              Open call is successful
 *   @li                   CSL_ESYS_FAIL       The instance number is invalid.
 *   @li                   CSL_ESYS_INVPARAMS  Invalid parameter 
 *                     
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  Base Address structure is populated
 *
 *   @b Modifies
 *   @n    1. The status variable  
 *         2. Base address structure is modified.
 *
 *   @b Example
 *   @verbatim
        CSL_Status           status;
        CSL_DmaxBaseAddress  baseAddress;

       ...
      status = CSL_dmaxGetBaseAddress(CSL_DMAX_0, NULL, &baseAddress);

    @endverbatim
 * ===========================================================================
 */

#pragma CODE_SECTION (CSL_dmaxGetBaseAddress, ".text:csl_section:dmax");

CSL_Status CSL_dmaxGetBaseAddress (
    CSL_InstNum         dmaxNum,
    CSL_DmaxParam       *pDmaxParam,
    CSL_DmaxBaseAddress *pBaseAddress
)
{

    CSL_Status               status = CSL_SOK;

    /* To avoid compiler warning/remark */
    pDmaxParam = pDmaxParam;

    if (pBaseAddress == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }

    switch (dmaxNum) {
    case CSL_DMAX:
        pBaseAddress->regs = (CSL_DmaxRegsOvly) CSL_DMAX_0_REGS;
        break;

    default:
        pBaseAddress->regs = NULL;
        status = CSL_ESYS_FAIL;
    }
    return status;
}
