/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_emifGetBaseAddress.c
 *
 *  @path $(CSLPATH)\emif\src\csl_emifGetBaseAddress.c
 *
 *  @brief File for functional layer of CSL API @a CSL_emifGetBaseAddress()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  10-Sep-2004 author File Created.
 * =============================================================================
 */

#include <soc.h>
#include <csl_emif.h>

/** ============================================================================
 *   @n@b CSL_emifGetBaseAddress
 *
 *   @b Description
 *   @n This function to get the base address of the EMIF instance. 
 *
 *   @b Arguments
 *   @verbatim
            emifNum			Instance number of the EMIF

			pEmifParam		Module specific parameters.

			pBaseAddress	Pointer to base address structure

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li   	CSL_SOK 		    - Successfully retrieved base address.
 *   @li    CSL_ESYS_FAIL     	- Failed to get the base address
 *	 @li 	CSL_ESYS_INVPARAMS  - If the input parameter is not valid
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  Gets the base address of EMIF
 *
 *   @b Modifies
 *   @n The base address is populated in the base address structure
 *
 *   @b Example
 *   @verbatim
		CSL_status			status;
		CSL_EmifParam 		emifParam;
		CSL_EmifBaseAddress baseAddress;
		. .
		status = CSL_emifGetBaseAddress (CSL_EMIF, &emifParam, &baseAddress);
		. .     
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_emifGetBaseAddress, ".text:csl_section:emif");
CSL_Status CSL_emifGetBaseAddress (
    /*
     * Instance number
     */
    CSL_InstNum emifNum,
    /*
     * Module specific parameters
     */
    CSL_EmifParam * pEmifParam,
    /*
     * Base address details
     */
    CSL_EmifBaseAddress * pBaseAddress
)
{
    CSL_Status               status = CSL_SOK;

    /* Added the following code to validate for input arguments */
    if (pBaseAddress == NULL) {
        return CSL_ESYS_INVPARAMS;
    }
    
    switch (emifNum) {
        case CSL_EMIF:
            pBaseAddress->regs = (CSL_EmifRegsOvly) CSL_EMIF_0_REGS;
            break;

        default:
            pBaseAddress->regs = (CSL_EmifRegsOvly) NULL;
            pEmifParam = pEmifParam;
            status = CSL_ESYS_FAIL;
            break;
    }

    return status;
}
