/*  ============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_i2cGetBaseAddress.c
 *
 *    @brief File for functional layer of CSL API @a CSL_i2cGetBaseAddress()
 *
 *  Description
 *    - The @a CSL_i2cGetBaseAddress() function definition & it's associated 
 *      functions
 *
 *  Modification 1
 *    - Modified on: 18/1/2005
 *    - Reason: created the sources
 * 
 *    @author Ramitha Mathew.

 *
 */


#include <soc.h>
#include <csl_i2c.h>

/** ============================================================================
 *   @n@b CSL_i2cGetBaseAddress
 *
 *   @b Description
 *   @n  Function to get the base address of the peripheral instance.
 *       This function is used for getting the base address of the peripheral
 *       instance. This function will be called inside the CSL_i2cOpen()
 *       function call. 
 *
 *   @b Arguments
 *   @verbatim
 
            i2cNum        Specifies the instance of the I2C to be opened.
            pI2cParam     Module specific parameters.   
            pBaseAddress  Pointer to baseaddress structure containing base
                          address details.

     @endverbatim
 *
 *   <b> Return Value </b> CSL_Status
 *   @li                   CSL_OK              Open call is successful
 *   @li                   CSL_ESYS_FAIL       The instance number is invalid.
 *   @li                   CSL_ESYS_INVPARAMS  Invalid parameter 
 *                     
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  Base Address structure is populated
 *
 *   @b Modifies
 *   @n    1. The status variable  
 *         2. Base address structure is modified.
 *
 *   @b Example
 *   @verbatim
        CSL_Status          status;
        CSL_I2cBaseAddress  baseAddress;

       ...
      status = CSL_i2cGetBaseAddress (CSL_I2C_0, NULL, &baseAddress);

    @endverbatim
 * ===========================================================================
 */

#pragma CODE_SECTION (CSL_i2cGetBaseAddress, ".text:csl_section:i2c");

CSL_Status CSL_i2cGetBaseAddress (
    CSL_InstNum         i2cNum,
    CSL_I2cParam        *pI2cParam,
    CSL_I2cBaseAddress  *pBaseAddress
)
{

    CSL_Status      status = CSL_SOK;

    /* To avoid compiler warning/remark */
    pI2cParam = pI2cParam;

    if (pBaseAddress == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }

    switch (i2cNum) {

        case CSL_I2C_0:
            pBaseAddress->regs = (CSL_I2cRegsOvly) CSL_I2C_0_REGS;
            break;
    
        case CSL_I2C_1:
            pBaseAddress->regs = (CSL_I2cRegsOvly) CSL_I2C_1_REGS;
            break;
    
        default:
            pBaseAddress->regs = NULL;
            status = CSL_ESYS_FAIL;
    }
    return status;
}
