/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */
/*  ============================================================================
 *   @file  csl_icacheGetBaseAddress.c
 *
 *   @path  $(CSLPATH)\soc\C67\src
 *
 *   @desc  L1P I-cache CSL implementation o get the base address 
 *          icache registers
 *  ============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 Ramitha Mathew File Created.
 *
 * =============================================================================
 */

#include <soc.h>
#include <csl_icache.h>
#include <cslr_icache.h>

/* =============================================================================
 *   @n@b CSL_icacheGetBaseAddress
 *
 *   @b Description
 *   @n  Function to get the base address of the peripheral, icache instance.
 *       This function is used for getting the base address of the peripheral
 *       instance. This function will be called inside the CSL_icacheOpen()
 *       function call.
 *
 *   @b Arguments
 *   @verbatim      
            icacheNum        Specifies the instance of the Icache to be opened 
            picacheParam     Module specific parameters 
            pBaseAddress     Pointer to baseaddress structure containing base 
                             address details.
            
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_OK            Open call is successful
 *   @li                    CSL_ESYS_FAIL     The instance number is invalid.
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  Base Address structure is populated
 *
 *   @b Modifies
 *   @n    1. The status variable
 *
 *         2. Base address structure is modified.
 *
 *   @b Example
 *   @verbatim
        CSL_Status               status;
        CSL_IcacheBaseAddress    baseAddress;

        ...
        status = CSL_icacheGetBaseAddress (CSL_ICACHE, NULL, &baseAddress);

    @endverbatim
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_icacheGetBaseAddress, ".text:csl_section:icache");

CSL_Status CSL_icacheGetBaseAddress (
    CSL_InstNum             icacheNum,
    CSL_IcacheParam         *pIcacheParam,
    CSL_IcacheBaseAddress   *pBaseAddress
)
{
    CSL_Status      status = CSL_SOK;

    /* Added to  remove warning */
    pIcacheParam = pIcacheParam;
    
    if (pBaseAddress == NULL)
        return CSL_ESYS_INVPARAMS;

    switch (icacheNum) {
        case CSL_ICACHE:
            pBaseAddress->regs = (CSL_IcacheRegsOvly) CSL_ICACHE_0_REGS;
            break;
    
        default:            
            pBaseAddress->regs = (CSL_IcacheRegsOvly) NULL;
            status = CSL_ESYS_FAIL;
            break;
    }

    
    return status;
}
