/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file csl_rtiGetBaseAddress.c
 *
 *   @path  $(CSLPATH)\soc\C67\src
 *
 *   @desc  Real time interrupt CSL implementation to get the base address 
 *          rti registers
 *
 */


/* =============================================================================
 *  Revision History
 *  ===============
 *  1-Dec-2004 Sd File Created.
 *
 * =============================================================================
 */

#include <soc.h>
#include <csl_rti.h>

/** ============================================================================
 *   @n@b CSL_rtiGetBaseAddress
 *
 *   @b Description
 *   @n  Function to get the base address of the peripheral instance.
 *       This function is used for getting the base address of the peripheral
 *       instance. This function will be called inside the CSL_rtiOpen()
 *       function call.This function is open for re-implementing if the user 
 *       wants to modify the base address of the peripheral object to point to
 *       a different location and there by allow CSL initiated write/reads into
 *       peripheral MMR's go to an alternate location. 
 *
 *   @b Arguments
 *   @verbatim      
            rtiNum          Specifies the instance of the RTI to be opened.
 
            pRtiParam       Module specific parameters.
 
            pBaseAddress    Pointer to baseaddress structure containing base 
                            address details.
            
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_OK            Open call is successful
 *   @li                    CSL_ESYS_FAIL     The instance number is invalid.
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  Base Address structure is populated
 *
 *   @b Modifies
 *   @n    1. The status variable
 *
 *         2. Base address structure is modified.
 *
 *   @b Example
 *   @verbatim
        CSL_Status              status;
        CSL_RtiBaseAddress      baseAddress;

       ...
      status = CSL_rtiGetBaseAddress (CSL_RTI, NULL, &baseAddress);

    @endverbatim
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_rtiGetBaseAddress, ".text:csl_section:rti");
CSL_Status CSL_rtiGetBaseAddress (
    CSL_InstNum         rtiNum,
    CSL_RtiParam        *pRtiParam,
    CSL_RtiBaseAddress  *pBaseAddress
)
{
    CSL_Status      status = CSL_SOK;

    if (pBaseAddress == NULL)
        return CSL_ESYS_INVPARAMS;

    switch (rtiNum) {
        case CSL_RTI:
            pBaseAddress->regs = (CSL_RtiRegsOvly) CSL_RTI_0_REGS;
            break;
    
        default:
            pRtiParam = pRtiParam;
            pBaseAddress->regs = (CSL_RtiRegsOvly) NULL;
            status = CSL_ESYS_FAIL;
            break;
    }

    return status;
}
