/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_spiGetBaseAddress.c
 *
 *  @path $(CSLPATH)\spi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_spiGetBaseAddress()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  25-Jan-2005 GaneshK File Created.
 * =============================================================================
 */

#include <csl_spi.h>

/** ===========================================================================
 *   @n@b CSL_spiGetBaseAddress
 *
 *   @b Description
 *   @n  Function to get the base address of the peripheral instance.
 *       This function is used for getting the base address of the peripheral
 *       instance. This function will be called inside the CSL_spiOpen()
 *       function call. This function is open for re-implementing if the user
 *       wants to modify the base address of the peripheral object to point to
 *       a different location and there by allow CSL initiated write/reads into
 *       peripheral MMR's go to an alternate location.
 *
 *   @b Arguments
 *   @verbatim
            spiNum          Specifies the instance of SPI to be opened.

            pSpiParam       Module specific parameters.

            pBaseAddress    Pointer to baseaddress structure containing base
                            address details.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_OK             Open call is successful
 *   @li                    CSL_ESYS_FAIL      The instance number is invalid.
 *	 @li					CSL_ESYS_INVPARAMS Invalid Parameters passed
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  Base Address structure is populated
 *
 *   @b Modifies
 *   @n    1. The status variable
 *
 *         2. Base address structure is modified.
 *
 *   @b Example
 *   @verbatim
        CSL_Status              status;
        CSL_SpiBaseAddress  baseAddress;

       ...
      status = CSL_spiGetBaseAddress(CSL_SPI_0, NULL, &baseAddress);

    @endverbatim
 * ============================================================================
 */
#pragma CODE_SECTION (CSL_spiGetBaseAddress, ".text:csl_section:spi");
CSL_Status CSL_spiGetBaseAddress (
    CSL_InstNum spiNum,
    CSL_SpiParam * pSpiParam,
    CSL_SpiBaseAddress * pBaseAddress
)
{
    CSL_Status               status = CSL_SOK;

    pSpiParam = pSpiParam;

    if (pBaseAddress == NULL) {
        return CSL_ESYS_INVPARAMS;
    }

    switch (spiNum) {
        case CSL_SPI_0:
            pBaseAddress->regs = (CSL_SpiRegsOvly) CSL_SPI_0_REGS;
            break;
        case CSL_SPI_1:
            pBaseAddress->regs = (CSL_SpiRegsOvly) CSL_SPI_1_REGS;
            break;
        default:
            pBaseAddress->regs = NULL;
            status = CSL_ESYS_FAIL;
    }
    return status;
}
