/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_uhpiGetBaseAddress.c
 *
 *  @path $(CSLPATH)\uhpi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_uhpiGetBaseAddress()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 asr author File Created.
 * =============================================================================
 */

#include <soc.h>
#include <csl_uhpi.h>

/** ============================================================================
 *   @n@b CSL_uhpiGetBaseAddress
 *
 *   @b Description
 *   @n  Function to get the base address of the peripheral instance.
 *       This function is used for getting the base address of the peripheral
 *       instance. This function will be called inside the CSL_uhpiOpen()
 *       function call. This function is open for re-implementing if the user
 *       wants to modify the base address of the peripheral object to point to
 *       a different location and there by allow CSL initiated write/reads into
 *       peripheral. MMR's go to an alternate location.
 *
 *   @b Arguments
 *   @verbatim
            uhpiNum      	Specifies the instance of the uhpi to be opened

            pUhpiParam   	Module specific parameters.

            pBaseAddress    Pointer to base address structure containing base
                            address details.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_OK              Open call is successful
 *   @li                    CSL_ESYS_FAIL       The instance number is invalid.
 *   @li                    CSL_ESYS_INVPARAMS  Invalid parameter 
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  Base address structure is populated
 *
 *   @b Modifies
 *   @n    1. The status variable
 *
 *         2. Base address structure is modified.
 *
 *   @b Example
 *   @verbatim
        CSL_Status              status;
        CSL_UhpiBaseAddress  baseAddress;

        ...

        status = CSL_uhpiGetBaseAddress(CSL_UHPI_0, NULL,
                                           &baseAddress);
        ...

    @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_uhpiGetBaseAddress, ".text:csl_section:uhpi");
CSL_Status CSL_uhpiGetBaseAddress (
    CSL_InstNum         uhpiNum,
    CSL_UhpiParam       *pUhpiParam,
    CSL_UhpiBaseAddress *pBaseAddress
)
{
    CSL_Status               status = CSL_SOK;

    if (pBaseAddress == NULL) {
        return CSL_ESYS_INVPARAMS;
    }

    switch (uhpiNum) {
    case CSL_UHPI:
        pBaseAddress->regs = (CSL_UhpiRegsOvly) CSL_UHPI_0_REGS;
        break;

    default:
        pBaseAddress->regs = (CSL_UhpiRegsOvly) NULL;
        pUhpiParam = pUhpiParam;
        status = CSL_ESYS_FAIL;
        break;
    }

    return status;
}
