/*  ============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_dmaxHwSetup1dParam.c
 *
 *  @brief File for functional layer of CSL API @a CSL_dmaxHwSetup1dParam()
 *
 *  Description
 *    - The @a CSL_dmaxHwSetup1dParam() function definition & it's associated
 *      functions
 *
 *  Created on: 06 July 2007
 *    - Reason: implementing the additional features ( 1d Burst Transfer)
 * 
 *  @author KNG.
 */

#include <csl_dmax.h>
/** =======================================================================
 *   @n@b CSL_dmaxHwSetup1dParam
 *
 *   @b Description
 *   @n This function initializes the device registers with the appropriate
 *      values provided through the HwSetup Data structure. After the 
 *      Setup is completed, the device is ready for  operation.      
 *      For information passed through the HwSetup Data structure refer
 *   @a CSL_dmaxHwSetup.
 *
 *   @b Arguments
 *   @verbatim
 *    
 *          paramEntry  Pointer to Prameter Table Entry where data is to be 
 *						stored
 *          setup  		Pointer to a dmax 1d Transfer Setup Object
 *           
 *   @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Successful completion of hardware     
 *                                    setup
 *   @li                    CSL_ESYS_ INVPARAMS - Hardware structure is not 
 *                                    properly initialized
 *   @li                    CSL_ESYS_ BADHANDLE - Invalid CSL handle
 *
 *
 *   <b> Pre Condition </b>
 *   @n  Both CSL_dmaxInit() and a CSL_dmaxOpen() must be called
 *
 *   <b> Post Condition </b>
 *   @n  DMAX registers are configured 
 *
 *   @b  Modifies
 *   @n  DMAX registers
 *
 *   @b Example
 *   @verbatim  
      CSL_DmaxParameterEntry 	paramEntry;
      CSL_dmaxHwSetup 			hwSetup;
      
      hwSetup.linearReload0  = 0x10000100;
      .
      .
      hwSetup.count0         = 3;
    
      CSL_dmaxHwSetup1dXFRParameterEntry(hDmax, &hwSetup);
     @endverbatim
 * 
 * ============================================================================
 */
#pragma CODE_SECTION \
    (CSL_dmaxSetup1dXFRParameterEntry, ".text:csl_section:dmax");
CSL_Status CSL_dmaxSetup1dXFRParameterEntry (
    CSL_DmaxParameterEntry 		*paramEntry,
    CSL_Dmax1dParameterSetup	*setup
)
{
    Uint32		*tmpPtr = (Uint32 *) paramEntry;

    /*
     * the linearReload0 address value copied into BOTH 
     * the reload address register AND the active address 
     * register.
     */
    tmpPtr[0] = (CSL_FMKR(31,24,setup->event) | CSL_FMKR(23,16,setup->tcc) |
                CSL_FMKR(7,4,setup->nburst) | CSL_FMKR(0,0,setup->tcint));
    tmpPtr[1] = setup->srcAddr;
    tmpPtr[2] = setup->dstAddr;
    tmpPtr[3] = (CSL_FMKR(23,16,setup->burstlen) | CSL_FMKR(15,0,setup->count)); 

    return CSL_SOK;
}
