/*  ============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_dmaxHwSetup.c
 *
 *  @brief File for functional layer of CSL API @a CSL_dmaxSetupFifoDesc()
 *
 *  Description
 *    - The @a CSL_dmaxSetupFifoDesc() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Modified on: 11/March/2005
 *    - Reason: created the sources
 * 
 *  @author asr.
 */

#include <csl_dmax.h>
/** =======================================================================
 *   @n@b CSL_dmaxSetupFifoDesc
 *
 *   @b Description
 *   @n This function formats a FIFO Descriptor object.
 *   @a CSL_dmaxSetupFifoDesc.
 *
 *   @b Arguments
 *   @verbatim
 *    
 *          fifoObj   	Pointer to data area in RAM where descriptor is to be stored.
 *
 *          setup  		Pointer to a dMax FIFO descriptor Object.
 *           
 *   @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Successful completion of hardware     
 *                                    setup
 *   @li                    CSL_ESYS_ INVPARAMS - Hardware structure is not properly 
 *                                    initialized
 *   @li                    CSL_ESYS_ BADHANDLE - Invalid CSL handle
 *
 *
 *   <b> Pre Condition </b>
 *   @n  Both CSL_dmaxInit() and a CSL_dmaxOpen() must be called
 *
 *   <b> Post Condition </b>
 *   @n  DMAX registers are configured 
 *
 *   @b  Modifies
 *   @n  DMAX registers
 *
 *   @b Example
 *   @verbatim  
      CSL_DmaxFifoDescriptor		fifoObj;
      CSL_DmaxFifoDescriptorSetup	setup;
            
    setup.fifoBaseAddr		= 0x20000100;
    .
    .
    setup.wPtr				= 0x10000000;
    
      CSL_dmaxSetupFifoDesc(&fifoObj, &setup);
     @endverbatim
 * 
 * ============================================================================
 */

#pragma CODE_SECTION (CSL_dmaxSetupFifoDesc, ".text:csl_section:dmax");

CSL_Status CSL_dmaxSetupFifoDesc (
    CSL_DmaxFifoDescriptor 		*fifoObj,
    CSL_DmaxFifoDescriptorSetup *setup
)
{
    CSL_Status	st;
    Uint32		*tmpPtr = (Uint32 *) fifoObj;

    if ((fifoObj != NULL) && (setup != NULL)) {
        tmpPtr[0] = setup->fifoBaseAddr;
        tmpPtr[1] = setup->wPtr;
        tmpPtr[2] = setup->fifoSize |
            			CSL_FMK (DMAX_FIFODESC_ESIZE, setup->esize);
        tmpPtr[3] = setup->rPtr;
        tmpPtr[4] = setup->fMark | CSL_FMK (DMAX_FIFODESC_FMSC, setup->fmsc);
        tmpPtr[5] = setup->eMark | CSL_FMK (DMAX_FIFODESC_EMSC, setup->emsc);
        tmpPtr[6] = 0;
        st = CSL_SOK;
    }
    else {
        st = CSL_ESYS_BADHANDLE;
    }
    return st;
}
