/*  ===========================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_dmaxStartAsyncTransferMulti.c
 *
 *  @brief  File for functional layer of CSL API 
 *					@a CSL_dmaxStartAsyncTransferMulti()
 *
 *  Description
 *    - The @a CSL_dmaxStartAsyncTransferMulti() function definition & it's 
 *			associated functions
 *
 *  Modification 1
 *    - Modified on: 11/Mar/2005
 *    - Reason: created the sources
 * 
 *  @author asr.
 */


#include <csl_dmax.h>
/** ===========================================================================
 *   @n@b CSL_dmaxStartAsyncTransferMulti
 *
 *   @b Description
 *   @n This function initiates dMax data transfer by toggling the appropriate 
 *      bit in the ESR(Event Set Register) register for multiple events.
 *   @a CSL_dmaxStartAsyncTransferMulti.
 *
 *   @b Arguments
 *   @verbatim
 *    
 *          hDmax   		Pointer to the dMax Handle Instance
 *           
 *   @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Successful completion
 *   @li                    CSL_EDMAX_BAD_ESR_FLAG - Bad ESR Flag
 *   @li                    CSL_ESYS_ BADHANDLE - Invalid CSL handle
 *
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  DMAX registers are configured 
 *
 *   @b  Modifies
 *   @n  DMAX registers
 *
 *   @b Example
 *   @verbatim  
 *     CSL_DmaxHandle			*hDmax;
 *           
 *     CSL_dmaxStartAsyncTransferMulti(hDmax);
 *    @endverbatim
 * 
 * ============================================================================
 */
CSL_Status CSL_dmaxStartAsyncTransferMulti (
    CSL_DmaxHandle 	*hDmax
)
{
    Uint16			flag;
    Uint32			mask, trigger_mask, end_mask;
    Uint32			polarity;
    CSL_Status		status;
    CSL_DmaxHandle	evHandle;

    status = CSL_SOK;

    mask = 0;
    trigger_mask = 0;
    end_mask = 0;

    while (*hDmax != 0) {
        evHandle = *hDmax;
        if ((Int) evHandle != CSL_ESYS_BADHANDLE) {
            flag = ((evHandle->eventUid) >> 16) & 0x00FF;

            if (flag != CSL_DMAX_BAD_ESR_FLAG) {
                mask |= 1u << flag;
                polarity = (evHandle->regs->DEPR) & (1u << flag);
                trigger_mask |= (~polarity) & mask;
            }
            else {
                status = CSL_EDMAX_BAD_ESR_FLAG;
            }
        }
        else {
            status = CSL_ESYS_BADHANDLE;
        }
        ++hDmax;
    }

    end_mask = (~trigger_mask) & mask;
    if (status == CSL_SOK) {
        CSL_dmaxSetDetr (trigger_mask);
        CSL_dmaxSetDetr (end_mask);
    }
    return status;
}
