/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_emifGetHwSetup.c
 *
 *  @path $(CSLPATH)\emif\src\csl_emifGetHwSetup.c
 *
 *  @brief File for functional layer of CSL API @a CSL_emifGetHwSetup()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  10-Sep-2004 author File Created.
 * =============================================================================
 */

#include <csl_emif.h>

/** ============================================================================
 *   @n@b CSL_emifGetHwSetup
 *
 *   @b Description
 *   @n It retrives the hardware setup parameters of the emif
 *      specified by the given handle.
 *
 *   @b Arguments
 *   @verbatim
            hEmif        Handle to the emif
 
            setup         Pointer to the harware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Retrieving the hardware setup
 *                                                parameters is successful
 *   @li                    CSL_ESYS_BADHANDLE  - The handle is passed is
 *                                                invalid
 *   @li                    CSL_ESYS_INVPARAMS  - Invalid parameter
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  The hardware setup structure is populated with the hardware setup
 *       parameters
 *
 *   @b Modifies
 *   @n hwSetup variable
 *
 *   @b Example
 *   @verbatim
            CSL_EmifHandle   hEmif;
            CSL_EmifHwSetup  hwSetup;

            ...
            
            status = CSL_emifGetHwSetup(hEmif, &hwSetup);
            
            ...
            
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_emifGetHwSetup, ".text:csl_section:emif");
CSL_Status CSL_emifGetHwSetup (
    /*
     * Pointer to the object that holds reference to the
     * instance of EMIF requested after the call 
     */
    CSL_EmifHandle hEmif,
    /*
     * The query to this API which indicates the status/setup
     * to be returned 
     */
    CSL_EmifHwSetup * setup
)
{

    if (hEmif == NULL) {
        return CSL_ESYS_BADHANDLE;
    }

    if (setup == NULL) {
        return CSL_ESYS_INVPARAMS;
    }

#if (EMIF_WIDTH == EMIF_32BIT_SUPPORT)
    /* Read max external wait configuration */
    setup->maxExtWait = (Uint8) CSL_FEXT (hEmif->regs->AWCCR, EMIF_AWCCR_MEWC);
    /* Read wait polarity Configuration */
    setup->waitPolarityCfg =
        (CSL_EmifWaitPolarity) CSL_FEXT (hEmif->regs->AWCCR, EMIF_AWCCR_WP0);
#endif

    /* Read back the self refresh state */
    setup->sdramSelfRefreshEn = CSL_FEXT (hEmif->regs->SDCR, EMIF_SDCR_SR);
    /* Read SDRAM data access mode */
    setup->narrowMode = (CSL_EmifNarrowMode) CSL_FEXT (hEmif->regs->SDCR,
        EMIF_SDCR_NM);
    /* Read Latency configuration */
    setup->sdramCasLaten =
        (CSL_EmifSdramCasLatency) CSL_FEXT (hEmif->regs->SDCR, EMIF_SDCR_CL);
    /* Read Internal Bank configuration */
    setup->sdramIntBankSetup =
        (CSL_EmifSdramInternalBankSetUp) CSL_FEXT (hEmif->regs->SDCR,
        EMIF_SDCR_IBANK);
    /* Read back the SDRAM page size */
    setup->sdramPageSize = (CSL_EmifSdramPageSize) CSL_FEXT (hEmif->regs->SDCR,
        EMIF_SDCR_PAGESIZE);

    /*Read SDRAM refresh rate */
    setup->refreshRate = (Uint16) CSL_FEXT (hEmif->regs->SDRCR, EMIF_SDRCR_RR);

    /* Read Async Bank configs */
    setup->asyncBankCfg1.ss = (Bool) CSL_FEXT (hEmif->regs->A1CR, EMIF_A1CR_SS);
    setup->asyncBankCfg1.ew = (Bool) CSL_FEXT (hEmif->regs->A1CR, EMIF_A1CR_EW);
    setup->asyncBankCfg1.w_setup = (Uint8) CSL_FEXT (hEmif->regs->A1CR,
        EMIF_A1CR_W_SETUP);
    setup->asyncBankCfg1.w_strobe = (Uint8) CSL_FEXT (hEmif->regs->A1CR,
        EMIF_A1CR_W_STROBE);
    setup->asyncBankCfg1.w_hold = (Uint8) CSL_FEXT (hEmif->regs->A1CR,
        EMIF_A1CR_W_HOLD);
    setup->asyncBankCfg1.r_setup = (Uint8) CSL_FEXT (hEmif->regs->A1CR,
        EMIF_A1CR_R_SETUP);
    setup->asyncBankCfg1.r_strobe = (Uint8) CSL_FEXT (hEmif->regs->A1CR,
        EMIF_A1CR_R_STROBE);
    setup->asyncBankCfg1.r_hold = (Uint8) CSL_FEXT (hEmif->regs->A1CR,
        EMIF_A1CR_R_HOLD);
    setup->asyncBankCfg1.ta = (Uint8) CSL_FEXT (hEmif->regs->A1CR,
        EMIF_A1CR_TA);
    setup->asyncBankCfg1.asize = (Uint8) CSL_FEXT (hEmif->regs->A1CR,
        EMIF_A1CR_ASIZE);

    /* Read from SDTIMR register */
    setup->emClkCycles.trfc = (Uint8) CSL_FEXT (hEmif->regs->SDTIMR,
        EMIF_SDTIMR_T_RFC);
    setup->emClkCycles.trp = (Uint8) CSL_FEXT (hEmif->regs->SDTIMR,
        EMIF_SDTIMR_T_RP);
    setup->emClkCycles.trcd = (Uint8) CSL_FEXT (hEmif->regs->SDTIMR,
        EMIF_SDTIMR_T_RCD);
    setup->emClkCycles.twr = (Uint8) CSL_FEXT (hEmif->regs->SDTIMR,
        EMIF_SDTIMR_T_WR);
    setup->emClkCycles.tras = (Uint8) CSL_FEXT (hEmif->regs->SDTIMR,
        EMIF_SDTIMR_T_RAS);
    setup->emClkCycles.trc = (Uint8) CSL_FEXT (hEmif->regs->SDTIMR,
        EMIF_SDTIMR_T_RC);
    setup->emClkCycles.trrd = (Uint8) CSL_FEXT (hEmif->regs->SDTIMR,
        EMIF_SDTIMR_T_RRD);

    /* Read from SDRETR register */
    setup->txs = (Uint8) CSL_FEXT (hEmif->regs->SDSRETR, EMIF_SDSRETR_T_XS);

#if (EMIF_WIDTH == EMIF_32BIT_SUPPORT)
    /* Read status of Asyn Time out */
    setup->emifIntrCfg.atIntrEn = (Bool) CSL_FEXT (hEmif->regs->EIMSR,
        EMIF_EIMSR_ATMSET);
#endif

    /* Read from NANDFCR */
    setup->nandSetup.nand_support = (Uint8) CSL_FEXT (hEmif->regs->NANDFCR,
         EMIF_NANDFCR_CS2NAND);
    setup->nandSetup.ecc_support = (Uint8) CSL_FEXT (hEmif->regs->NANDFCR,
         EMIF_NANDFCR_CS2ECC);

    return CSL_SOK;
}
