/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_emifGetHwStatus.c
 *
 *  @path $(CSLPATH)\emif\src\csl_emifGetHwStatus.c
 *
 *  @brief File for functional layer of CSL API @a CSL_emifGetHwStatus()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  10-Sep-2004 author  File Created.
 * =============================================================================
 */

#include <csl_emif.h>
#include <csl_emifAux.h>

/** ============================================================================
 *   @n@b CSL_emifGetHwStatus
 *
 *   @b Description
 *   @n Gets the status of the different operations of EMIF and depends on the 
 *      query passed. 
 *
 *   @b Arguments
 *   @verbatim
            hEmif 			Handle to EMIF

			query 		    The query to this API of EMIF that indicates the
                           status to be returned.

			response 		Placeholder to return the status.
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li   	CSL_SOK 		    - Successful completion of the query
 *   @li    CSL_ESYS_BADHANDLE 	- Invalid handle
 *   @li    CSL_ESYS_INVQUERY   - Invalid query command 
 *	 @li	CSL_ESYS_INVPARAMS  - Invalid parameter
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n The input argument response.
 *
 *   @b Example
 *   @verbatim
      	CSL_EmifHandle          hEmif;
        CSL_EmifHwStatusQuery   query= CSL_EMIF_QUERY_REFRESH_RATE;
        Uint16                  response;

        status = CSL_emifGetHwStatus (hEmif, query, &response);

		. .            
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_emifGetHwStatus, ".text:csl_section:emif");
CSL_Status CSL_emifGetHwStatus (
    /* 
     * Pointer to the object that holds reference to the
     * instance of EMIF requested after the call
     */
    CSL_EmifHandle hEmif,
    /*
     * The query to this API, which indicates the status
     *  to be returned
     */
    CSL_EmifHwStatusQuery query,
    /*
     * Placeholder to return the status; @a void* casted
     */
    void *response
)
{
    CSL_Status               status = CSL_SOK;

    if (hEmif == NULL) {
        return CSL_ESYS_BADHANDLE;
    }
    
    if (response == NULL) {
        return CSL_ESYS_INVPARAMS;
    }
    
    switch (query) {
        case CSL_EMIF_QUERY_SELF_REFRESH:
            *(CSL_EmifSdramSelfRefresh *) response =
                CSL_emifGetSelfRefreshStatus (hEmif);
            break;
        case CSL_EMIF_QUERY_REFRESH_RATE:
            *(Uint16 *) response = CSL_emifGetRefreshRate (hEmif);
            break;
#if (EMIF_WIDTH== EMIF_32BIT_SUPPORT)
        case CSL_EMIF_QUERY_ASYNC_TIMEOUT_STATUS:
            *(Bool *) response = CSL_emifGetAsyncTimeoutStatus (hEmif);
            break;
        case CSL_EMIF_QUERY_MASKED_ASYNC_TIMEOUT_STATUS:
            *(Bool *) response = CSL_emifGetMaskedAsyncTimeoutStatus (hEmif);
            break;
        case CSL_EMIF_QUERY_MASKED_ASYNC_TIMEOUT_INTR_STATUS:
            *(Bool *) response = CSL_emifGetMaskedAsyncTimeoutIntrStatus (hEmif);
            break;
#endif
        case CSL_EMIF_QUERY_NANDSETUP_STATUS:
            *(CSL_EmifNandSetup *) response = CSL_emifGetNandStatus(hEmif);
            break;
        case CSL_EMIF_QUERY_NANDSTATUSREG:
            *(Bool *) response = CSL_emifGetNandWaitStatus(hEmif);
            break;

        case CSL_EMIF_QUERY_NANDECCREG:
            *(Uint32 *) response = CSL_emifGetNandEccStatus(hEmif);
            break;
        default:
            status = CSL_ESYS_INVQUERY;
    }

    return status;
}
