/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_emifHwControl.c
 *
 *  @path $(CSLPATH)\emif\src\csl_emifHwControl.c
 *
 *  @brief File for functional layer of CSL API @a CSL_emifHwControl()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  10-Sep-2004 author File Created.
 * =============================================================================
 */

#include <csl_emif.h>
#include <csl_emifAux.h>

/** ============================================================================
 *   @n@b CSL_emifHwControl
 *
 *   @b Description
 *   @n This function performs various control operations on the EMIF, based 
 *		on the command passed
 *
 *   @b Arguments
 *   @verbatim
            hEmif	The handle to EMIF module

			cmd		Operation to be performed on EMIF

			arg 	Argument specific to the command

 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li   	CSL_SOK 		    - Successful completion of the query
 *   @li    CSL_ESYS_INVCMD 	- Command not supported
 *   @li    CSL_ESYS_BADHANDLE 	- Invalid handle
 *	 @li	CSL_ESYS_INVPARAMS  - Invalid parameter passed
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  EMIF registers are configured according to the command and command
 *		 arguments. The command determines which registers are modified.
 *
 *   @b Modifies
 *   @n The hardware registers of EMIF determined by the command.
 *
 *   @b Example
 *   @verbatim
        CSL_EmifHandle 				 hEmif;
        CSL_EmifHwControlCmd         cmd= CSL_EMIF_CMD_SELF_REFRESH;
		CSL_EmifSdramSelfRefresh     arg = CSL_EMIF_SELF_REFRESH_DISABLE;
     	CSL_Status     				 status;

            ...
                  
      status = CSL_EmifHwControl(hEmif,cmd, &arg);
            ...
            
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_emifHwControl, ".text:csl_section:emif");
CSL_Status CSL_emifHwControl (
    /*
     * Pointer to the object that holds reference to the
     * instance of EMIF requested after the call
     */
    CSL_EmifHandle hEmif,
    /*
     * The command to this API, which indicates the action to be taken
     */
    CSL_EmifHwControlCmd cmd,
    /*
     * An optional argument @a void* casted
     */
    void *arg
)
{
    CSL_Status               status = CSL_SOK;

    if (hEmif == NULL) {
        return CSL_ESYS_BADHANDLE;
    }
    
    if (arg == NULL) {
        return CSL_ESYS_INVPARAMS;
    }
    
    switch (cmd) {
        case CSL_EMIF_CMD_SELF_REFRESH:
            CSL_emifSetSelfRefresh (hEmif, *(CSL_EmifSdramSelfRefresh *) arg);
            break;

        case CSL_EMIF_CMD_SELF_REFRESH_RATE:
            if (*(Uint16 *) arg < 0x10) {
                return (CSL_ESYS_INVPARAMS);
            }
            CSL_emifSetSelfRefreshRate (hEmif, *(Uint16 *) arg);
            break;

#if (EMIF_WIDTH== EMIF_32BIT_SUPPORT)
        case CSL_EMIF_CMD_SET_ASYNC_TIMEOUT_INTR:
            CSL_emifSetAsyncTimeOutIntr (hEmif);
            break;

        case CSL_EMIF_CMD_CLR_ASYNC_TIMEOUT_INTR:
            CSL_emifClrAsyncTimeOutIntr (hEmif);
            break;

        case CSL_EMIF_CMD_CLEAR_ASYNC_TIMEOUT:
            CSL_emifClearAsyncTimeOut (hEmif);
            break;

        case CSL_EMIF_CMD_CLEAR_MASKED_ASYNC_TIMEOUT:
            CSL_emifClearMaskedAsyncTimeOut (hEmif);
            break;
#endif
        case CSL_EMIF_CMD_SETUPNAND:
        {
            CSL_EmifNandSetup *setup = (CSL_EmifNandSetup *)arg;
            CSL_emifSetNandSetup(hEmif, setup->nand_support);
            CSL_emifSetNandEccSetup(hEmif, setup->ecc_support);
        }
            break;
        default:
            status = CSL_ESYS_INVCMD;
            break;
    }                           /* End of switch (cmd) */
    return status;
}                               /*End of CSL_Status CSL_EmifHwControl */
