/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_emifHwSetup.c
 *
 *  @path $(CSLPATH)\emif\src\csl_emifHwSetup.c
 * 
 *  @brief File for functional layer of CSL API @a CSL_emifHwSetup()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  10-Sep-2004 author File Created.
 * =============================================================================
 */

#include <csl_emif.h>

/** ============================================================================
 *   @n@b CSL_emifHwSetup
 *
 *   @b Description
 *   @n It configures the emif registers as emif the values passed
 *      in the hardware setup structure.
 *
 *   @b Arguments
 *   @verbatim
            hEmif            Handle to the emif
 
            hwSetup             Pointer to harware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Hardware setup successful
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVPARAMS  - Hardware structure is not
                                                  properly initialized
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  EMIF controller registers are configured according 
 *       to the hardware setup parameters
 *
 *   @b Modifies
 *   @n EMIF controller registers
 *
 *   @b Example
 *   @verbatim
            CSL_EmifHandle   hEmif;
            CSL_EmifObj      emifObj;
            CSL_EmifHwSetup  hwSetup;
            CSL_status       status;

            ...
            
            hEmif = CSL_emifOpen(&emifObj, CSL_EMIF, NULL, &status);            
                      
            status = CSL_emifHwSetup(hEmif, &hwSetup);
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_emifHwSetup, ".text:csl_section:emif");
CSL_Status CSL_emifHwSetup (
    /*
     * Pointer to the object that holds reference to the
     * instance of EMIF requested after the call
     */
    CSL_EmifHandle hEmif,
    /*
     * Pointer to setup structure which contains the
     * information to program EMIF to a useful state
     */
    CSL_EmifHwSetup * hwSetup
)
{
    CSL_Status               status = CSL_SOK;
    Uint32                   val;
    Uint32                  *pSdramSpace = (Uint32 *) CSL_EMIF_SDRAM_SPACE;

    if (hEmif == NULL) {
        return CSL_ESYS_BADHANDLE;
    }

    if (hwSetup == NULL) {
        return CSL_ESYS_INVPARAMS;
    }

#if (EMIF_WIDTH == EMIF_16BIT_SUPPORT)
    hwSetup->narrowMode = CSL_EMIF_16BIT_USAGE;
    hwSetup->asyncBankCfg1.asize &= 0x01;
    hwSetup->asyncBankCfg1.ew = 0x00;
#endif

        /** Program SDTIMR Register 
	*/
    val = 0x00;
    val |= hwSetup->emClkCycles.trfc;
    val <<= 3;
    val |= hwSetup->emClkCycles.trp;
    val <<= 4;
    val |= hwSetup->emClkCycles.trcd;
    val <<= 4;
    val |= hwSetup->emClkCycles.twr;
    val <<= 4;
    val |= hwSetup->emClkCycles.tras;
    val <<= 4;
    val |= hwSetup->emClkCycles.trc;
    val <<= 4;
    val |= hwSetup->emClkCycles.trrd;
    val <<= 4;
    hEmif->regs->SDTIMR = val;

    /* Program SDRETR */
    CSL_FINS (hEmif->regs->SDSRETR, EMIF_SDSRETR_T_XS, hwSetup->txs);

   /* 
    * Initialise the SDRAM device acc. to Single Rate Define 
	* Program the refresh rate so that (RR * 8)/input_freq > 200usec.
	* input frequency is 133.33 Mhz 
	*/
    val = 0xD06;
    CSL_FINS (hEmif->regs->SDRCR, EMIF_SDRCR_RR, val);

    val = 0;
    val = hwSetup->sdramSelfRefreshEn;
    val <<= 17;
    val |= hwSetup->narrowMode;
    val <<= 5;
    val |= hwSetup->sdramCasLaten;
    val <<= 1;
    /* Set 1 in Bit11_9 lock field to enable CL field write */
    val |= 1;
    val <<= 4;
    val |= hwSetup->sdramIntBankSetup;
    val <<= 4;
    val |= hwSetup->sdramPageSize;

    /* Update SDRAM configuration register */
    hEmif->regs->SDCR = val;

    /* Perform a Read from SDRAM memory space*/
    val = *pSdramSpace;

    /* Program SDRCR with the given value */
    CSL_FINS (hEmif->regs->SDRCR, EMIF_SDRCR_RR, hwSetup->refreshRate);


#if (EMIF_WIDTH == EMIF_32BIT_SUPPORT)
    /* Write to clear Asynchrnous Time out */
    CSL_FINS (hEmif->regs->EIRR, EMIF_EIRR_AT, hwSetup->emifIntrCfg.atIntrEn);

    /* Write to configure AWAIT polarity */
    CSL_FINS (hEmif->regs->AWCCR, EMIF_AWCCR_WP0, hwSetup->waitPolarityCfg);
    /* Write to configure Maximum External Wait */
    CSL_FINS (hEmif->regs->AWCCR, EMIF_AWCCR_MEWC, hwSetup->maxExtWait);

    /* Clear the interrupts */
    CSL_FINS (hEmif->regs->EIRR, EMIF_EIRR_AT, 0x01);
    /* Setting the AT interrupt register */
    CSL_FINS (hEmif->regs->EIMSR, EMIF_EIMSR_ATMSET,
        hwSetup->emifIntrCfg.atIntrEn);
#endif

    /* Async 1 Configuration */
    CSL_FINS (hEmif->regs->A1CR, EMIF_A1CR_SS, hwSetup->asyncBankCfg1.ss);
    CSL_FINS (hEmif->regs->A1CR, EMIF_A1CR_EW, hwSetup->asyncBankCfg1.ew);
    CSL_FINS (hEmif->regs->A1CR, EMIF_A1CR_W_SETUP,
        hwSetup->asyncBankCfg1.w_setup);
    CSL_FINS (hEmif->regs->A1CR, EMIF_A1CR_W_STROBE,
        hwSetup->asyncBankCfg1.w_strobe);
    CSL_FINS (hEmif->regs->A1CR, EMIF_A1CR_W_HOLD,
        hwSetup->asyncBankCfg1.w_hold);
    CSL_FINS (hEmif->regs->A1CR, EMIF_A1CR_R_SETUP,
        hwSetup->asyncBankCfg1.r_setup);
    CSL_FINS (hEmif->regs->A1CR, EMIF_A1CR_R_STROBE,
        hwSetup->asyncBankCfg1.r_strobe);
    CSL_FINS (hEmif->regs->A1CR, EMIF_A1CR_R_HOLD,
        hwSetup->asyncBankCfg1.r_hold);
    CSL_FINS (hEmif->regs->A1CR, EMIF_A1CR_TA, hwSetup->asyncBankCfg1.ta);
    CSL_FINS (hEmif->regs->A1CR, EMIF_A1CR_ASIZE, hwSetup->asyncBankCfg1.asize);

    /* NAND Configuration */
    CSL_FINS (hEmif->regs->NANDFCR, EMIF_NANDFCR_CS2NAND, 
        hwSetup->nandSetup.nand_support);
    CSL_FINS (hEmif->regs->NANDFCR, EMIF_NANDFCR_CS2ECC, 
        hwSetup->nandSetup.ecc_support);

    return status;
}
