/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_emifOpen.c
 *
 *  @path $(CSLPATH)\emif\src\csl_emifOpen.c
 *
 *  @brief File for functional layer of CSL API @a CSL_emifOpen()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  1-Dec-2004 author File Created.
 * =============================================================================
 */

#include <csl_emif.h>

/** ============================================================================
 *   @n@b CSL_emifOpen
 *
 *   @b Description
 *   @n This function opens the EMIF CSL. It returns a handle to the CSL for the 
 *   EMIF instance. This handle is passed to all other CSL APIs, as the reference 
 *   to the EMIF instance .
 *
 *   @b Arguments
 *   @verbatim
        pEmifObj	Pointer to EMIF object.

        emifNum	    Instance of EMIF to be opened.

        pEmifParam	Module specific parameters.

        pStatus		The status of the function call.
        
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_EmifHandle
 *   @li                         Valid EMIF handle will be returned if
 *                              status value is equal to CSL_SOK.
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  1.	The status is returned in the status variable. If status 
 *           returned is
 *	@li         CSL_OK		       - Open call is successful
 *  @li         CSL_ESYS_FAIL	   - Module instance is invalid.
 *  @li			CSL_ESYS_INVPARAMS - Invalid Parametere is passed.
 *       2.	EMIF object structure is populated
 *
 *   @b Modifies
 *   @n  1.	The status variable
 *
 *       2.	EMIF object structure 
 *
 *
 *   @b Example
 *   @verbatim
     CSL_EmifObj	    emifObj;
     CSL_EmifHandle     hEmif;
     CSL_EmifHwSetup    hwSetup;
     CSL_Status         status;

     ..
     
     hEmif = CSL_emifOpen (&emifObj, CSL_EMIF, NULL, &status);
        
     ..
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_emifOpen, ".text:csl_section:emif");
CSL_EmifHandle           CSL_emifOpen (
    /*
     * Pointer to the object that holds reference to the
     * instance of EMIF requested after the call
     */
    CSL_EmifObj * pEmifObj,
    /*
     * Instance of EMIF to which a handle is requested
     */
    CSL_InstNum emifNum,
    /*
     * Module specific parameters;
     * Currently there are none; the user should pass 'NULL'
     */
    CSL_EmifParam * pEmifParam,
    /*
     * This returns the status (success/errors) of the call.
     * Could be 'NULL' if the user does not want status information.
     */
    CSL_Status * pStatus
)
{
    CSL_Status               status;
    CSL_EmifHandle           hEmif;
    CSL_EmifBaseAddress      baseAddress;

    if (pStatus == NULL) {
        hEmif = (CSL_EmifHandle) NULL;
        return hEmif;
    }

    /* Added following code to validate input argument */

    if (pEmifObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
        hEmif = (CSL_EmifHandle) NULL;
        return hEmif;
    }

    status = CSL_emifGetBaseAddress (emifNum, pEmifParam, &baseAddress);

    if (status == CSL_SOK) {
        pEmifObj->regs = baseAddress.regs;
        pEmifObj->emifNum = (CSL_InstNum) emifNum;
        hEmif = (CSL_EmifHandle) pEmifObj;
    }
    else {
        pEmifObj->regs = (CSL_EmifRegsOvly) NULL;
        pEmifObj->emifNum = (CSL_InstNum) - 1;
        hEmif = (CSL_EmifHandle) NULL;
    }

    if (pStatus) {
        *pStatus = status;
    }

    return hEmif;
}
