/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file csl_i2cGetHwSetup.c
 *
 *  @brief    File for functional layer of CSL API @a CSL_i2cGetHwSetup()
 *
 *  Description
 *    - The @a CSL_i2cGetHwSetup() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Modified on: 18/1/2005
 *    - Reason: created the sources
 * 
 *    @author Ramitha Mathew.
 */

#include <csl_i2c.h>


/** ============================================================================
 *   @n@b CSL_i2cGetHwSetup
 *
 *   @b Description
 *   @n It retrives the hardware setup parameters of the I2C
 *      specified by the given handle.
 *
 *   @b Arguments
 *   @verbatim
 
            hI2c        Handle to the I2C  
            setup       Pointer to the harware setup structure

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Retrieving the hardware setup
 *                                                parameters is successful
 *   @li                    CSL_ESYS_BADHANDLE  - The handle is passed is
 *                                                invalid
 *   @li                    CSL_ESYS_INVPARAMS  - Invalid parameter
 *
 *   <b> Pre Condition </b>
 *   @n  i2c must have opened properly
 *
 *   <b> Post Condition </b>
 *   @n  The hardware setup structure is populated with the hardware setup
 *       parameters
 *
 *   @b Modifies
 *   @n setup variable
 *
 *   @b Example
 *   @verbatim
            CSL_I2cHandle   hI2c;
            CSL_I2cHwSetup  hwSetup;

            ...

            status = CSL_i2cGetHwSetup (hI2c, &hwSetup);

            ...

     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_i2cGetHwSetup, ".text:csl_section:i2c");

CSL_Status CSL_i2cGetHwSetup (
    CSL_I2cHandle       hI2c,
    CSL_I2cHwSetup      *setup
)
{
    CSL_Status  status = CSL_SOK;

    if (hI2c == NULL){
        status = CSL_ESYS_BADHANDLE;
    }
    else if(setup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        /* extracting I2C Mode register bits */
        setup->mode     = CSL_FEXT (hI2c->regs->I2CMDR, I2C_I2CMDR_MST);
        setup->dir              = CSL_FEXT (hI2c->regs->I2CMDR, I2C_I2CMDR_TRX);
        setup->addrMode         = CSL_FEXT (hI2c->regs->I2CMDR, I2C_I2CMDR_XA);
        setup->ownaddr          = CSL_FEXT (hI2c->regs->I2COAR, I2C_I2COAR_OADDR);
        setup->sttbyteen        = CSL_FEXT (hI2c->regs->I2CMDR, I2C_I2CMDR_STB);
        setup->ackMode          = CSL_FEXT (hI2c->regs->I2CMDR, I2C_I2CMDR_NACKMOD);
        setup->runMode          = CSL_FEXT (hI2c->regs->I2CMDR, I2C_I2CMDR_FREE);
        setup->repeatMode       = CSL_FEXT (hI2c->regs->I2CMDR, I2C_I2CMDR_RM);
        setup->loopBackMode     = CSL_FEXT (hI2c->regs->I2CMDR, I2C_I2CMDR_DLB);
        setup->freeDataFormat   = CSL_FEXT (hI2c->regs->I2CMDR, I2C_I2CMDR_FDF);
        setup->resetMode        = CSL_FEXT (hI2c->regs->I2CMDR, I2C_I2CMDR_IRS);
        setup->xrdym              = CSL_FEXT (hI2c->regs->I2CEMDR, I2C_I2CEMDR_XRDYM);

        /* extracting I2C Interrupt Mask register */
        setup->inten = hI2c->regs->I2CIER;

        /* extracting I2C PreScaler register */
        setup->clksetup->prescalar = CSL_FEXT (hI2c->regs->I2CPSC, I2C_I2CPSC_IPSC);
        /* extracting I2C Clock Divider Low register */
        setup->clksetup->clklowdiv = CSL_FEXT (hI2c->regs->I2CCLKL, I2C_I2CCLKL_ICCL);
        /* extracting I2C Clock Divider High register */
        setup->clksetup->clkhighdiv = CSL_FEXT (hI2c->regs->I2CCLKH, I2C_I2CCLKH_ICCH);
    }

    return status;
}
