/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file csl_i2cGetHwStatus.c
 *
 *  @brief    File for functional layer of CSL API @a CSL_i2cGetHwStatus()
 *
 *  Description
 *    - The @a CSL_i2cGetHwStatus() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Modified on: 18/1/2005
 *    - Reason: created the sources
 *
 *    @author Ramitha Mathew.
 */

#include <csl_i2c.h>
#include <csl_i2cAux.h>


/** ============================================================================
 *   @n@b CSL_i2cGetHwStatus
 *
 *   @b Description
 *   @n Gets the status of the different operations of I2C.
 *
 *   @b Arguments
 *   @verbatim
            hI2c        Handle to the I2C instance 
            query       The query to this API of I2C which indicates the
                        status to be returned.
            response    Placeholder to return the status.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Status info return successful
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVQUERY   - Invalid query command
 *   @li                    CSL_ESYS_INVPARAMS  - Invalid parameter
 *
 *   <b> Pre Condition </b>
 *   @n  i2c opened properly
 *
 *   <b> Post Condition </b>
 *   @n  none
 *
 *   @b  Modifies
 *   @n  response variable holds the queried value
 *
 *   @b Example
 *   @verbatim
        CSL_I2cHandle           hI2c;
        CSL_I2cHwStatusQuery    query;
        void                    *reponse;

        status = CSL_Geti2cHwStatus (hI2c, query, &response);

     @endverbatim
 * =============================================================================
 */
 
#pragma CODE_SECTION (CSL_i2cGetHwStatus, ".text:csl_section:i2c")
CSL_Status CSL_i2cGetHwStatus (
    CSL_I2cHandle           hI2c,
    CSL_I2cHwStatusQuery    query,
    void                    *response
)
{

    CSL_Status  status = CSL_SOK;

    if (hI2c == NULL){
        status = CSL_ESYS_BADHANDLE;
    }
    else if (response == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch (query) {
            case CSL_I2C_QUERY_CLOCK_SETUP:
                CSL_i2cGetClockSetup (hI2c, response);
                break;

            case CSL_I2C_QUERY_BUS_BUSY:
                CSL_i2cGetBusBusy (hI2c, response);
                break;

            case CSL_I2C_QUERY_RX_RDY:
                CSL_i2cGetRxRdy (hI2c, response);
                break;

            case CSL_I2C_QUERY_TX_RDY:
                CSL_i2cGetTxRdy (hI2c, response);
                break;

            case CSL_I2C_QUERY_ACS_RDY:
                CSL_i2cGetAcsRdy (hI2c, response);
                break;

            case CSL_I2C_QUERY_SCD:
                CSL_i2cGetScd (hI2c, response);
                break;

            case CSL_I2C_QUERY_AD0:
                CSL_i2cGetAd0 (hI2c, response);
                break;

            case CSL_I2C_QUERY_AAS:
                CSL_i2cGetAas (hI2c, response);
                break;

            case CSL_I2C_QUERY_RSFULL:
                CSL_i2cGetRsFull (hI2c, response);
                break;

            case CSL_I2C_QUERY_XSMT:
                CSL_i2cGetXsmt (hI2c, response);
                break;

            case CSL_I2C_QUERY_AL:
                CSL_i2cGetAl (hI2c, response);
                break;

            case CSL_I2C_QUERY_SDIR:
                CSL_i2cGetSdir (hI2c, response);
                break;

            case CSL_I2C_QUERY_NACKSNT:
                CSL_i2cGetNacksnt (hI2c, response);
                break;

            case CSL_I2C_QUERY_RDONE:
                CSL_i2cGetRdone (hI2c, response);
                break;

            case CSL_I2C_QUERY_BITCOUNT:
                CSL_i2cGetBitcount (hI2c, response);
                break;

            case CSL_I2C_QUERY_INTCODE:
                CSL_i2cGetIntcode (hI2c, response);
                break;

            case CSL_I2C_QUERY_REV:
                CSL_i2cGetRev (hI2c, response);
                break;

            case CSL_I2C_QUERY_CLASS:
                CSL_i2cGetClass (hI2c, response);
                break;

            case CSL_I2C_QUERY_TYPE:
                CSL_i2cGetType (hI2c, response);
                break;

            default:
                status = CSL_ESYS_INVQUERY;
                break;
        }
    }
    return status;
}
