/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file csl_i2cHwControl.c
 *
 *  @brief    File for functional layer of CSL API @a CSL_i2cHwControl()
 *
 *  Description
 *    - The @a CSL_i2cHwControl() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Modified on: 18/1/2005
 *    - Reason: created the sources
 *	  - Modified on: 25/10/2005
 *	  - Added command for setting I2C as master/slave
 *
 *    @author Ramitha Mathew.
 */


#include <csl_i2c.h>
#include <csl_i2cAux.h>



/** ============================================================================
 *   @n@b CSL_i2cHwControl
 *
 *   @b Description
 *   @n Takes a command of I2C with an optional argument & implements it.
 *
 *   @b Arguments
 *   @verbatim
 
            hI2c        Handle to the I2C instance 
            cmd         The command to this API indicates the action to be
                        taken on I2C. 
            arg         An optional argument.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li         CSL_SOK               - Status info return successful.
 *   @li         CSL_ESYS_BADHANDLE    - Invalid handle
 *   @li         CSL_ESYS_INVCMD       - Invalid command
 *
 *   <b> Pre Condition </b>
 *   @n  i2c opened properly
 *
 *   <b> Post Condition </b>
 *   @n  device register programmed accordingly
 *
 *   @b Modifies
 *   @n The hardware registers of I2C.
 *
 *   @b Example
 *   @verbatim
        CSL_I2cHandle           hI2c;
        CSL_I2cHwControlCmd     cmd;
        void                    *arg;
        
        cmd = CSL_I2C_CMD_RESET;

        status = CSL_i2cHwControl (hI2c, cmd, &arg);

     @endverbatim
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_i2cHwControl, ".text:csl_section:i2c");

CSL_Status CSL_i2cHwControl (
    CSL_I2cHandle       hI2c,
    CSL_I2cHwControlCmd cmd,
    void                *arg
)
{
    CSL_Status  status = CSL_SOK;

    if (hI2c == NULL){
        status = CSL_ESYS_BADHANDLE;
    }
    else{
        switch (cmd) {
            case CSL_I2C_CMD_ENABLE:
                CSL_i2cEnable (hI2c);
                break;

            case CSL_I2C_CMD_CONFIG_AS_GIO:
                CSL_i2cConfigAsGio (hI2c);
                break;

            case CSL_I2C_CMD_RESET:
                CSL_i2cReset (hI2c);
                break;

            case CSL_I2C_CMD_OUTOFRESET:
                CSL_i2cOutOfReset (hI2c);
                break;

            case CSL_I2C_CMD_CLEAR_STATUS:
                CSL_i2cClearStatus (hI2c);
                break;

            case CSL_I2C_CMD_SET_SLAVE_ADDR:
                CSL_i2cSetSlaveAddr (hI2c, arg);
                break;

            case CSL_I2C_CMD_SET_DATA_COUNT:
                CSL_i2cSetDataCount (hI2c, arg);
                break;

            case CSL_I2C_CMD_START:
                CSL_i2cStart (hI2c);
                break;

            case CSL_I2C_CMD_STOP:
                CSL_i2cStop (hI2c);
                break;

            case CSL_I2C_CMD_DIR_TRANSMIT:
                CSL_i2cDirTransmit (hI2c);
                break;

            case CSL_I2C_CMD_DIR_RECEIVE:
                CSL_i2cDirReceive (hI2c);
                break;

            case CSL_I2C_CMD_RM_ENABLE:
                CSL_i2cRmEnable (hI2c);
                break;

            case CSL_I2C_CMD_RM_DISABLE:
                CSL_i2cRmDisable (hI2c);
                break;

            case CSL_I2C_CMD_DLB_ENABLE:
                CSL_i2cDlbEnable (hI2c);
                break;

            case CSL_I2C_CMD_DLB_DISABLE:
                CSL_i2cDlbDisable (hI2c);
                break;

            case CSL_I2C_CMD_INTR_ENABLE:
                CSL_i2cEnableIntr (hI2c);
                break;

            case CSL_I2C_CMD_INTR_DISABLE:
                CSL_i2cDisableIntr (hI2c);
                break;

            case CSL_I2C_CMD_SET_OWN_ADDR:
                CSL_i2cSetOwnAddr (hI2c, arg);
                break;

            case CSL_I2C_CMD_SET_CLOCK:
                CSL_i2cSetClock (hI2c, arg);
                break;

            case CSL_I2C_CMD_SET_MODE:
                CSL_i2cSetMode (hI2c, arg);

            default:
                status = CSL_ESYS_INVCMD;
                break;
        }
    }
    return status;
}
