/*  ============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_i2cHwSetup.c
 *
 *  @brief File for functional layer of CSL API @a CSL_i2cHwSetup()
 *
 *  Description
 *    - The @a CSL_i2cHwSetup() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Modified on: 18/1/2005
 *    - Reason: created the sources
 * 
 *  @author Ramitha Mathew.
 */

#include <csl_i2c.h>

/** ============================================================================
 *   @n@b CSL_i2cHwSetup
 *
 *   @b Description
 *   @n This function initializes the device registers with the appropriate
 *      values provided through the HwSetup Data structure. After the 
 *      Setup is completed, the device is ready for  operation.      
 *      For information passed through the HwSetup Data structure refer
 *   @a CSL_i2cHwSetup.
 *
 *   @b Arguments
     @verbatim
     
            hI2c   handle to the I2c instance
            setup  Pointer to setup structure that programs I2C
            
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Successful completion of hardware     
 *                                    setup
 *   @li                    CSL_ESYS_ INVPARAMS - Hardware structure is not  
 *                                    properly initialized
 *   @li                    CSL_ESYS_ BADHANDLE - Invalid CSL handle
 *
 *
 *   <b> Pre Condition </b>
 *   @n  Both CSL_i2cInit() and a CSL_i2cOpen() must be called
 *
 *   <b> Post Condition </b>
 *   @n  I2C registers are configured 
 *
 *   @b  Modifies
 *   @n  I2C registers
 *
 *   @b Example
 *   @verbatim  
        CSL_i2cHandle hI2c;
        CSL_i2cHwSetup hwSetup;
      
        hwSetup.mode           = CSL_I2C_MODE_MASTER;
        hwSetup.dir            = CSL_I2C_DIR_TRANSMIT;
        hwSetup.addrMode       = CSL_I2C_ADDRSZ_SEVEN;
        .
        .
        hwSetup.clksetup       = &clksetup;
    
        CSL_i2cHwSetup (hI2c, &hwSetup);
     @endverbatim
 * 
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_i2cHwSetup, ".text:csl_section:i2c");

CSL_Status CSL_i2cHwSetup (
    CSL_I2cHandle       hI2c,
    CSL_I2cHwSetup      *setup
)
{
    CSL_Status    status = CSL_SOK;

    if (hI2c == NULL){
        status = CSL_ESYS_BADHANDLE;
    }

    else if (setup == NULL){
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        /*  
         *  Set the mode(Master/Slave), direction(Transmitter/Receiver),
         *  addressing mode(7-bit or 10-bit, free run mode, free data format and
         *  start byte mode,ack mode, repeat mode, loopback mode and reset mode 
         *  in I2C Mode register
         */

        /*  
         *  All the bits to be setup are initialiazed to zero
         *  before assigning the passed setup.
         *  The register value I2CMDR is anded with the mask (0x3807) 
         *  to make all fields (that need to be programmed) zeroes.
         *  
         */
        hI2c->regs->I2CMDR = ((hI2c->regs->I2CMDR & 0x3807)
                            | (CSL_FMK (I2C_I2CMDR_MST, setup->mode)
                            | CSL_FMK (I2C_I2CMDR_NACKMOD, setup->ackMode)
                            | CSL_FMK (I2C_I2CMDR_TRX, setup->dir)
                            | CSL_FMK (I2C_I2CMDR_XA, setup->addrMode)
                            | CSL_FMK (I2C_I2CMDR_FREE, setup->runMode)
                            | CSL_FMK (I2C_I2CMDR_STB, setup->sttbyteen)
                            | CSL_FMK (I2C_I2CMDR_FDF, setup->freeDataFormat)
                            | CSL_FMK (I2C_I2CMDR_RM, setup->repeatMode)
                            | CSL_FMK (I2C_I2CMDR_DLB, setup->loopBackMode)
                            | CSL_FMK (I2C_I2CMDR_IRS, setup->resetMode)));

        /*  
         *  Setting the BCM in I2C Extended Mode register
         *  All the bits to be setup are initialiazed to zero
         *  before assigning the passed setup.
         *  The register value I2CEMDR is anded with the mask (0xfffe) 
         *  to make all fields (that need to be programmed) zeroes.
         *  
         */ 
        hI2c->regs->I2CEMDR = (hI2c->regs->I2CEMDR & 0xfffe)
                            | (CSL_FMK (I2C_I2CEMDR_XRDYM, setup->xrdym));

        /* Set the own address of the given instance */
        CSL_FINS (hI2c->regs->I2COAR, I2C_I2COAR_OADDR, setup->ownaddr);

        /* The interrupt status is set into the interrupt enable register.
         *  All the bits to be setup are initialiazed to zero
         *  before assigning the passed setup.
         *  The register value I2CIMR is anded with the mask (0xff80) 
         *  to make all fields (that need to be programmed) zeroes.
         *  */
        hI2c->regs->I2CIER = (hI2c->regs->I2CIER & 0xff80) | setup->inten;

        /* Set up the prescalar value */
        CSL_FINS (hI2c->regs->I2CPSC, I2C_I2CPSC_IPSC, setup->clksetup->prescalar);

        /* Set the clock low value */
        CSL_FINS (hI2c->regs->I2CCLKL, I2C_I2CCLKL_ICCL, setup->clksetup->clklowdiv);

        /* Set the clock high value */
        CSL_FINS (hI2c->regs->I2CCLKH, I2C_I2CCLKH_ICCH, setup->clksetup->clkhighdiv);
    }

    return status;
}
