/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file csl_i2cHwSetupRaw.c
 *
 *  @brief File for functional layer of CSL API @a CSL_i2cHwSetupRaw()
 *
 *  Description
 *    - The @a CSL_i2cHwSetupRaw() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Modified on: 18/1/2005
 *    - Reason: created the sources
 * 
 *  @author Ramitha Mathew.
 */



#include <csl_i2c.h>

/** ============================================================================
 *   @n@b CSL_i2cHwSetupRaw
 *
 *   @b Description
 *   @n This function initializes the device registers with the register-values
 *      provided through the Config Data structure.
 *
 *   @b Arguments
 *   @verbatim
            hI2c        Handle to the I2C  
            config      Pointer to config structure
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Configuration successful
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVPARAMS  - Configuration is not
 *                                                properly initialized
 *
 *   <b> Pre Condition </b>
 *   @n  Both CSL_i2cInit() and a CSL_i2cOpen() must be called
 *
 *
 *   <b> Post Condition </b>
 *   @n  The registers of the specified I2C instance will be setup
 *       according to value passed.
 *
 *   @b Modifies
 *   @n Hardware registers of the specified I2C instance.
 *
 *   @b Example
 *   @verbatim
        CSL_I2cHandle       hI2c;
        CSL_I2cConfig       config = CSL_I2C_CONFIG_DEFAULTS;
        CSL_Status          status;

        status = CSL_i2cHwSetupRaw (hI2c, &config);

     @endverbatim
 * ===========================================================================
 */

#pragma CODE_SECTION (CSL_i2cHwSetupRaw, ".text:csl_section:i2c");
CSL_Status CSL_i2cHwSetupRaw (
    CSL_I2cHandle   hI2c,
    CSL_I2cConfig   *config
)
{
    CSL_Status status = CSL_SOK;

    if (hI2c == NULL){
        status = CSL_ESYS_BADHANDLE;
    }
    else if (config == NULL){
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        hI2c->regs->I2COAR = config->I2COAR;
        hI2c->regs->I2CIER = config->I2CIER;
        hI2c->regs->I2CSTR = config->I2CSTR;
        hI2c->regs->I2CCLKL = config->I2CCLKL;
        hI2c->regs->I2CCLKH = config->I2CCLKH;
        hI2c->regs->I2CCNT = config->I2CCNT;
        hI2c->regs->I2CSAR = config->I2CSAR;
        hI2c->regs->I2CDXR = config->I2CDXR;
        hI2c->regs->I2CMDR = config->I2CMDR;
        hI2c->regs->I2CISR = config->I2CISR;
        hI2c->regs->I2CEMDR = config->I2CEMDR;
        hI2c->regs->I2CPSC = config->I2CPSC;
        hI2c->regs->I2CPFUNC = config->I2CPFUNC;
        hI2c->regs->I2CPDIR = config->I2CPDIR;
        hI2c->regs->I2CPDOUT = config->I2CPDOUT;
        hI2c->regs->I2CPDSET = config->I2CPDSET;
        hI2c->regs->I2CPDCLR = config->I2CPDCLR;
    }
    return status;
}
