/*  ============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_i2cOpen.c
 *
 *  @brief  File for functional layer of CSL API @a CSL_i2cOpen()
 *
 *  Description
 *    - The @a CSL_i2cOpen() function definition & it's associated functions
 *
 *  Modification 1
 *    - Created on: 18/01/2005
 *
 *  @author Ramitha Mathew.
 */

#include <csl_i2c.h>


/** ===========================================================================
 *   @n@b CSL_i2cOpen
 *
 *   @b Description
 *   @n This function populates the peripheral data object for the instance
 *      and returns a handle to the instance.
 *      The open call sets up the data structures for the particular instance
 *      of I2C device. The device can be re-opened anytime after it has been
 *      normally closed if so required.
 *      The handle returned by this call is input as an essential argument for 
 *      rest of the APIs described for this module. 
 *        
 *   @b Arguments
     @verbatim

        pI2cObj     Pointer to the I2C instance object
        i2cNum      Instance of the I2C to be opened. 
        pI2cParam   Pointer to module specific parameters
        pStatus     Pointer for returning status of the function call
        
 *   @endverbatim
 *
 *   <b> Return Value </b> CSL_I2cHandle
 *
 *       - Valid I2C instance handle will be returned if status value is
 *        equal to CSL_SOK else CSL_I2C_BADHANDLE
 *
 *   <b> Pre Condition </b>
 *   @n  CSL_i2cInit() has to be called
 *
 *   <b> Post Condition </b>
 *   @n  1. The status is returned in the status variable. If status returned is
 *   @li            CSL_OK             - Open call is successful
 *   @li            CSL_ESYS_INVPARAMS - If invalid parameter passed
 *   @li            CSL_ESYS_FAIL      - If invalid instance number
 *       2. I2C object structure is populated
 *
 *   @b Modifies
 *   @n@li      The status variable
 *     @li      I2C object structure 
 *
 *   @b Example
 *   @verbatim
 *        CSL_status        status;
 *        CSL_I2cObj        i2cObj;
 *        CSL_I2cHandle     hI2c;
 *
 *        hI2c = CSL_I2cOpen (&i2cObj,
 *                            CSL_I2C_0,
 *                            NULL,
 *                            &status
 *                            );
     @endverbatim
 * ===========================================================================
 */

#pragma CODE_SECTION (CSL_i2cOpen, ".text:csl_section:i2c");

CSL_I2cHandle CSL_i2cOpen (
    CSL_I2cObj      *pI2cObj,
    CSL_InstNum     i2cNum,
    CSL_I2cParam    *pI2cParam,
    CSL_Status      *pStatus
)
{
    CSL_I2cHandle            hI2c = (CSL_I2cHandle) NULL;
    CSL_I2cBaseAddress       baseAddress;

    if (pStatus == NULL) {
        /* do nothing : module handle is already initialized to NULL */
    }
    else if (pI2cObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }
    else{
        *pStatus = CSL_i2cGetBaseAddress (i2cNum, pI2cParam, &baseAddress);

        if (*pStatus == CSL_SOK) {
            pI2cObj->regs = baseAddress.regs;
            pI2cObj->perNum = (CSL_InstNum) i2cNum;
            hI2c = (CSL_I2cHandle) pI2cObj;

            /* To remove compiler warning/remark. */
            *pI2cParam = *pI2cParam;
        }
        else {
            pI2cObj->regs = (CSL_I2cRegsOvly) NULL;
            pI2cObj->perNum = (CSL_InstNum) - 1;
        }
    }
    return hI2c;
}
