/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file csl_i2cRead.c
 *
 *  @brief File for functional layer of CSL API @a CSL_i2cRead()
 *
 *  Description
 *    - The @a CSL_i2cRead() function definition & it's associated functions
 *
 *  Modification 1
 *    - Created on: 18/1/2005
 *    - Reason: created the sources
 *
 *  @author Ramitha Mathew.
 */

#include <csl_i2c.h>

/** ============================================================================
 *   @n@b CSL_i2cRead
 *
 *   @b Description
 *   @n Reads the received data from the I2C Data Receive register
 *
 *   @b Arguments
     @verbatim
            hI2c   Handle of already opened peripheral
            buf    Pointer to memory where data will be read and stored
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Data successfully extracted
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVPARAMS  - Invalid parameter
 *                  
 *   <b> Pre Condition </b>
 *   @n  Both @a CSL_i2cInit() and @a CSL_i2cOpen() must be called successfully
 *
 *   <b> Post Condition </b>
 *   @n  RSFULL flag bit in ICSTR register is cleared
 *       ICRRDY flag bit in ICSTR register is cleared
 *
 *   @b Modifies
 *   @n buf variable holds the received data
 *
 *   @b Example
 *   @verbatim 
 
        Uint16        inData;
        CSL_Status    status;
        CSL_I2cHandle hI2c;
        ...
        // I2C object defined and HwSetup structure defined and initialized
        ...

        // Init, Open, HwSetup successfully done in that order
        ...

        status = CSL_i2cRead(hI2c, &inData);
     @endverbatim
 *
 *  ============================================================================
 */

#pragma CODE_SECTION (CSL_i2cRead, ".text:csl_section:i2c");

CSL_Status CSL_i2cRead (    
    CSL_I2cHandle   hI2c,    
    void            *buf
)
{
    CSL_Status status = CSL_SOK;

    if (hI2c == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (buf == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        /* Reading the received data */
        *(Uint8 *) buf = CSL_FEXT (hI2c->regs->I2CDRR, I2C_I2CDRR_D);
    }
    return status;
}
