/*  ===========================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in 
 *   the license agreement under which this software has been supplied.
 *   ==========================================================================
 */

/* ============================================================================
 *   @file  _csl_icacheConfg.c
 *
 *   @path  $(CSLPATH)\ipmodules\icache\src
 *
 *   @desc  File implements CSL internal function for setting cache operating mode.
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 Ramitha Mathew File Created.
 *
 * =============================================================================
 */

#include <csl_icache.h>
#include <csl_chip.h>


/* ============================================================================
 *   @n@b _CSL_icacheConfg
 *
 *   @b Description
 *   @n This function is internal to the L1P I-cache CSL. The function 
 *      configures the I-cache operating mode and is called from the  
 *      function CSL_icacheHwSetup().
 *
 *   @b Arguments
 *   @verbatim
             
            icacheMode      Required I-cache mode
            icachePrio      RAM access priority 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Hardware setup successful
 *   @li                    CSL_ESYS_INVPARAMS - Invalid parameter
 *
 *   <b> Pre Condition </b>
 *   @n  I-cache has to be opened properly
 *
 *   <b> Post Condition </b>
 *   @n   1.    The status is returned. If status
 *              returned is
 *   @li            CSL_OK                Hardware setup successful
 *   @li            CSL_ESYS_INVPARAMS    Invalid parameter  
 *
 *        2.    Hardware registers are initialized
 *
 *
 *   @b Modifies
 *   @n   1. Hardware registers
 *
 *
 *   @b Example
 *   @verbatim
 
            CSL_IcacheMode            icacheMode;
            CSL_IcachePrio            icachePrio;
            ...
            _CSL_icacheConfg (icacheMode,icachePrio);
            ...
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (_CSL_icacheConfg , ".text:csl_section:icache");

CSL_Status _CSL_icacheConfg (
    CSL_IcacheMode  icacheMode,
    CSL_IcachePrio  icachePrio
)
{
    Uint32      readValue;
    Uint32      writeValue;

    /* Checking for valid cache mode */
    if ((icacheMode < CSL_ICACHE_MODE_CACHE_ENABLE)
        || (icacheMode > CSL_ICACHE_MODE_CACHE_BYPASS)) {
        return CSL_ESYS_INVPARAMS;
    }

    /* Getting the csr register value */
    readValue = CSL_chipReadReg (CSL_CHIP_REG_CSR);

    /* Writing the mode in PCC field of CSR */
    writeValue = (readValue & ~(CSL_CHIP_CSR_PCC_MASK))
                |(icacheMode << CSL_CHIP_CSR_PCC_SHIFT);

    CSL_chipWriteReg (CSL_CHIP_REG_CSR, writeValue);

    /* Getting the MEMCSR register value */
    readValue = CSL_chipReadReg (CSL_CHIP_REG_MEMCSR);

    /* Writing the icachePrio in P field of MEMCSR */
    writeValue = (readValue & ~(CSL_ICACHE_MEMCSR_P_MASK))
                |(icachePrio << CSL_ICACHE_MEMCSR_P_SHIFT);

    CSL_chipWriteReg (CSL_CHIP_REG_MEMCSR, writeValue);

    return CSL_SOK;
}
