/** ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied priovided
 *  ============================================================================
*/

/** ============================================================================
 *   @file  csl_icacheGetHwSetup.c
 *
 *   @path  $(CSLPATH)\ipmodules\icache\src
 *
 *   @desc  I-cache CSL implementation 
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 Ramitha Mathew File Created.
 *
 * =============================================================================
 */

#include <csl_icache.h>
#include <csl_chip.h>

/** ============================================================================
 *   @n@b CSL_icacheGetHwSetup
 *
 *   @b Description
 *   @n It retrives the hardware setup parameters of the I-cache module
 *      specified by the given handle.
 *
 *   @b Arguments
 *   @verbatim

            hIcache         Handle to the instance of I-cache 
            hwSetup         Pointer to the harware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Retrieving the hardware setup
 *                                                parameters is successful
 *   @li                    CSL_ESYS_BADHANDLE  - The handle is passed is
 *                                                invalid
 *   @li                    CSL_ESYS_INVPARAMS  - Invalid parameters
 *
 *   <b> Pre Condition </b>
 *   @n  icache would have opened properly
 *
 *   <b> Post Condition </b>
 *   @n  The hardware setup structure is populated with the hardware setup
 *       parameters
 *
 *   @b Modifies
 *   @n hwSetup variable
 *
 *   @b Example
 *   @verbatim
            CSL_IcacheHandle   hIcache;
            CSL_IcacheHwSetup  hwSetup;

            ...
            
            status = CSL_icacheGetHwSetup (hIcache, &hwSetup);
            
            ...
            
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_icacheGetHwSetup, ".text:csl_section:icache");

CSL_Status CSL_icacheGetHwSetup (
    CSL_IcacheHandle    hIcache,
    CSL_IcacheHwSetup   *hwSetup
)
{
    Uint32  readValue;

    if (hIcache == NULL)
        return CSL_ESYS_BADHANDLE;

    if (hwSetup == NULL) {
        return CSL_ESYS_INVPARAMS;
    }

    /* Getting the csr register value */
    readValue = CSL_chipReadReg (CSL_CHIP_REG_CSR);
    /* Extracting PCC from CSR register */
    hwSetup->mode = (CSL_IcacheMode) ((readValue & \
                    CSL_CHIP_CSR_PCC_MASK) >> CSL_CHIP_CSR_PCC_SHIFT);

    /* Getting the MEMCSR register value */
    readValue = CSL_chipReadReg (CSL_CHIP_REG_MEMCSR);
    /* Extracting P field from MEMCSR register */
    hwSetup->ramAccessPrio = (CSL_IcachePrio) ((readValue & \
                             CSL_ICACHE_MEMCSR_P_MASK) >> CSL_ICACHE_MEMCSR_P_SHIFT);

    return CSL_SOK;
}
