/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** ============================================================================
 *   @file  csl_icacheGetHwStatus.c
 *
 *   @path  $(CSLPATH)\ipmodules\icache\src
 *
 *   @desc  L1P I-cache CSL implementation.
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 Ramitha Mathew File Created.
 *
 * =============================================================================
 */

#include <csl_icache.h>
#include <csl_chip.h>
#include <csl_icacheAux.h>


/** ============================================================================
 *   @n@b CSL_icacheGetHwStatus
 *
 *   @b Description
 *   @n This function is for querying the hardware status. It accepts the query 
 *      and populates the data structure passed with the corresponding hardware 
 *      status.
 *
 *   @b Arguments
 *   @verbatim

            hIcache         Handle to the DSP I-cache instance 
            myQuery         Query to be performed.  
            response        Pointer to data structure to hold the 
                            status information
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Query successful
 *   @li                    CSL_ESYS_BADHANDLE - Invalid handle
 *   @li                    CSL_ESYS_INVQUERY  - Invalid query
 *   @li                    CSL_ESYS_INVPARAMS - Invalid parameters
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n   1.    The status is returned. If status
 *              returned is
 *   @li            CSL_OK              Query is successful
 *   @li            CSL_ESYS_BADHANDLE  Invalid handle
 *   @li            CSL_ESYS_INVQUERY   Invalid query 
 *
 *        2.    The status information is copied to the corresponding
 *              data structure 
 *
 *   @b Modifies
 *   @n    Data structure pointed by response
 *
 *   @b Example
 *   @verbatim
            CSL_Status                  status;
            CSL_IcacheMode              modarg;
            CSL_IcacheHandle            hIcache;

            ...

            status = CSL_icacheGetHwStatus (
                                hIcache, 
                                CSL_ICACHE_QUERY_MODE, 
                                (void*) &modarg);
                          
            ...
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_icacheGetHwStatus, ".text:csl_section:icache");

CSL_Status CSL_icacheGetHwStatus (
    CSL_IcacheHandle        hIcache,
    CSL_IcacheHwStatusQuery myQuery,
    void                    *response
)
{
    Uint32          readValue;
    CSL_Status      status = CSL_SOK;

    if (hIcache == NULL)
        return CSL_ESYS_BADHANDLE;

    switch (myQuery) {
        case CSL_ICACHE_QUERY_MODE:        
            /* Getting the csr register value */
            readValue = CSL_chipReadReg (CSL_CHIP_REG_CSR);            
            /* Extracting the PCC field from CSR register value */
            *(CSL_IcacheMode *) response = (CSL_IcacheMode) ((readValue & \
                                           CSL_CHIP_CSR_PCC_MASK) >> CSL_CHIP_CSR_PCC_SHIFT);
            break;
    
        case CSL_ICACHE_QUERY_INV_WORDCNT:
            *(CSL_IcacheCount *) response = CSL_icacheGetInvCnt (hIcache);
            break;
        
        case CSL_ICACHE_QUERY_INV_STARTADDR:
            *(CSL_IcacheAddr *) response = CSL_icacheGetInvAddr (hIcache);
            break;
    
        case CSL_ICACHE_QUERY_INV_CACHE:
            *(Uint8 *) response = CSL_icacheGetIp (hIcache);
            break;
        
        case CSL_ICACHE_QUERY_PRIO:
        
            /* Getting the MEMCSR register value */
            readValue = CSL_chipReadReg (CSL_CHIP_REG_MEMCSR);
            
            /* Extracting P field from MEMCSR register */
            *(CSL_IcacheMode *) response = (CSL_IcacheMode) ((readValue & \
                                            CSL_ICACHE_MEMCSR_P_MASK) >> CSL_ICACHE_MEMCSR_P_SHIFT);
            break;
    
        default:
            status = CSL_ESYS_INVQUERY;
    }

    return status;
}
