/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** ============================================================================
 *   @file  csl_icacheHwControl.c
 *
 *   @path  $(CSLPATH)\ipmodules\icache\src
 *
 *   @desc  L1P I-cache CSL implementation 
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 Ramitha Mathew File Created.
 *
 * =============================================================================
 */

#include <csl_icache.h>
#include <csl_icacheAux.h>

/** ============================================================================
 *   @n@b CSL_icacheHwControl
 *
 *   @b Description
 *   @n This function is used for controlling the L1P I-cache instance. It 
 *      accepts the commands and data to configure/control the hardware. Some
 *      commands does not need any data.
 *
 *   @b Arguments
 *   @verbatim

            hIcache         Handle to the L1P I-cache instance 
            cmd             Command to be executed 
            cmdArg          Data pointer corresponding to command 
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Command execution successful.
 *   @li                    CSL_ESYS_BADHANDLE - Invalid handle
 *   @li                    CSL_ESYS_INVCMD    - Invalid command 
 *
 *   <b> Pre Condition </b>
 *   @n  icache would have opened properly
 *
 *   <b> Post Condition </b>
 *   @n   1.    The status is returned. If status
 *              returned is
 *   @li            CSL_OK                Command successful
 *   @li            CSL_ESYS_BADHANDLE    Invalid handle
 *   @li            CSL_ESYS_INVCMD       Invalid command   
 *        2.    Appropriate hardware parameters are configured based on
 *              the command
 *
 *
 *   @b Modifies
 *   @n Hardware registers
 *
 *   @b Example
 *   @verbatim
            CSL_Status                  status;
            CSL_IcacheHandle            hIcache;

            ...
            
            status  = CSL_icacheHwControl (
                                hIcache,
                                CSL_ICACHE_CMD_CACHE_ENABLE,
                                NULL);
            ...
            
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_icacheHwControl, ".text:csl_section:icache");

CSL_Status CSL_icacheHwControl (
    CSL_IcacheHandle        hIcache,
    CSL_IcacheHwControlCmd  cmd,
    void                    *cmdArg
)
{
    CSL_Status  status = CSL_SOK;

    if (hIcache == NULL)
        return CSL_ESYS_BADHANDLE;

    switch (cmd) {
        case CSL_ICACHE_CMD_CACHE_ENABLE:
            CSL_icacheSetMode (CSL_ICACHE_MODE_CACHE_ENABLE);
            break;
    
        case CSL_ICACHE_CMD_CACHE_FREEZE:
            CSL_icacheSetMode (CSL_ICACHE_MODE_CACHE_FREEZE);
            break;
    
        case CSL_ICACHE_CMD_CACHE_BYPASS:
            CSL_icacheSetMode (CSL_ICACHE_MODE_CACHE_BYPASS);
            break;
    
        case CSL_ICACHE_CMD_INV_STARTADDR:
            CSL_icacheSetInvAddr (hIcache, (CSL_IcacheAddr) cmdArg);
            break;
    
        case CSL_ICACHE_CMD_INV_BYTECNT:        
            /* calculating the word count */
            *((CSL_IcacheCount *) cmdArg) = (*(CSL_IcacheCount *) cmdArg + 3) >> 2;
            
            CSL_icacheSetInvCnt (hIcache, (CSL_IcacheCount *) cmdArg);
            break;
            
        case CSL_ICACHE_CMD_INV_CACHELINE:
            CSL_icacheSetInvAddr (hIcache, *(CSL_IcacheAddr *) cmdArg);
            *(CSL_IcacheCount *) cmdArg = 1;
            CSL_icacheSetInvCnt (hIcache, cmdArg);
            break;
            
        case CSL_ICACHE_CMD_INV_CACHE:    
            CSL_icacheSetIp (hIcache);
            if (*(CSL_IcacheWait *) cmdArg) {
                
                /* Waiting for invalidation to be complete */
                while (CSL_FEXT (hIcache->regs->L1PICR, ICACHE_L1PICR_IP));
            }
            break;
    
        default:
            status = CSL_ESYS_INVCMD;

    }

    return status;
}
