/* =============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** ============================================================================
 *   @file  csl_icacheOpen.c
 *
 *   @path  $(CSLPATH)\ipmodules\icache\src
 *
 *   @desc  L1P I-cache CSL implementation 
 * =============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 Ramitha Mathew File Created.
 *
 * =============================================================================
 */

#include <csl_icache.h>

/** ============================================================================
 *   @n@b CSL_icacheOpen
 *
 *   @b Description
 *   @n This Function populates the peripheral data object for the instance and
 *      returns handle to it
 *
 *   @b Arguments
 *   @verbatim
            pIcacheObj       Pointer to the data object for icache instance 
            icacheNum        Specifies the instance of the icache to be opened 
            pIcacheParam     Module specific parameter for icache instance 
            pStatus          Status of the function call
      @endverbatim
 *
 *   <b> Return Value </b>  CSL_IcacheHandle
 *   @n                     Valid icache handle will be returned if
 *                          status value is equal to CSL_SOK.
 *
 *   <b> Pre Condition </b>
 *   @n  I-cache module has to be initialized
 *
 *   <b> Post Condition </b>
 *   @n     1.    The status is returned in the status variable. If status
 *                returned is
 *   @li            CSL_OK          Open call is successful
 *   @li            CSL_ESYS_FAIL   Open call failed
 *
 *          2.    Icache object structure is populated
 *
 *   @b Modifies
 *   @n     1. The status variable
 *          2. The data object for the instance
 *
 *   @b Example
 *   @verbatim
            CSL_status            status;
            CSL_IcacheObj         icacheObj;
            CSL_IcacheHandle      hIcache;

            hIcache = CSL_IcacheOpen (&icacheObj, CSL_ICACHE, NULL, &status);
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_icacheOpen, ".text:csl_section:icache");

CSL_IcacheHandle CSL_icacheOpen (
    CSL_IcacheObj       *pIcacheObj,
    CSL_InstNum         icacheNum,
    CSL_IcacheParam     *param,
    CSL_Status          *pStatus
)
{
    CSL_Status               st;
    CSL_IcacheHandle         hIcache;
    CSL_IcacheBaseAddress    baseAddress;

    /* obtains the base address of the icache MMRs */
    if (CSL_icacheGetBaseAddress (icacheNum, param, &baseAddress) == CSL_SOK) {
        /* filling the icache data object */
        pIcacheObj->regs = baseAddress.regs;
        pIcacheObj->icacheNum = (CSL_InstNum) icacheNum;
        hIcache = (CSL_IcacheHandle) pIcacheObj;
        st = CSL_SOK;
    }
    else {
        /* if valid base address is not obtained data obj is as follows */
        pIcacheObj->regs = (CSL_IcacheRegsOvly) NULL;
        pIcacheObj->icacheNum = (CSL_InstNum) - 1;
        hIcache = (CSL_IcacheHandle) NULL;
        st = CSL_ESYS_FAIL;
    }

    if (pStatus) {
        *pStatus = st;
    }

    return hIcache;
}
