/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**
 *  @file  csl_intcClose.c
 *
 *  @brief  INTC Functional Layer: CSL_intcClose(..)
 *
 *  Description
 *  - CSL_intcClose(..) function definition
 *  
 *  Modification
 *  - Modified on: 14/12/2004
 *  - Reason: creation
 * 
 *  @author RMathew
 */

#include <csl_intc.h>
#include "_csl_intc.h"
#include <soc.h>

/** =============================================================================
 *   @n@b CSL_intcClose
 *
 *   @b Description
 *   @n Releases an allocated event. CSL_intcClose() must be called to
 *      release an event that has been previously allocated with a call
 *      to CSL_intcOpen().
 *
 *   @b Arguments
 *   @verbatim
            hIntc            Handle identifying the event
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Close successful
 *   @li                    CSL_ESYS_FAIL       - Close failed
 *
 *   <b> Pre Condition </b>
 *   @n  Module must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n None
 *
 *
 *   @b Example
 *   @verbatim
            CSL_IntcHandle       hIntc;
            CSL_status           status;
            ...

            status = CSL_intcClose(hIntc);
            if (status != CSL_SOK) {
                // close failed! //
            }
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_intcClose, ".text:csl_section:intc");

CSL_Status CSL_intcClose (
    CSL_IntcHandle hIntc
)
{
    CSL_Status                  status = CSL_ESYS_BADHANDLE;
    CSL_IntcGlobalEnableState   gie;

    /* checking whether closing is done on an open event */
    if (hIntc != (CSL_IntcHandle) CSL_INTC_BADHANDLE) {
        /* checking validity of the eventId */
        if ((hIntc->eventId != CSL_INTC_EVENTID_INVALID)) {
            CSL_intcGlobalDisable (&gie);

            /* unmasking the envent for reuse */
            _CSL_IntcEventAllocMask[hIntc->eventId] =
                        (CSL_BitMask16) _CSL_INTC_EVENTUNMASKED;
            CSL_intcGlobalRestore (gie);

            hIntc->eventId = CSL_INTC_EVENTID_INVALID;
            status = CSL_SOK;
        }
    }
    return status;
}
