/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**
 *  @file  csl_intcHookIsr.c
 *
 *  @brief  INTC Functional Layer: CSL_intcHookIsr(..)
 *
 *  Description
 *  - CSL_intcHookIsr(..) function definition
 * 
 *
 * Modification
 *  - Modified on: 20/12/2004
 *  - Reason: creation
 *
 *  - Modified on: 11/03/2005 
 *  - Reason:dma related code added[RMathew]
 *
 *  @author RMathew
 *
 */

#include <csl_intc.h>
#include "_csl_intc.h"
#include <soc.h>
#include <csl_dmax.h>

#define CSL_MVKHL_OPCODE                0xFF80007F
#define CSL_HIGH_ADDR_MASK              0xFFFF0000
#define CSL_LOW_ADDR_MASK               0x0000FFFF

extern void _CSL_intcFetchPacket (
    void
);
extern Uint32 _CSL_intcReadISTP (
    void
);

/** ============================================================================
 *  @n@b CSL_intcHookIsr
 *
 *  @b Description
 *  @n The CSL_intcHookIsr (..) hooks up the Interrupt Service Routine(ISR) to 
 *     the specified event. Note: Unlike CSL_intcPlugEventHandler (..)  , this  
 *     is done without opening the module (INTC) for the event. Hence the 
 *     CSL dispatcher is also not made use.
 *
 *     
 *  @b Arguments
 *  @verbatim
        eventId       Event Identifier        
        isrAddr       Pointer to the handler
    @endverbatim
 *  
 *  @b Pre Condition 
 *  @n INTC has to be initialized properly
 *
 *  @b Post Condition 
 *  @n Handler plugged
 *
 *  @b Modifies 
 *  @n None
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK         - Isr plugged properly
 *   @li                    CSL_ESYS_FAIL   - Isr plug failed.(The DMAX 
 *	    									  uid used in INTC ie 
 *											  CSL_DMAX_LOPRIORITY_EVENT0_UID 
 *											  might be in use by some other
 *											  application)
 *
 *  @b Example:
 *  @verbatim
        CSL_intcHookIsr (CSL_INTC_EVENTID_RTI_INT_REQ0 , rtiIsr);
    @endverbatim 
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_intcHookIsr, ".text:csl_section:intc");

CSL_Status CSL_intcHookIsr (
    CSL_IntcEventId     eventId,
    Uint32              isrAddr
)
{
    CSL_IntcGlobalEnableState    gie;
    CSL_Status                   status;
    Uint32                       vector;
    Uint32                       *fetchPacket;
    Uint32                       work[8];
    int                          loop;
    volatile Uint16              response = 0;
    volatile Uint32              *gpCount0Addr = (Uint32 *) 0x620080A0;

    /* DMax related variable declarations */
    CSL_DmaxHandle               hDmax;
    CSL_DmaxGPXFRParameterSetup  myGpxfrParameterSetup;
    CSL_DmaxGPTransferEventSetup myGpxfrEventSetup;
    CSL_DmaxObj                  myEvent;
    CSL_DmaxHwSetup              myHwSetup;

    status = CSL_SOK;

    if (_CSL_IntcContextFlags & CSL_INTC_CONTEXT_DISABLECOREVECTORWRITES) {
        /* in case there's an OS that's managing the core vector area */
        return CSL_ESYS_FAIL;
    }

    if ((eventId >= CSL_INTC_EVENTID_RESET &&
            eventId <= CSL_INTC_EVENTID_DMAXEVTOUT7)) {
        CSL_intcGlobalDisable (&gie);

        /* 
         * getting the address of the general fetch packet depending 
         * upon maskable or non maskable interrupts
         */
        fetchPacket = (Uint32 *) ((void *) _CSL_intcFetchPacket);

        /* getting the base address of Interrupt vector table */
        vector = _CSL_intcReadISTP ();

        /* calculating the fetch packet address of the event */
        vector = vector + (8 * 4 * eventId);

        /* copy the fixed assembled fetch packet over to the work area */
        for (loop = 0; loop < 8; loop++) {
            work[loop] = fetchPacket[loop];
        }

        /* Inserting the function address directly into the MVKL/H opcodes */
        work[1] =
            (work[1] & CSL_MVKHL_OPCODE) | (((Uint32) isrAddr & CSL_LOW_ADDR_MASK) << 7);
        work[2] =
            (work[2] & CSL_MVKHL_OPCODE) | (((Uint32) isrAddr & CSL_HIGH_ADDR_MASK) >> 9);


        /*DMAX event 0 is opted */
        myEvent.paramUid = CSL_DMAX_LOPRIORITY_PARAMETERENTRY_ANY;
        myEvent.eventUid = CSL_DMAX_LOPRIORITY_EVENT0_UID;

        hDmax = CSL_dmaxOpen (&myEvent, CSL_DMAX, NULL, &status);

        if (status == CSL_SOK) {
            myGpxfrEventSetup.qtsl                  = CSL_DMAX_EVENT0_QTSL_MOVE8_ELE;
            myGpxfrEventSetup.sync                  = CSL_DMAX_EVENT0_SYNC_TRAN_COMPL;
            /* Tcc bit 0 need to be set on transfer completion */
            myGpxfrEventSetup.tcc                   = 0;
            myGpxfrEventSetup.atcint                = CSL_DMAX_EVENT0_ATCINT_DISABLE;
            myGpxfrEventSetup.tcint                 = CSL_DMAX_EVENT0_TCINT_DISABLE;
            myGpxfrEventSetup.rload                 = CSL_DMAX_EVENT0_RLOAD_DISABLE;
            myGpxfrEventSetup.cc = 
                                CSL_DMAX_EVENT0_CC_COUNT2_15_COUNT1_8_COUNT0_8;
            myGpxfrEventSetup.esize                 = CSL_DMAX_EVENT0_ESIZE_32BIT;
            myGpxfrEventSetup.pte                   = hDmax->paramPtr;
            myGpxfrEventSetup.etype                 = CSL_DMAX_EVENT0_ETYPE_GENERALXFR;
            myGpxfrEventSetup.paramSetup            = &myGpxfrParameterSetup;
            /* Number of elemnts to be transfered */
            myGpxfrParameterSetup.count0            = 8;
            myGpxfrParameterSetup.count1            = 0;
            myGpxfrParameterSetup.count2            = 0;
            /* Increment the src address by 1 after each element transfer */
            myGpxfrParameterSetup.srcIndex0         = 1;
            /* Increment the dst address by 1 after each element transfer */
            myGpxfrParameterSetup.dstIndex0         = 1;
            myGpxfrParameterSetup.srcIndex1         = 0;
            myGpxfrParameterSetup.dstIndex1         = 0;
            myGpxfrParameterSetup.srcIndex2         = 0;
            myGpxfrParameterSetup.dstIndex2         = 0;
            myGpxfrParameterSetup.srcReloadAddr0    = (Uint32) work;
            myGpxfrParameterSetup.dstReloadAddr0    = (Uint32) vector;
            myGpxfrParameterSetup.srcReloadAddr1    = 0;
            myGpxfrParameterSetup.dstReloadAddr1    = 0;

            myHwSetup.polarity = 0;

            /* low priority */
            myHwSetup.priority = 0;
            myHwSetup.eventSetup = (CSL_DmaxEventSetup *) & myGpxfrEventSetup;

            CSL_dmaxHwSetup (hDmax, &myHwSetup);
            CSL_dmaxHwControl (hDmax, CSL_DMAX_CMD_EVENTENABLE, NULL);
            CSL_dmaxHwControl (hDmax, CSL_DMAX_CMD_CLEARTCC, NULL);
            /* Triggering the event */
            CSL_dmaxHwControl (hDmax, CSL_DMAX_CMD_STARTASYNCTRANSFER, NULL);

            /* 
             * gpCount0Addr points to Base Addres of the Low Parameter Entry 
             * Table. As the Parameter Entry is ANY we should poll the proper 
             * PTE. Following one will caliculate the exact Parameter and, 
             * adding 2 (i.e +2) points to count0 value in the parameter Entry
             */
            gpCount0Addr = gpCount0Addr + hDmax->paramPtr + 2;

            /* Give a small delay before checking the transfer completion */
            response = 0x1000;
            while (response--);

            /* 
             * Waiting for DMAX trasfer complete. This check for count0 in 
             * one dimentional transfer. This routine is for setting 
             * interupt handler the transfer complete interrupt is not used 
             */
            do {
                response = *(Uint32 *) gpCount0Addr;
            } while (response != 0);

            /* Clearing the TCC bit */
            CSL_dmaxHwControl (hDmax, CSL_DMAX_CMD_CLEARTCC, NULL);

            CSL_dmaxClose (hDmax);

            CSL_intcGlobalRestore (gie);
        }
        else {
            return (CSL_ESYS_FAIL);
        }

    }
    else {
        return (CSL_ESYS_FAIL);
    }
    return status;
}
