/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**
 *  @file  csl_intcHwControl.c
 *
 *  @brief  INTC Functional Layer: CSL_intcHwControl(..)
 *
 *  Description
 *  - CSL_intcHwControl(..) function definition
 *  
 *  Modification
 *  - Modified on: 15/12/2004
 *  - Reason: creation
 *
 *  @author RMathew
 *
 */

#include <csl_intc.h>
#include "_csl_intc.h"
#include <soc.h>


extern CSL_IntcEventEnableState _CSL_intcEventEnable (
    _CSL_IntcVecId,
    Uint32
);
extern CSL_IntcEventEnableState _CSL_intcEventDisable (
    _CSL_IntcVecId,
    Uint32
);
extern void _CSL_intcEventSet (
    _CSL_IntcVecId
);
extern void _CSL_intcEventClear (
    _CSL_IntcVecId
);


/** ============================================================================
 *   @n@b CSL_intcHwControl
 *
 *   @b Description
 *   @n This API is used to invoke any of the supported control-operations
 *      supported by the module. Note: Refer to the control-command 
 *      documentation for details on the parameter (if any) that a specific 
 *      command accepts.
 
 *   @b Arguments
 *   @verbatim
            hIntc           Handle identifying the event
            command         The command to this API indicates the action to be
                            taken on INTC.
            commandArg      An optional argument.
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - HwControl successful.
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVCMD     - Invalid command
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n The hardware registers of INTC.
 *
 *   @b Example:
 *   @verbatim
        CSL_intcHwControl (hIntc, CSL_INTC_CMD_EVTSET, NULL);
     @endverbatim
 * =============================================================================
 */
 
#pragma CODE_SECTION (CSL_intcHwControl, ".text:csl_section:intc");

CSL_Status CSL_intcHwControl (
    CSL_IntcHandle          hIntc,
    CSL_IntcHwControlCmd    controlCommand,
    void                    *commandArg
)
{
    CSL_Status               status;
    CSL_IntcEventEnableState ie;
    /* Interrupt Vector to which event is mapped */
    Uint32                   vecId;

    /* starting off on an optimistic note */
    status = CSL_SOK;

    if ((hIntc != NULL) && (hIntc->eventId >= CSL_INTC_EVENTID_RESET && \
            hIntc->eventId <= CSL_INTC_EVENTID_DMAXEVTOUT7)) {
        switch (controlCommand) {
            case CSL_INTC_CMD_EVTENABLE:                
                    vecId = 31 - _lmbd (1, _CSL_IntcEventTable[hIntc->eventId]);
                    /* enabling the event */
                    ie = (CSL_IntcEventEnableState)
                        _CSL_intcEventEnable (
                            _CSL_IntcEventTable[hIntc->eventId],vecId);
    
                    if (commandArg != NULL) {
                        *(CSL_IntcEventEnableState *) commandArg = ie;
                   }
                    break;
                
    
            case CSL_INTC_CMD_EVTDISABLE:               
                    vecId = 31 - _lmbd (1, _CSL_IntcEventTable[hIntc->eventId]);
                    /* disabling the event */
                    ie = (CSL_IntcEventEnableState)
                        _CSL_intcEventDisable (~(_CSL_IntcEventTable[hIntc->
                                eventId]), vecId);
                    if (commandArg != NULL) {
                        *(CSL_IntcEventEnableState *) commandArg = ie;
                   }
                    break;
                
    
            case CSL_INTC_CMD_EVTCLEAR:
                    /* clearing the Interrupt pending flag */
                    _CSL_intcEventClear (_CSL_IntcEventTable[hIntc->eventId]);
                    break;
    
            case CSL_INTC_CMD_EVTSET:
                    /* setting the Interrupt pending flag */
                    _CSL_intcEventSet (_CSL_IntcEventTable[hIntc->eventId]);
                    break;
    
            default:
                status = CSL_ESYS_INVCMD;
                break;
        }
    }
    else {
        status = CSL_ESYS_BADHANDLE;
    }

    return status;
}
