/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */
 
/**
 *  @file  csl_intcHwStatus.c
 *
 *  @brief  INTC Functional Layer: CSL_intcHwStatus(..)
 *
 *  Description
 *  - CSL_intcHwStatus(..) function definition
 *  
 *  Modification
 *  - Modified on: 15/12/2004
 *  - Reason: creation
 *
 *  @author RMathew
 *
 */


#include <csl_intc.h>
#include "_csl_intc.h"
#include <soc.h>


#pragma CODE_SECTION (CSL_intcGetHwStatus, ".text:csl_section:intc");

extern CSL_IntcEventPendingState _CSL_intcEventFlagTest (
    _CSL_IntcVecId,
    Uint32
);


/** ============================================================================
 *   @n@b CSL_intcGetHwStatus
 *
 *   @b Description
 *   @n The CSL_intcGetHwStatus(..) API could be used to retrieve status
 *      or configuration information from the peripheral. The user must
 *      allocate an object that would hold the retrieved information
 *      and pass a pointer to it to the function. The type of the object
 *      is specific to the query-command.
 *
 *   @b Arguments
 *   @verbatim
            hIntc           Handle identifying the event
            query           The query to this API of INTC which indicates the
                            status to be returned.
            response        Placeholder to return the status.
     @endverbatim
 *
 *   <b> Return Value </b> CSL_Status
 *   @li                   CSL_SOK               - Status info return successful
 *   @li                   CSL_ESYS_BADHANDLE    - Invalid handle
 *   @li                   CSL_ESYS_INVQUERY     - Invalid query 
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n None
 *
 *   @b Example:
 *   @verbatim
     Bool    evtPending = FALSE;
     while (evtPending == FALSE) {
        CSL_intcGetHwStatus(hIntc,CSL_INTC_QUERY_ISEVENTPENDING,&evtPending);
      }
  
     @endverbatim
 *
 * =============================================================================
 */
CSL_Status  CSL_intcGetHwStatus (
    CSL_IntcHandle          hIntc,
    CSL_IntcHwStatusQuery   myQuery,
    void                    *answer
)
{
    CSL_Status      status = CSL_SOK;
    Uint32          vecId;

    if ((hIntc != NULL) && (hIntc->eventId >= CSL_INTC_EVENTID_RESET && \
            hIntc->eventId <= CSL_INTC_EVENTID_DMAXEVTOUT7)) {

        /* getting the interrupt vector to which the event is mapped */
        vecId = 31 - _lmbd (1, _CSL_IntcEventTable[hIntc->eventId]);

        switch (myQuery) {
            case CSL_INTC_QUERY_ISEVENTPENDING:
                /* checking for pending flag */
                *(CSL_IntcEventPendingState *) answer =
                    _CSL_intcEventFlagTest (_CSL_IntcEventTable[hIntc->eventId],
                    vecId);
                break;
    
            default:
                status = CSL_ESYS_INVQUERY;
                break;
        }
    }
    else {
        status = CSL_ESYS_BADHANDLE;
   }

    return status;
}
