/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**  @file  csl_intcInit.c
 *
 *  @brief  INTC Functional Layer: CSL_intcInit(..)
 *
 *  Description
 *  - CSL_intcInit(..) function definition
 *  
 *  Modification
 *  - Modified on:14/12/2004
 *  - Reason: creation 
 *
 *  @author RMathew
 *
 */

#include <csl_intc.h>
#include "_csl_intc.h"

#pragma DATA_SECTION (_CSL_IntcEventTable,".bss:csl_section:intc")
_CSL_IntcVecId  _CSL_IntcEventTable[CSL_INTC_EVENT_CNT] = {
                CSL_INTC_INT0, CSL_INTC_INT1, CSL_INTC_INT2,  CSL_INTC_INT3,
                CSL_INTC_INT4, CSL_INTC_INT5, CSL_INTC_INT6,  CSL_INTC_INT7,
                CSL_INTC_INT8, CSL_INTC_INT9, CSL_INTC_INT10, CSL_INTC_INT11,
                CSL_INTC_INT12,CSL_INTC_INT13, CSL_INTC_INT14, CSL_INTC_INT15
};

#pragma DATA_SECTION (_CSL_IntcContextFlags,".bss:csl_section:intc")
CSL_BitMask16   _CSL_IntcContextFlags;

/** ============================================================================
 *   @n@b CSL_intcInit
 *
 *   @b Description
 *   This API performs any module-specific initialization. 
 *   CSL_intcInit (..) must be invoked before calling any other 
 *   API in the INTC module.
 *
 *   @b Arguments
 *   @n pContext - pointer to the intc context memory allocated
 *      by the user
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - returns on success
 *                          CSL_ESYS_ALREADY_INITIALIZED - if initialized
 *   <b> Pre Condition </b>
 *   @n  Memory has to be allocated and filled for the context variable
 *
 *   <b> Post Condition </b>
 *   @n  Intc module will be initialized 
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example:
 *   @verbatim
      if ((CSL_intcInit ( ) != CSL_SOK) && \
          (CSL_intcInit () != CSL_ESYS_ALREADY_INITIALIZED)
         ) 
         { 
         //module initialization failed! //
         }  
     @endverbatim
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_intcInit,".text:csl_section:intc");

CSL_Status CSL_intcInit (
    CSL_IntcContext     *pContext
)
{
    CSL_Status      status;
    Uint16          count;

    if (_CSL_IntcEventAllocMask == NULL) {
        /* pointer to the mask array  */
        _CSL_IntcEventAllocMask = pContext->eventAllocMask;

        /* Initializing _CSL_IntcEventAllocMask array memory to zeroes */
        for (count = 0; count < CSL_INTC_EVENT_CNT; count++)
            _CSL_IntcEventAllocMask[count] = 0;

        /* save the flags for reference, later */
        _CSL_IntcContextFlags = pContext->flags;
        status = CSL_SOK;

    }
    else {
        status = CSL_ESYS_ALREADY_INITIALIZED;
   }

    return status;
}
