/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**
 *  @file  csl_intcOpen.c
 *
 *  @brief  INTC Functional Layer: CSL_intcOpen(..)
 *
 *  Description
 *  - CSL_intcOpen(..) function definition
 *  
 *  Modification
 *  - Modified on: 14/12/2004
 *  - Reason: creation 
 *
 *  @author RMathew
 *
 */


#include <csl_intc.h>
#include "_csl_intc.h"
#include <soc.h>


#pragma DATA_SECTION (_CSL_IntcEventAllocMask, ".bss:csl_section:intc");
CSL_BitMask16   *_CSL_IntcEventAllocMask = NULL;

/** ============================================================================
 *   @n@b CSL_intcOpen
 *
 *   @b Description
 *   @n The API would reserve an interrupt-event for use. It returns
 *      a valid handle to the event only if the event is not currently
 *      allocated. The user could release the event after use by calling
 *      CSL_intcClose(..). The CSL-object ('intcObj') that the user
 *      passes would be used to store information pertaining handle.
 *
 *   *   @b Arguments
 *   @verbatim
              pIntcObj     pointer to the CSL-object allocated by the user              
              eventId      the event-id of the interrupt
              params       module specific parameter              
              pStatus      (optional) pointer for returning status of the
                           function call
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_IntcHandle
 *   @n                     Valid INTC handle identifying the event
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n   1.    INTC object structure is populated
 *   @n   2.    The status is returned in the status variable. If status
 *              returned is
 *   @li            CSL_SOK             Valid intc handle is returned
 *   @li            CSL_ESYS_FAIL       The open command failed
 *
 *   @b Modifies
 *   @n    1. The status variable
 *   @n    2. INTC object structure
 *
 *   @b Example:
 *   @verbatim
     CSL_IntcObj     intcObj;
     CSL_IntcHandle  hIntc;
     CSL_Status      openStatus;
  
     hIntc = CSL_intcOpen (&intcObj, CSL_INTC_EventID_I2C0INTR, NULL, NULL);
     if (openStatus != CSL_SOK) {
     // open failed //
     }
    @endverbatim
 * =============================================================================
 */
 
#pragma CODE_SECTION (CSL_intcOpen, ".text:csl_section:intc");

CSL_IntcHandle CSL_intcOpen (
    CSL_IntcObj         *intcObj,
    CSL_IntcEventId     eventId,
    CSL_IntcParams      *params,
    CSL_Status          *status
)
{
    CSL_IntcHandle              handle;
    CSL_Status                  openStatus;
    CSL_IntcGlobalEnableState   gie;

    params = params;
    handle = (CSL_IntcHandle) CSL_INTC_BADHANDLE;

    /* checking the validity of eventId passed */
    if ((eventId >= CSL_INTC_EVENTID_RESET && \
            eventId <= CSL_INTC_EVENTID_DMAXEVTOUT7)) {
        /* checking for reallocation of events */
        if (_CSL_IntcEventAllocMask[eventId] != \
            (CSL_BitMask16) _CSL_INTC_EVENTMASKED) {

            CSL_intcGlobalDisable (&gie);

            /* event in use mask assigned */
            _CSL_IntcEventAllocMask[eventId] =
                (CSL_BitMask16) _CSL_INTC_EVENTMASKED;

            CSL_intcGlobalRestore (gie);
            handle = intcObj;
        }
    }
    if (handle != (CSL_IntcHandle) CSL_INTC_BADHANDLE) {
        intcObj->eventId = eventId;
        openStatus = CSL_SOK;
    }
    else {
        intcObj->eventId = (CSL_IntcEventId) CSL_INTC_EVENTID_INVALID;
        openStatus = CSL_ESYS_FAIL;
    }
    if (status) {
        *status = openStatus;
    }

    return handle;
}
