/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**
 *  @file  csl_intcPlugEventHandler.c
 *
 *  @brief  INTC Functional Layer: CSL_intcPlugEventHandler (..)
 *
 *  Description
 *  - CSL_intcDispatcherInit(..) function definition
 *  
 *  Modification
 *  - Modified on: 15/12/2004
 *  - Reason: creation
 *
 *  @author RMathew 
 */

#include <csl_intc.h>
#include "_csl_intc.h"
#include <soc.h>

/** ============================================================================
 *  @n@b CSL_intcPlugEventHandler
 *
 *  @b Description
 *  @n CSL_intcPlugEventHandler (..) ties an event-handler to an event; so
 *     that the occurence of the event, would result in the event-handler
 *     being invoked.
 *
 *  @b Arguments
 *  @verbatim
        hIntc                Handle identifying the interrupt-event        
        eventHandlerRecord   Provides the details of the event-handler
    @endverbatim
 *
 *  @b Pre Condition 
 *  @n 1. INTC has to be initialized and  opened for the event
 *  @n 2. DispatcherInit has to called
 *  @n 3. EventHandlerRecord has to be filled 
 
 *  @b Post Condition 
 *  @n Handler plugged

 *  @b Modifies 
 *  @n None
 *
 *  <b> Return Value </b>
 *  @n  Returns the address of the previous handler or
 *      CSL_INTC_EVENTHANDLER_PLUG_ERROR if the isr was not properly plugged  
 *
 *  @b Example:
 *  @verbatim
        CSL_IntcEventHandlerRecord  evtHandlerRecord;
  
        evtHandlerRecord.handler = myIsr;
        evtHandlerRecord.arg     = (void *)hI2c;
        CSL_intcPlugEventHandler (hIntc, &evtHandlerRecord);
    @endverbatim
 *
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_intcPlugEventHandler, ".text:csl_section:intc");

CSL_IntcEventHandler CSL_intcPlugEventHandler (
    CSL_IntcHandle              hIntc,
    CSL_IntcEventHandlerRecord  *eventHandlerRecord
)
{
    CSL_IntcEventHandler        prevEventHandler;
    CSL_IntcGlobalEnableState   gie;
	CSL_Status                  status;

    CSL_intcGlobalDisable (&gie);

    /* getting the previous isr that was plugged */
    prevEventHandler = _CSL_intcEventHandlerRecord[hIntc->eventId].handler;

    if (eventHandlerRecord == CSL_INTC_EVTHANDLER_NONE) {
        _CSL_intcEventHandlerRecord[hIntc->eventId].handler =
                                            _CSL_INTC_EVTHANDLER_UNPLUGGED; 
    }
    else {

        /* valid EventHandlerRecord is obtained */
        _CSL_intcEventHandlerRecord[hIntc->eventId].handler =
                                                eventHandlerRecord->handler;
        _CSL_intcEventHandlerRecord[hIntc->eventId].arg =
                                                eventHandlerRecord->arg;

        if ((hIntc->eventId >= 0) && (hIntc->eventId <= 15)) {
            /* Hooks the isr address in the Interrupt Vector Table 
             * fetch packet
             */
            volatile Uint32 delta =
                            (Uint32) _CSL_intcIsr1 - (Uint32) _CSL_intcIsr0;
                            
            status = CSL_intcHookIsr (
                            hIntc->eventId, 
                            (Uint32) _CSL_intcIsr0 + \
                                (Uint32) ((int) hIntc->eventId * (int) delta));

			if(status != CSL_SOK){
				/* filling prevEventHandler with the error notification that
				 * isr is not plugged in properly
				 */
				 prevEventHandler = CSL_INTC_EVENTHANDLER_PLUG_ERROR;
			}
        }
    }

    CSL_intcGlobalRestore (gie);

    return prevEventHandler;
}
