/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_pllcGetHwSetup.c
 *
 *  @path $(CSLPATH)\pllc\src\csl_pllcGetHwSetup.c
 *
 *  @brief File for functional layer of CSL API @a CSL_pllcGetHwSetup()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  22-Nov-2004 Ganeshk File Created.
 * =============================================================================
 */

#include <csl_pllc.h>

/** ============================================================================
 *   @n@b CSL_pllcGetHwSetup
 *
 *   @b Description
 *   @n It retrives the hardware setup parameters of the pllc
 *      specified by the given handle.
 *
 *   @b Arguments
 *   @verbatim
            hPllc        Handle to the pllc
 
            hwSetup      Pointer to the harware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Retrieving the hardware setup
 *                                                parameters is successful
 *   @li                    CSL_ESYS_BADHANDLE  - The handle is passed is
 *                                                invalid
 *   @li                    CSL_ESYS_INVPARAMS  - Invalid parameter
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  The hardware setup structure is populated with the hardware setup
 *       parameters
 *
 *   @b Modifies
 *   @n hwSetup variable
 *
 *   @b Example
 *   @verbatim
            CSL_PllcHandle   hPllc;
            CSL_PllcHwSetup  hwSetup;

            ...
            
            status = CSL_pllcGetHwSetup(hPllc, &hwSetup);
            
            ...
            
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_pllcGetHwSetup, ".text:csl_section:pllc");
CSL_Status CSL_pllcGetHwSetup (
    CSL_PllcHandle hPllc,
    CSL_PllcHwSetup * hwSetup
)
{
    CSL_PllcDivState         divState = CSL_PLLC_PLLDIV_DISABLE;
    Uint16                   divRatio = 0;

    if (hPllc == NULL) {
        return CSL_ESYS_BADHANDLE;
    }
    
    if (hwSetup == NULL) {
        return CSL_ESYS_INVPARAMS;
    }

    hwSetup->pllcMode = (CSL_PllcMode) CSL_FEXT (hPllc->regs->PLLCSR,
        PLLC_PLLCSR_PLLEN);

    hwSetup->pllM = (Uint16) CSL_FEXT (hPllc->regs->PLLM, PLLC_PLLM_PLLM);

    divState = (CSL_PllcDivState) CSL_FEXT (hPllc->regs->PLLDIV0,
        PLLC_PLLDIV0_D0EN);

    divRatio = (Uint16) CSL_FEXT (hPllc->regs->PLLDIV0, PLLC_PLLDIV0_RATIO);

    hwSetup->div0Enable.divEnable = divState;

    hwSetup->div0Enable.pllDivRatio = divRatio;

    divState = (CSL_PllcDivState) CSL_FEXT (hPllc->regs->PLLDIV1,
        PLLC_PLLDIV1_D1EN);

    divRatio = (Uint16) CSL_FEXT (hPllc->regs->PLLDIV1, PLLC_PLLDIV1_RATIO);
    hwSetup->div1Enable.divEnable = divState;

    hwSetup->div1Enable.pllDivRatio = divRatio;

    divState = (CSL_PllcDivState) CSL_FEXT (hPllc->regs->PLLDIV2,
        PLLC_PLLDIV2_D2EN);

    divRatio = (Uint16) CSL_FEXT (hPllc->regs->PLLDIV2, PLLC_PLLDIV2_RATIO);
    hwSetup->div2Enable.divEnable = divState;

    hwSetup->div2Enable.pllDivRatio = divRatio;

    divState = (CSL_PllcDivState) CSL_FEXT (hPllc->regs->PLLDIV3,
        PLLC_PLLDIV3_D3EN);

    divRatio = (Uint16) CSL_FEXT (hPllc->regs->PLLDIV3, PLLC_PLLDIV3_RATIO);
    hwSetup->div3Enable.divEnable = divState;

    hwSetup->div3Enable.pllDivRatio = divRatio;

    return CSL_SOK;
}
