/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_pllcGetHwStatus.c
 *
 *  @path $(CSLPATH)\pllc\v1\src\csl_pllcGetHwStatus.c
 *
 *  @brief File for functional layer of CSL API @a CSL_pllcGetHwStatus()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  23-Nov-2004 GaneshK  File Created.
 * =============================================================================
 */

#include <csl_pllc.h>
#include <csl_pllcAux.h>

/** ============================================================================
 *   @n@b CSL_pllcGetHwStatus
 *
 *   @b Description
 *   @n Gets the status of the different operations of PLLC.
 *
 *   @b Arguments
 *   @verbatim
            hPllc      Handle to the PLLC instance

            query      The query to this API of PLLC which indicates the
                       status to be returned.

            response   Placeholder to return the status.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Status info return successful
 *   @li                    CSL_ESYS_BADHANDLE   - Invalid handle
 *   @li                    CSL_ESYS_INVQUERY    - Invalid query command
 *   @li                    CSL_ESYS_INVPARAMS   - Invalid parameter
 *   @li                    CSL_ESYS_NOTSUPPORTED- Action Not Supported
 *  
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n The argument varibale passed
 *
 *   @b Example
 *   @verbatim
        CSL_PllcHandle          hPllc;
        CSL_PllcHwStatusQuery   query= CSL_PLLC_QUERY_OSC_STATE;    
        CSL_PllcState           response;

        status = CSL_pllcGetHwStatus (hPllc, query, &response);

     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_pllcGetHwStatus, ".text:csl_section:pllc");
CSL_Status CSL_pllcGetHwStatus (
    CSL_PllcHandle hPllc,
    CSL_PllcHwStatusQuery query,
    void *response
)
{
    CSL_Status               status = CSL_SOK;

    if (hPllc == NULL) {
        return CSL_ESYS_BADHANDLE;
    }
    
    if (response == NULL) {
        return CSL_ESYS_INVPARAMS;
    }
    
    switch (query) {
        case CSL_PLLC_QUERY_MODE:
            *(CSL_PllcMode *) response = CSL_pllcGetPllMode (hPllc);
            break;

        case CSL_PLLC_QUERY_STATE:
            *(CSL_PllcState *) response = CSL_pllcGetPllState (hPllc);
            break;

        case CSL_PLLC_QUERY_OSC_STATE:
            *(CSL_PllcState *) response = CSL_pllcGetOscState (hPllc);
            break;

        case CSL_PLLC_QUERY_RESET:
            *(CSL_PllcResetState *) response = CSL_pllcGetResetStatus (hPllc);
            break;

        case CSL_PLLC_QUERY_OSC_STABLE_STATE:
            *(CSL_PllcOscStableState *) response =
                CSL_pllcGetOscStableState (hPllc);
            break;

        case CSL_PLLC_QUERY_GOSTAT:
            *(CSL_PllcGoStatus *) response = CSL_pllcGetGoStatus (hPllc);
            break;

        case CSL_PLLC_QUERY_PLLM_MUL_FACTOR:
            *(Uint16 *) response = CSL_pllcGetPllmMulFactor (hPllc);
            break;

        case CSL_PLLC_QUERY_DIVIDER_STATE:
            {
                CSL_PllcDivCntrl         divCntrl = 
                                    *(CSL_PllcDivCntrl *) response;
                switch (divCntrl.divNum) {
                    case CSL_PLLC_DIV0:
                        *(CSL_PllcDivCntrl *) response 
                            = CSL_pllcGetDiv0Ctrl (hPllc);
                        break;
                    case CSL_PLLC_DIV1:
                        *(CSL_PllcDivCntrl *) response 
                            = CSL_pllcGetDiv1Ctrl (hPllc);
                        break;
                    case CSL_PLLC_DIV2:
                        *(CSL_PllcDivCntrl *) response 
                            = CSL_pllcGetDiv2Ctrl (hPllc);
                        break;
                    case CSL_PLLC_DIV3:
                        *(CSL_PllcDivCntrl *) response 
                            = CSL_pllcGetDiv3Ctrl (hPllc);
                        break;
                    default:
                        status = CSL_ESYS_NOTSUPPORTED;
                        break;
                }
                break;
            }

        case CSL_PLLC_QUERY_CLK_STATE:
            *(CSL_PllcClockStatus *) response = CSL_pllcGetAuxClkStatus (hPllc);
            break;

        case CSL_PLLC_QUERY_SYSCLK_STATE:
            {
                CSL_PllcSysClkStatus     pllSysClkStat =
                    *(CSL_PllcSysClkStatus *) (response);

                switch (pllSysClkStat.sysClk) {
                    case CSL_PLLC_SYSCLK1:
                        *(CSL_PllcSysClkStatus *) response =
                            CSL_pllcGetSysClk1Status (hPllc);
                        break;
                    case CSL_PLLC_SYSCLK2:
                        *(CSL_PllcSysClkStatus *) response =
                            CSL_pllcGetSysClk2Status (hPllc);
                        break;
                    case CSL_PLLC_SYSCLK3:
                        *(CSL_PllcSysClkStatus *) response =
                            CSL_pllcGetSysClk3Status (hPllc);
                        break;
                    default:
                        status = CSL_ESYS_NOTSUPPORTED;
                        break;
                }
            break;
            }

        default:
            status = CSL_ESYS_INVQUERY;
    } /* End of switch (cmd) */
    return status;
}
