/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_pllcHwControl.c
 *
 *  @path $(CSLPATH)\pllc\v1\src\csl_pllcHwControl.c
 *
 *  @brief File for functional layer of CSL API @a CSL_pllcHwControl()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  23-Nov-2004 GaneshK File Created.
 * =============================================================================
 */

#include <csl_pllc.h>
#include <csl_pllcAux.h>

/** ============================================================================
 *   @n@b CSL_pllcHwControl
 *
 *   @b Description
 *   @n Takes a command of PLLC with an optional argument and implements it.
 *
 *   @b Arguments
 *   @verbatim
            hPllc        Handle to the PLLC instance

            cmd             The command to this API indicates the action to be
                            taken on PLLC.

            arg             An optional argument.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li         CSL_SOK               - Status info return successful.
 *   @li         CSL_ESYS_BADHANDLE    - Invalid handle
 *   @li         CSL_ESYS_INVCMD       - Invalid command
 *   @li         CSL_ESYS_INVPARAMS    - Invalid parameter
 *   @li         CSL_ESYS_NOTSUPPORTED - Action Not Supported
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n The hardware registers of PLLC.
 *
 *   @b Example
 *   @verbatim
        CSL_PllcHandle         hPllc;
        CSL_PllcHwControlCmd   cmd=CSL_PLLC_CMD_SET_MODE;
        CSL_PllcMode           arg=CSL_PLLC_PLL_MODE;

        status = CSL_pllcHwControl (hPllc, cmd, &arg);

     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_pllcHwControl, ".text:csl_section:pllc");
CSL_Status CSL_pllcHwControl (
    CSL_PllcHandle hPllc,
    CSL_PllcHwControlCmd cmd,
    void *arg
)
{
    CSL_Status               status = CSL_SOK;

    if (hPllc == NULL) {
        return CSL_ESYS_BADHANDLE;
    }
    
    if (arg == NULL) {
        return CSL_ESYS_INVPARAMS;
    }
    
    switch (cmd) {
        case CSL_PLLC_CMD_SET_MODE:
            CSL_pllcSetMode (hPllc, *(CSL_PllcMode *) arg);
            break;

        case CSL_PLLC_CMD_SET_PLL_STATE:
            {
                CSL_PllcMode             tempVal;
                if (*(CSL_PllcState *) arg == CSL_PLLC_PWRDN) {
                    tempVal = (CSL_PllcMode) CSL_FEXT (hPllc->regs->PLLCSR,
                        PLLC_PLLCSR_PLLEN);
                    if (tempVal == CSL_PLLC_PLL_MODE) {
                        return (CSL_ESYS_NOTSUPPORTED);
                    }
                }
            }
            CSL_pllcSetPllState (hPllc, *(CSL_PllcState *) arg);
            break;

        case CSL_PLLC_CMD_SET_OSC_STATE:
            CSL_pllcSetOscState (hPllc, *(CSL_PllcState *) arg);
            break;

        case CSL_PLLC_CMD_RESET_CONTROL:
            CSL_pllcResetControl (hPllc, *(CSL_PllcResetState *) arg);
            break;

        case CSL_PLLC_CMD_SET_GO_OPN:
            CSL_pllcSetGoOperation (hPllc);
            break;

        case CSL_PLLC_CMD_ALIGN_CONTROL:
            switch (*(CSL_PllcSysClk *) arg) {
                case CSL_PLLC_SYSCLK1:
                    CSL_pllcSetSysClk1AlignControl (hPllc);
                    break;
                case CSL_PLLC_SYSCLK2:
                    CSL_pllcSetSysClk2AlignControl (hPllc);
                    break;
                case CSL_PLLC_SYSCLK3:
                    CSL_pllcSetSysClk3AlignControl (hPllc);
                    break;
            }
            break;

        case CSL_PLLC_CMD_SET_PLLM_MULFACTOR:
            {
                CSL_PllcMode             tempVal;
                tempVal = (CSL_PllcMode) CSL_FEXT (hPllc->regs->PLLCSR,
                    PLLC_PLLCSR_PLLEN);
                if (tempVal == CSL_PLLC_PLL_MODE) {
                    return (CSL_ESYS_NOTSUPPORTED);
                }
                CSL_pllcSetPllmMulFactor (hPllc, *(Uint16 *) arg);
                break;
            }

        case CSL_PLLC_CMD_DIV_CONTROL:
            {
                CSL_PllcDivCntrl        *pllDivCtrl = (CSL_PllcDivCntrl *) arg;
                switch (pllDivCtrl->divNum) {
                    case CSL_PLLC_DIV0:
                        {
                            CSL_PllcMode             check;
                            check = (CSL_PllcMode) CSL_FEXT (
                                hPllc->regs->PLLCSR, PLLC_PLLCSR_PLLEN);
                            if (check == CSL_PLLC_PLL_MODE) {
                                status = CSL_ESYS_NOTSUPPORTED;
                                return (status);
                            }
                            CSL_pllcSetDiv0Enable (hPllc,
                                pllDivCtrl->divControl.divEnable);
                            if (pllDivCtrl->divControl.divEnable ==
                                CSL_PLLC_PLLDIV_ENABLE) {
                                CSL_pllcSetDiv0Ratio (hPllc,
                                    pllDivCtrl->divControl.pllDivRatio);
                            }
                            break;
                        }

                    case CSL_PLLC_DIV1:

                        CSL_pllcSetDiv1Enable (hPllc, 
                            pllDivCtrl->divControl.divEnable);
                        if (pllDivCtrl->divControl.divEnable == 
                            CSL_PLLC_PLLDIV_ENABLE) {
                            CSL_pllcSetDiv1Ratio (hPllc,
                                pllDivCtrl->divControl.pllDivRatio);
                        }
                        break;

                    case CSL_PLLC_DIV2:

                        CSL_pllcSetDiv2Enable (hPllc, 
                            pllDivCtrl->divControl.divEnable);
                        if (pllDivCtrl->divControl.divEnable == 
                            CSL_PLLC_PLLDIV_ENABLE) {
                            CSL_pllcSetDiv2Ratio (hPllc,
                                pllDivCtrl->divControl.pllDivRatio);
                        }
                        break;

                    case CSL_PLLC_DIV3:

                        CSL_pllcSetDiv3Enable (hPllc, 
                            pllDivCtrl->divControl.divEnable);
                        if (pllDivCtrl->divControl.divEnable == 
                            CSL_PLLC_PLLDIV_ENABLE) {
                            CSL_pllcSetDiv3Ratio (hPllc,
                                pllDivCtrl->divControl.pllDivRatio);
                        }
                        break;

                    default:
                        status = CSL_ESYS_NOTSUPPORTED;
                        break;

                }
                break;
            }

        case CSL_PLLC_CMD_AUCXLK_CONTROL:
            CSL_pllcSetAuxClkEnable (hPllc, *(CSL_PllcClkState *) arg);
            break;

        default:
            status = CSL_ESYS_INVCMD;
            break;
    }  /* End of switch (cmd) */
    return status;
}
