/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_pllcHwSetup.c
 *
 *  @path $(CSLPATH)\pllc\v1\src\csl_pllcHwSetup.c
 * 
 *  @brief File for functional layer of CSL API @a CSL_pllcHwSetup()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  22-Nov-2004 GaneshK File Created.
 * =============================================================================
 */

#include <csl_pllc.h>

/** ============================================================================
 *   @n@b CSL_pllcHwSetup
 *
 *   @b Description
 *   @n It configures the pllc registers as per the values passed
 *      in the hardware setup structure.
 *
 *   @b Arguments
 *   @verbatim
            hPllc            Handle to the pllc
 
            hwSetup             Pointer to harware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Hardware setup successful
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVPARAMS  - Hardware structure is not
                                                  properly initialized
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  PLL controller registers are configured according 
 *       to the hardware setup parameters
 *
 *   @b Modifies
 *   @n PLL controller registers
 *
 *   @b Example
 *   @verbatim
            CSL_PllcHandle   hPllc;
            CSL_PllcObj      pllcObj;
            CSL_PllcHwSetup  hwSetup;
            CSL_status          status;

            ...
            
            hPllc = CSL_pllcOpen(&pllcObj, CSL_PLLC, NULL, &status);            
                      
            status = CSL_pllcHwSetup(hPllc, &hwSetup);
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_pllcHwSetup, ".text:csl_section:pllc");
CSL_Status CSL_pllcHwSetup (
    CSL_PllcHandle hPllc,
    CSL_PllcHwSetup * hwSetup
)
{
    CSL_PllcGoStatus         goStat;
    CSL_Status               status = CSL_SOK;
    volatile Uint32          loopCount;

    if (hPllc == NULL) {
        return CSL_ESYS_BADHANDLE;
    }
    
    if (hwSetup == NULL) {
        return CSL_ESYS_INVPARAMS;
    }
    
    /* Set PLLEN to Bypass mode */
    CSL_FINS (hPllc->regs->PLLCSR, PLLC_PLLCSR_PLLEN,
        CSL_PLLC_PLLCSR_PLLEN_BYPASS);

    /* 
     * wait for 4 clock cycles, and ensure PLLEN mux switches to 
     * bypass clock 
     */
    /* DELAY_200MS arbitrary delay for synchronisation */
    loopCount = DELAY_200MS;
    while (loopCount--) {
        asm ("	NOP");
    }
    
    /* Set PLLRST to ASSERTED */
    CSL_FINS (hPllc->regs->PLLCSR, PLLC_PLLCSR_PLLRST,
        CSL_PLLC_PLLCSR_PLLRST_ASSERTED);

    /* If Pll  Mode program PLLDIV0 and PLLM */
    if (hwSetup->pllcMode == CSL_PLLC_PLLCSR_PLLEN_PLL) {
        /* Program Divider D0 PLLDIV0 */
        if (hwSetup->div0Enable.divEnable == CSL_PLLC_PLLDIV0_D0EN_ENABLE) {
            CSL_FINS (hPllc->regs->PLLDIV0, PLLC_PLLDIV0_D0EN,
                CSL_PLLC_PLLDIV0_D0EN_ENABLE);
            CSL_FINS (hPllc->regs->PLLDIV0, PLLC_PLLDIV0_RATIO,
                hwSetup->div0Enable.pllDivRatio);
        }
        

        /* Program PLLM */
        CSL_FINS (hPllc->regs->PLLM, PLLC_PLLM_PLLM, hwSetup->pllM);

        /* arbitrary delay for PLL clock lock */
        loopCount = DELAY_200MS;
        while (loopCount--)
            asm ("	NOP");

    }

    /* Wait if any of go set operation is in progress */
    do {
        goStat = (CSL_PllcGoStatus) CSL_FEXT (hPllc->regs->PLLSTAT,
            PLLC_PLLSTAT_GOSTAT);
    } while (goStat == CSL_PLLC_PLLSTAT_GOSTAT_INPROG);

    /* Program Divider 1 to 3  */
    if (hwSetup->div1Enable.divEnable == CSL_PLLC_PLLDIV1_D1EN_ENABLE) {
        CSL_FINS (hPllc->regs->PLLDIV1, PLLC_PLLDIV1_D1EN,
            CSL_PLLC_PLLDIV1_D1EN_ENABLE);
        CSL_FINS (hPllc->regs->PLLDIV1, PLLC_PLLDIV0_RATIO,
            hwSetup->div1Enable.pllDivRatio);
    }

    if (hwSetup->div2Enable.divEnable == CSL_PLLC_PLLDIV2_D2EN_ENABLE) {
        CSL_FINS (hPllc->regs->PLLDIV2, PLLC_PLLDIV2_D2EN,
            CSL_PLLC_PLLDIV2_D2EN_ENABLE);
        CSL_FINS (hPllc->regs->PLLDIV2, PLLC_PLLDIV2_RATIO,
            hwSetup->div2Enable.pllDivRatio);
    }

    if (hwSetup->div3Enable.divEnable == CSL_PLLC_PLLDIV0_D0EN_ENABLE) {
        CSL_FINS (hPllc->regs->PLLDIV3, PLLC_PLLDIV3_D3EN,
            CSL_PLLC_PLLDIV3_D3EN_ENABLE);
        CSL_FINS (hPllc->regs->PLLDIV3, PLLC_PLLDIV3_RATIO,
            hwSetup->div3Enable.pllDivRatio);
    }

    /* set Align sysclk1 with sysclk */
    CSL_FINS (hPllc->regs->ALNCTL, PLLC_ALNCTL_ALN1,
        CSL_PLLC_ALNCTL_ALN1_ALIGN);

    /* set Align sysclk1 with sysclk */
    CSL_FINS (hPllc->regs->ALNCTL, PLLC_ALNCTL_ALN2,
        CSL_PLLC_ALNCTL_ALN2_ALIGN);

    /* set Align sysclk1 with sysclk */
    CSL_FINS (hPllc->regs->ALNCTL, PLLC_ALNCTL_ALN3,
        CSL_PLLC_ALNCTL_ALN3_ALIGN);

    /* Set the GOSET bit in PLLCMD register */
    CSL_FINS (hPllc->regs->PLLCMD, PLLC_PLLCMD_GOSET,
        CSL_PLLC_PLLCMD_GOSET_SET);

    /* wait till Align */
    do {
        goStat = (CSL_PllcGoStatus) CSL_FEXT (hPllc->regs->PLLSTAT,
            PLLC_PLLSTAT_GOSTAT);
    } while (goStat == CSL_PLLC_PLLSTAT_GOSTAT_INPROG);

    /* arbitrary delay for synchronisation */
    loopCount = DELAY_200MS;
    while (loopCount--)
        asm ("	NOP");

    /* Set PLLRST = 0 */
    /* Set PLLRST to ASSERTED */
    CSL_FINS (hPllc->regs->PLLCSR, PLLC_PLLCSR_PLLRST,
        CSL_PLLC_PLLCSR_PLLRST_RELEASED);

    /* Wait for PLL to lock */
    /* arbitrary delay for synchronisation */
    loopCount = DELAY_200MS;
    while (loopCount--)
        asm ("	NOP");


    if (hwSetup->pllcMode == CSL_PLLC_PLLCSR_PLLEN_PLL) {
        /* Set PLLEN = 1 */
        CSL_FINS (hPllc->regs->PLLCSR, PLLC_PLLCSR_PLLEN,
            CSL_PLLC_PLLCSR_PLLEN_PLL);
    }

    return status;
}
