/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_pllcHwSetupRaw.c
 *
 *  @path $(CSLPATH)\pllc\v1\src\csl_pllcHwSetupRaw.c
 *
 *  @brief File for functional layer of CSL API @a CSL_pllcHwSetupRaw()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  24-Nov-2004 GaneshK  File Created.
 * =============================================================================
 */

#include <csl_pllc.h>
#include <csl_pllcAux.h>

/** ============================================================================
 *   @n@b CSL_pllcHwSetupRaw
 *
 *   @b Description
 *   @n This function initializes the device registers with the register-values
 *      provided through the Config Data structure. This configures registers 
 *      based on a structure of register values, as compared to HwSetup, which 
 *      configures registers based on structure of bit field values and may 
 *      perform other functions (delays, etc.)
 *
 *   @b Arguments
 *   @verbatim
            hPllc        Handle to the PLLC instance

            config          Pointer to config structure
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li            CSL_SOK               - Configuration successful
 *   @li            CSL_ESYS_BADHANDLE    - Invalid handle
 *   @li            CSL_ESYS_INVPARAMS    - Configuration is not
                                            properly initialized
 *   @li            CSL_ESYS_NOTSUPPORTED - Action not supported.
 
 *    <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  The registers of the specified PLLC instance will be setup
 *       according to input configuration structure values.
 *
 *   @b Modifies
 *   @n Hardware registers of the specified PLLC instance.
 *
 *   @b Example
 *   @verbatim
        CSL_PllcHandle       hPllc;
        CSL_PllcConfig       config = CSL_PLLC_CONFIG_DEFAULTS;
        CSL_Status              status;

        status = CSL_pllcHwSetupRaw (hPllc, &config);

     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_pllcHwSetupRaw, ".text:csl_section:pllc");
CSL_Status CSL_pllcHwSetupRaw (
    CSL_PllcHandle hPllc,
    CSL_PllcConfig * config
)
{
    CSL_PllcMode             pllcMode;
    volatile Uint32          loopCount = DELAY_200MS;

    if (hPllc == NULL) {
        return CSL_ESYS_BADHANDLE;
    }
    
    if (config == NULL) {
        return CSL_ESYS_INVPARAMS;
    }
    
    pllcMode = (CSL_PllcMode) CSL_FEXT (hPllc->regs->PLLCSR, PLLC_PLLCSR_PLLEN);

    if (pllcMode == CSL_PLLC_PLLCSR_PLLEN_BYPASS) {

        /* Write to Pllc Control and status Register */
        hPllc->regs->PLLCSR = config->PLLCSR & (~CSL_PLLC_PLLCSR_PLLRST_MASK);

        /* Write to Pllc PLL Multiplier control Register */
        hPllc->regs->PLLM = config->PLLM;

        /* Write to Pllc Divider 0 Register */
        hPllc->regs->PLLDIV0 = config->PLLDIV0;

        /* Write to Pllc Divider 1 Register */
        hPllc->regs->PLLDIV1 = config->PLLDIV1;

        /* Write to Pllc Divider 2 Register */
        hPllc->regs->PLLDIV2 = config->PLLDIV2;

        /* Write to Pllc Divider 3 Register */
        hPllc->regs->PLLDIV3 = config->PLLDIV3;

        hPllc->regs->PLLCMD = config->PLLCMD;

        /* Write to Pllc clock Allign controller Register */
        hPllc->regs->ALNCTL = config->ALNCTL;

        /* Write to Pllc clock enable Register */
        hPllc->regs->CKEN = config->CKEN;


        /* Set the GOSET bit in PLLCMD register */
        CSL_FINS (hPllc->regs->PLLCMD, PLLC_PLLCMD_GOSET,
            CSL_PLLC_PLLCMD_GOSET_SET);

        /* Fixed time delay - waiting for the PLL to re-lock */
        /* arbitrary delay for synchronisation */
        loopCount = DELAY_200MS;
        while (loopCount--)
            asm ("	NOP");

        /* Write to Pllc Control and status Register */
        hPllc->regs->PLLCSR = config->PLLCSR;
        /* wait till PLLRST = 1 */
        /* arbitrary delay for synchronisation */
        loopCount = DELAY_200MS;
        while (loopCount--)
            asm ("	NOP");

        return CSL_SOK;
    }
    return CSL_ESYS_NOTSUPPORTED;
}
