/** ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied priovided
 *  ============================================================================
 */

/** ============================================================================
 *   @file  csl_rtiGetHwSetup.c
 *
 *   @path  $(CSLPATH)\ipmodules\rti\src
 *
 *   @desc  Real time interrupt CSL implementation for getting setup
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  3-Dec-2004 sd File Created.
 *
 * =============================================================================
 */
 
#include <csl_rti.h>

/** ============================================================================
 *   @n@b CSL_rtiGetHwSetup
 *
 *   @b Description
 *   @n It retrives the hardware setup parameters of the real time interrupt 
 *      module specified by the given handle.
 *
 *   @b Arguments
 *   @verbatim
            hRti            Handle to the real time interrupt
 
            hwSetup         Pointer to the harware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK            - Retrieving the hardware setup
 *                                               parameters is successful
 *   @li                    CSL_ESYS_BADHANDLE - The handle is passed is
 *                                               invalid
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  The hardware setup structure is populated with the hardware setup
 *       parameters
 *
 *   @b Modifies
 *   @n hwSetup variable
 *
 *   @b Example
 *   @verbatim
            CSL_RtiHandle   hRti;
            CSL_RtiHwSetup  hwSetup;

            ...
            
            status = CSL_rtiGetHwSetup (hRti, &hwSetup);
            
            ...
            
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_rtiGetHwSetup, ".text:csl_section:rti");

CSL_Status CSL_rtiGetHwSetup (
    CSL_RtiHandle       hRti,
    CSL_RtiHwSetup      *hwSetup
)
{
    if (hRti == NULL)
        return CSL_ESYS_BADHANDLE;

    /* Get the debug mode when device in suspend mode */
    hwSetup->contOnSuspend =
                        (CSL_RtiContOnSuspend) CSL_FEXT (hRti->regs->RTIGCTRL,\
                            RTI_RTIGCTRL_COS);

    /* Get the block1 capture event source */
    hwSetup->blk1ExtnCntl =
                        (CSL_RtiExtnControl) CSL_FEXT (hRti->regs->RTICAPCTRL,\
                            RTI_RTICAPCTRL_CAPCNTR1);

    /* Get the block0 capture event source */
    hwSetup->blk0ExtnCntl =
                        (CSL_RtiExtnControl) CSL_FEXT (hRti->regs->RTICAPCTRL,\
                            RTI_RTICAPCTRL_CAPCNTR0);

    /* Get the compare counter control */
    hwSetup->compare3Cntl =
                        (CSL_RtiCompareCntl) CSL_FEXT (hRti->regs->RTICOMPCTRL,\
                            RTI_RTICOMPCTRL_COMPSEL3);
    hwSetup->compare2Cntl =
                        (CSL_RtiCompareCntl) CSL_FEXT (hRti->regs->RTICOMPCTRL,\
                            RTI_RTICOMPCTRL_COMPSEL2);
    hwSetup->compare1Cntl =
                        (CSL_RtiCompareCntl) CSL_FEXT (hRti->regs->RTICOMPCTRL,\
                            RTI_RTICOMPCTRL_COMPSEL1);
    hwSetup->compare0Cntl =
                        (CSL_RtiCompareCntl) CSL_FEXT (hRti->regs->RTICOMPCTRL,\
                            RTI_RTICOMPCTRL_COMPSEL0);

    /* Get the Counters Values */
    hwSetup->counters.frc0Counter   = (Uint32) hRti->regs->RTIFRC0;
    hwSetup->counters.uc0Counter    = (Uint32) hRti->regs->RTIUC0;
    hwSetup->counters.frc1Counter   = (Uint32) hRti->regs->RTIFRC1;
    hwSetup->counters.uc1Counter    = (Uint32) hRti->regs->RTIUC1;

    /* Get the compare Counters values */
    hwSetup->compareUpCntrs.compareUpCntr0 = (Uint32) hRti->regs->RTICPUC0;
    hwSetup->compareUpCntrs.compareUpCntr1 = (Uint32) hRti->regs->RTICPUC1;

    /* Get the compare register values */
    hwSetup->compVal.comp0Val = (Uint32) hRti->regs->RTICOMP0;
    hwSetup->compVal.comp1Val = (Uint32) hRti->regs->RTICOMP1;
    hwSetup->compVal.comp2Val = (Uint32) hRti->regs->RTICOMP2;
    hwSetup->compVal.comp3Val = (Uint32) hRti->regs->RTICOMP3;

    /* Get the update Compare register values */
    hwSetup->updateCompVal.updateComp0Val = (Uint32) hRti->regs->RTIUDCP0;
    hwSetup->updateCompVal.updateComp1Val = (Uint32) hRti->regs->RTIUDCP1;
    hwSetup->updateCompVal.updateComp2Val = (Uint32) hRti->regs->RTIUDCP2;
    hwSetup->updateCompVal.updateComp3Val = (Uint32) hRti->regs->RTIUDCP3;

    /* Get overflow1 interrupts enable/disable status */
    if (hwSetup->intConfig.ovlIntr1En == TRUE) {
        hwSetup->intConfig.ovlIntr1En = (Bool) CSL_FEXT (hRti->regs->RTISETINT,
            RTI_RTISETINT_SETOVL1INT);
    }
    else {
        hwSetup->intConfig.ovlIntr1En =
            (Bool) CSL_FEXT (hRti->regs->RTICLEARINT,
            RTI_RTICLEARINT_CLEAROVL1INT);
    }

    /* Get overflow0 interrupts enable/disable status */
    if (hwSetup->intConfig.ovlIntr0En == TRUE) {
        hwSetup->intConfig.ovlIntr0En = (Bool) CSL_FEXT (hRti->regs->RTISETINT,
            RTI_RTISETINT_SETOVL0INT);
    }
    else {
        hwSetup->intConfig.ovlIntr1En =
            (Bool) CSL_FEXT (hRti->regs->RTICLEARINT,
            RTI_RTICLEARINT_CLEAROVL0INT);
    }

    /* Get compare3 interrupts enable/disable status */
    if (hwSetup->intConfig.compIntr3En == TRUE) {
        hwSetup->intConfig.compIntr3En = (Bool) CSL_FEXT (hRti->regs->RTISETINT,
            RTI_RTISETINT_SETINT3);
    }
    else {
        hwSetup->intConfig.compIntr3En =
            (Bool) CSL_FEXT (hRti->regs->RTICLEARINT,
            RTI_RTICLEARINT_CLEARINT3);
    }

    /* Get compare2 interrupts enable/disable status */
    if (hwSetup->intConfig.compIntr2En == TRUE) {
        hwSetup->intConfig.compIntr2En = (Bool) CSL_FEXT (hRti->regs->RTISETINT,
            RTI_RTISETINT_SETINT2);
   }
    else {
        hwSetup->intConfig.compIntr2En =
            (Bool) CSL_FEXT (hRti->regs->RTICLEARINT,
            RTI_RTICLEARINT_CLEARINT2);
      }
      
    /* Get compare1 interrupts enable/disable status */
    if (hwSetup->intConfig.compIntr1En == TRUE) {
        hwSetup->intConfig.compIntr1En = (Bool) CSL_FEXT (hRti->regs->RTISETINT,
            RTI_RTISETINT_SETINT1);
    }
    else {
        hwSetup->intConfig.compIntr1En =
            (Bool) CSL_FEXT (hRti->regs->RTICLEARINT,
            RTI_RTICLEARINT_CLEARINT1);
      }
      
    /* Get compare0 interrupts enable/disable status */ 
    if (hwSetup->intConfig.compIntr0En == TRUE){
        hwSetup->intConfig.compIntr0En = (Bool) CSL_FEXT (hRti->regs->RTISETINT,
            RTI_RTISETINT_SETINT0);
    }
    else {
        hwSetup->intConfig.compIntr0En =
            (Bool) CSL_FEXT (hRti->regs->RTICLEARINT,
            RTI_RTICLEARINT_CLEARINT0);
    }
    
    /* Get dma Request3 enable/disable status */
    if (hwSetup->dmaReqEn.dmaReq3En == TRUE) {
        hwSetup->dmaReqEn.dmaReq3En = (Bool) CSL_FEXT (hRti->regs->RTISETINT,
            RTI_RTISETINT_SETDMA3);
    }
    else {
        hwSetup->dmaReqEn.dmaReq3En = (Bool) CSL_FEXT (hRti->regs->RTICLEARINT,
            RTI_RTICLEARINT_CLEARDMA3);
    }

    /* Get dma Request2 enable/disable status */
    if (hwSetup->dmaReqEn.dmaReq2En == TRUE) {
        hwSetup->dmaReqEn.dmaReq2En = (Bool) CSL_FEXT (hRti->regs->RTISETINT,
            RTI_RTISETINT_SETDMA2);
     }
    else
        hwSetup->dmaReqEn.dmaReq2En = (Bool) CSL_FEXT (hRti->regs->RTICLEARINT,
            RTI_RTICLEARINT_CLEARDMA2);

    /* Get dma Request1 enable/disable status */
    if (hwSetup->dmaReqEn.dmaReq1En == TRUE) {
        hwSetup->dmaReqEn.dmaReq1En = (Bool) CSL_FEXT (hRti->regs->RTISETINT,
            RTI_RTISETINT_SETDMA1);
     }
    else {
        hwSetup->dmaReqEn.dmaReq1En = (Bool) CSL_FEXT (hRti->regs->RTICLEARINT,
            RTI_RTICLEARINT_CLEARDMA1);
   }

    /* Get dma Request0 enable/disable status */
    if (hwSetup->dmaReqEn.dmaReq0En == TRUE) {
        hwSetup->dmaReqEn.dmaReq0En = (Bool) CSL_FEXT (hRti->regs->RTISETINT,
            RTI_RTISETINT_SETDMA0);
    }
    else {
        hwSetup->dmaReqEn.dmaReq0En = (Bool) CSL_FEXT (hRti->regs->RTICLEARINT,
            RTI_RTICLEARINT_CLEARDMA0);
    }

    /* Get the preload value of digital watchdog */
    hwSetup->preLoadWatchdog = (Uint16) hRti->regs->RTIDWDPRLD;

    return CSL_SOK;

}
