/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_rtiGetHwStatus.c
 *
 *   @path  $(CSLPATH)\ipmodules\rti\src
 *
 *   @desc  Real Time Interrupt CSL implementation for queries
 *
 */
 
/* =============================================================================
 *  Revision History
 *  ===============
 *  3-Dec-2004 sd File Created.
 *
 * =============================================================================
 */
 
#include <csl_rti.h>
#include <csl_rtiAux.h>

/** ============================================================================
 *   @n@b CSL_rtiGetHwStatus
 *
 *   @b Description
 *   @n This function is used to get the value of various parameters of the
 *      real time interrupt. The value returned depends on the query passed.
 *
 *   @b Arguments
 *   @verbatim
            hRti            Handle to the real time interrupt
 
            query           Query to be performed. 
 
            response        Pointer to buffer to return the data requested by
                            the query passed
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK            - Successful completion of the
 *                                               query
 *
 *   @li                    CSL_ESYS_BADHANDLE - Invalid handle
 *
 *   @li                    CSL_ESYS_INVQUERY  - Query command not supported
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *       Data requested by the query is returned through the variable "response"
 *
 *   @b Modifies
 *   @n  The input arguement "response" is modified
 *
 *   @b Example
 *   @verbatim
            Uint32       count = 0;
            CSL_Status   status;
            
            ...
            
            status = CSL_rtiGetHwStatus (hRti, CSL_RTI_QUERY_CUR_FRC0_CNT,
                                        &count);
            ...
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_rtiGetHwStatus, ".text:csl_section:rti");
CSL_Status CSL_rtiGetHwStatus (
    CSL_RtiHandle           hRti,
    CSL_RtiHwStatusQuery    query,
    void                    *response
)
{
    CSL_Status      status = CSL_SOK;

    if (hRti == NULL)
        return CSL_ESYS_BADHANDLE;

    switch (query) {
            /* Gets the current value of the FRC0 register */
        case CSL_RTI_QUERY_CUR_FRC0_CNT:            
                *((Uint32 *) response) = CSL_rtiGetFrc0Cnt (hRti);
                break;
            
    
            /* Gets the current value of the UC0 register */
        case CSL_RTI_QUERY_CUR_UC0_CNT:         
                *((Uint32 *) response) = CSL_rtiGetUc0Cnt (hRti);
                break;
            
            /* Gets the current value of the FRC1 register */
        case CSL_RTI_QUERY_CUR_FRC1_CNT:            
                *((Uint32 *) response) = CSL_rtiGetFrc1Cnt (hRti);
                break;
            
    
            /* Gets the current value of the UC1 register */
        case CSL_RTI_QUERY_CUR_UC1_CNT:         
                *((Uint32 *) response) = CSL_rtiGetUc1Cnt (hRti);
                break;
            
    
            /* Get the captured value of up counter0 */
        case CSL_RTI_QUERY_UC0_CAPTURE_VAL:         
                *((Uint32 *) response) = CSL_rtiGetUc0CapVal (hRti);
                break;
            
    
            /* Get the captured value of free running counter0 */
        case CSL_RTI_QUERY_FRC0_CAPTURE_VAL:            
                *((Uint32 *) response) = CSL_rtiGetFrc0CapVal (hRti);
                break;
            
    
            /* Get the captured value of up counter1 */
        case CSL_RTI_QUERY_UC1_CAPTURE_VAL:         
                *((Uint32 *) response) = CSL_rtiGetUc1CapVal (hRti);
                break;
            
    
            /* Get the captured value of free running counter1 */
        case CSL_RTI_QUERY_FRC1_CAPTURE_VAL:            
                *((Uint32 *) response) = CSL_rtiGetFrc1CapVal (hRti);
                break;
            
    
            /* Get the value of compare0 register */
        case CSL_RTI_QUERY_COMP0_CNT:           
                *((Uint32 *) response) = CSL_rtiGetComp0Cnt (hRti);
                break;
            
    
            /* Get the value of compare1 register */
        case CSL_RTI_QUERY_COMP1_CNT:           
                *((Uint32 *) response) = CSL_rtiGetComp1Cnt (hRti);
                break;
            
    
            /* Get the value of compare2 register */
        case CSL_RTI_QUERY_COMP2_CNT:           
                *((Uint32 *) response) = CSL_rtiGetComp2Cnt (hRti);
                break;
            
    
            /* Get the value of compare3 register */
        case CSL_RTI_QUERY_COMP3_CNT:           
                *((Uint32 *) response) = CSL_rtiGetComp3Cnt (hRti);
                break;
            
    
            /* Get the status overflow interrupt0 */
        case CSL_RTI_QUERY_OVLINT0_STATUS:          
                *((Bool *) response) = CSL_rtiGetOvlInt0Stat (hRti);
                break;
            
    
            /* Get the status overflow interrupt1 */
        case CSL_RTI_QUERY_OVLINT1_STATUS:          
                *((Bool *) response) = CSL_rtiGetOvlInt1Stat (hRti);
                break;
            
    
            /* Get the status compare interrupt0 */
        case CSL_RTI_QUERY_INT0_STATUS:         
                *((Bool *) response) = CSL_rtiGetInt0Stat (hRti);
                break;
            
    
            /* Get the status compare interrupt1 */
        case CSL_RTI_QUERY_INT1_STATUS:         
                *((Bool *) response) = CSL_rtiGetInt1Stat (hRti);
                break;
            
    
            /* Get the status compare interrupt2 */
        case CSL_RTI_QUERY_INT2_STATUS:         
                *((Bool *) response) = CSL_rtiGetInt2Stat (hRti);
                break;
            
    
            /* Get the status compare interrupt3 */
        case CSL_RTI_QUERY_INT3_STATUS:         
                *((Bool *) response) = CSL_rtiGetInt3Stat (hRti);
                break;
            
    
            /* Get the status of digital watchdog */
        case CSL_RTI_QUERY_WATCHDOG_STATUS:         
                *((Bool *) response) = CSL_rtiGetDwdStatus (hRti);
                break;
            
    
            /* Get the status of digital watchdog down counter */
        case CSL_RTI_QUERY_WATCHDOG_DWNCTR:         
                *((Uint32 *) response) = CSL_rtiGetDwdDwnCtrStatus (hRti);
                break;            
    
        default:
            status = CSL_ESYS_INVQUERY;
            break;
    }

    return status;
}
