/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_rtiHwControl.c
 *
 *   @path  $(CSLPATH)\ipmodules\rti\src
 *
 *   @desc  Real time interrupt CSL implementation for controls
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  3-Dec-2004 sd File Created.
 *
 * =============================================================================
 */
 
#include <csl_rti.h>
#include <csl_rtiAux.h>

/** ============================================================================
 *   @n@b CSL_rtiHwControl
 *
 *   @b Description
 *   @n This function performs various control operations on the real time 
 *      interrupt, based on the command passed.
 *
 *   @b Arguments
 *   @verbatim
            hRti         Handle to the real time interrupt
 
            cmd          Operation to be performed on the real time interrupt
 
            cmdArg       Arguement specific to the command 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK            - Command execution successful.
 *   @li                    CSL_ESYS_BADHANDLE - Invalid handle
 *   @li                    CSL_ESYS_INVCMD    - Invalid command
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  Real time interrupt registers are configured according to the command 
 *       and the command arguements. The command determines which registers 
 *       are modified.
 *
 *   @b Modifies
 *   @n Real time interrupt registers determined by the command
 *
 *   @b Example
 *   @verbatim
            CSL_RtiHandle   hRti;
            Uint32          dwdCounterDis = 0x5312ACED;
            
            ...
            
            status = CSL_rtiHwControl(hRti, CSL_RTI_CMD_DWD_ENABLE, \
                            &dwdCounterDis);
            
            ...
            
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_rtiHwControl, ".text:csl_section:rti");

CSL_Status CSL_rtiHwControl (
    CSL_RtiHandle           hRti,
    CSL_RtiHwControlCmd     cmd,
    void                    *cmdArg
)
{
    CSL_Status      status = CSL_SOK;

    if (hRti == NULL)
        return CSL_ESYS_BADHANDLE;

    switch (cmd) {
            /* Start the Block0 Counters */
        case CSL_RTI_CMD_START_BLOCK0:          
                CSL_rtiBlock0Start (hRti);
                break;
            
    
            /* Stop the Block0 Counters */
        case CSL_RTI_CMD_STOP_BLOCK0:           
                CSL_rtiBlock0Stop (hRti);
                break;
            
    
            /* Start the Block1 Counters */
        case CSL_RTI_CMD_START_BLOCK1:          
                CSL_rtiBlock1Start (hRti);
                break;
            
    
            /* Stop the Block1 Counters */
        case CSL_RTI_CMD_STOP_BLOCK1:           
                CSL_rtiBlock1Stop (hRti);
                break;
            
    
            /* Clear the interrupt0 */
        case CSL_RTI_CMD_CLEAR_INT0:            
                CSL_rtiClearInt0 (hRti);
                break;
            
    
            /* Clear the interrupt1 */
        case CSL_RTI_CMD_CLEAR_INT1:            
                CSL_rtiClearInt1 (hRti);
                break;
            
    
            /* Clear the interrupt2 */
        case CSL_RTI_CMD_CLEAR_INT2:            
                CSL_rtiClearInt2 (hRti);
                break;
            
    
            /* Clear the interrupt3 */
        case CSL_RTI_CMD_CLEAR_INT3:            
                CSL_rtiClearInt3 (hRti);
                break;
            
    
            /* Clear the overflow interrupt0 */
        case CSL_RTI_CMD_CLEAR_OVFINT0:         
                CSL_rtiClearOvfInt0 (hRti);
                break;
            
    
            /* Clear the overflow interrupt1 */
        case CSL_RTI_CMD_CLEAR_OVFINT1:         
                CSL_rtiClearOvfInt1 (hRti);
                break;
            
    
            /* Enable the Digital Watchdog */
        case CSL_RTI_CMD_DWD_ENABLE:            
                CSL_rtiDwdEnable (hRti);
                break;
            
    
            /* Disable the Digital Watchdog */
        case CSL_RTI_CMD_DWD_DISABLE:           
                CSL_rtiDwdDisable (hRti);
                break;
            
            /* Clear the Digital watchdog status */
        case CSL_RTI_CMD_CLEAR_DWD:         
                CSL_rtiClearDwd (hRti);
                break;
            
            /* set digital watchdog key */
        case CSL_RTI_CMD_WDKEY:         
                CSL_rtiWdKey (hRti);
                break;
            
    
        default:
            cmdArg = cmdArg;
            status = CSL_ESYS_INVCMD;
            break;
    }

    return status;
}
