/** ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_rtiHwSetupRaw.c
 *  
 *   @path  $(CSLPATH)\ipmodules\rti\src
 *
 *   @desc  Real Time Interrupt raw setups
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  1-Dec-2004 Sd File Created.
 *
 * =============================================================================
 */

#include <csl_rti.h>

/** ============================================================================
 *   @n@b CSL_rtiHwSetupRaw
 *
 *   @b Description
 *   @n This function initializes the device registers with the register-values
 *      provided through the Config Data structure.  
 *
 *   @b Arguments
 *   @verbatim
            hRti            Handle to the RTI instance
 
            config          Pointer to config structure
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Configuration successful
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVPARAMS  - Configuration is not
 *                                                properly initialized
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  The registers of the specified RTI instance will be setup 
 *       according to value passed
 *
 *   @b Modifies
 *   @n Hardware registers of the specified RTI instance
 *
 *   @b Example
 *   @verbatim
        CSL_RtiHandle       hRti;
        CSL_RtiConfig       config = CSL_RTI_CONFIG_DEFAULTS;
        CSL_Status          status;

        status = CSL_rtiHwSetupRaw (hRti, &config);
            
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_rtiHwSetupRaw, ".text:csl_section:rti");

CSL_Status CSL_rtiHwSetupRaw (
    CSL_RtiHandle       hRti,
    CSL_RtiConfig       *config
)
{
    if (hRti == NULL)
        return CSL_ESYS_BADHANDLE;

    if (config == NULL)
        return CSL_ESYS_INVPARAMS;

    hRti->regs->RTIGCTRL    = config->RTIGCTRL;
    hRti->regs->RTICAPCTRL  = config->RTICAPCTRL;
    hRti->regs->RTICOMPCTRL = config->RTICOMPCTRL;
    hRti->regs->RTIFRC0     = config->RTIFRC0;
    hRti->regs->RTIUC0      = config->RTIUC0;
    hRti->regs->RTICPUC0    = config->RTICPUC0;
    hRti->regs->RTIFRC1     = config->RTIFRC1;
    hRti->regs->RTIUC1      = config->RTIUC1;
    hRti->regs->RTICPUC1    = config->RTICPUC1;
    hRti->regs->RTICOMP0    = config->RTICOMP0;
    hRti->regs->RTIUDCP0    = config->RTIUDCP0;
    hRti->regs->RTICOMP1    = config->RTICOMP1;
    hRti->regs->RTIUDCP1    = config->RTIUDCP1;
    hRti->regs->RTICOMP2    = config->RTICOMP2;
    hRti->regs->RTIUDCP2    = config->RTIUDCP2;
    hRti->regs->RTICOMP3    = config->RTICOMP3;
    hRti->regs->RTIUDCP3    = config->RTIUDCP3;
    hRti->regs->RTISETINT   = config->RTISETINT;
    hRti->regs->RTICLEARINT = config->RTICLEARINT;
    hRti->regs->RTIDWDCTRL  = config->RTIDWDCTRL;
    hRti->regs->RTIDWDPRLD  = config->RTIDWDPRLD;

    return CSL_SOK;
}
