/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_rtiHwSetup.c
 *
 *   @path  $(CSLPATH)\ipmodules\rti\src
 *
 *   @desc  Real Time Interrupt CSL implementation for module setup
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  02-Dec-2004 sd File Created.
 *
 * =============================================================================
 */

#include <csl_rti.h>

/** ============================================================================
 *   @n@b CSL_rtiHwSetup
 *
 *   @b Description
 *   @n It configures the  Real time interrupt registers as per the values 
 *      passed in the hardware setup structure.
 *
 *   @b Arguments
 *   @verbatim
            hRti            Handle to the  Real time interrupt
 
            hwSetup         Pointer to harware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Hardware setup successful
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVPARAMS  - Hardware structure is not
                                                  properly initialized
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n   Real time interrupt registers are configured according to the 
 *        hardware setup parameters
 *
 *   @b Modifies
 *   @n Real time interrupt registers
 *
 *   @b Example
 *   @verbatim
         CSL_RtiHandle              hRti;
         CSL_RtiObj                 rtiObj;
         CSL_status                 status;
         CSL_RtiHwSetup             hwSetup;
        
         ...
        
         hRti = CSL_rtiOpen (&rtiObj, CSL_RTI, NULL, &status);
        
         hwSetup.contOnSuspend                  = CSL_RTI_COUNTERS_RUN;
         hwSetup.blk0ExtnCntl                   = CSL_RTI_CAPTURE_EVENT_SOURCE0;
         hwSetup.blk1ExtnCntl                   = CSL_RTI_CAPTURE_EVENT_SOURCE0;
         hwSetup.compare0Cntl                   = CSL_RTI_FRC0_COMPARE_ENABLE;
         hwSetup.compare1Cntl                   = CSL_RTI_FRC0_COMPARE_ENABLE;
         hwSetup.compare2Cntl                   = CSL_RTI_FRC0_COMPARE_ENABLE;
         hwSetup.compare3Cntl                   = CSL_RTI_FRC0_COMPARE_ENABLE;
         hwSetup.counters.frc0Counter           = FRC0_TEST_VALUE; 
         hwSetup.counters.uc0Counter            = UC0_TEST_VALUE; 
         hwSetup.counters.frc1Counter           = FRC1_TEST_VALUE; 
         hwSetup.counters.uc1Counter            = UC1_TEST_VALUE; 
         hwSetup.compareUpCntrs.compareUpCntr0  = UC0_COMP_VALUE;
         hwSetup.compareUpCntrs.compareUpCntr1  = UC1_COMP_VALUE;
         hwSetup.compVal.comp0Val               = COMPARE0_VALUE;
         hwSetup.compVal.comp1Val               = COMPARE1_VALUE;
         hwSetup.compVal.comp2Val               = COMPARE2_VALUE;
         hwSetup.compVal.comp3Val               = COMPARE3_VALUE;   
         hwSetup.updateCompVal.updateComp0Val   = UPDATE_COMPARE0_VALUE;
         hwSetup.updateCompVal.updateComp1Val   = UPDATE_COMPARE1_VALUE;
         hwSetup.updateCompVal.updateComp2Val   = UPDATE_COMPARE2_VALUE;
         hwSetup.updateCompVal.updateComp3Val   = UPDATE_COMPARE3_VALUE;
         hwSetup.intEnable.compIntr0En          = FALSE; 
         hwSetup.intEnable.compIntr1En          = FALSE;
         hwSetup.intEnable.compIntr2En          = FALSE;
         hwSetup.intEnable.compIntr3En          = FALSE;
         hwSetup.intEnable.ovlInt0En            = FALSE;
         hwSetup.intEnable.ovlInt0En            = FALSE;
         hwSetup.dmaReq.dmareq0En               = FALSE;
         hwSetup.dmaReq.dmareq1En               = FALSE;
         hwSetup.dmaReq.dmareq2En               = FALSE;
         hwSetup.dmaReq.dmareq3En               = FALSE;
         hwSetup.preLoadWatchdog                = 0x1FFF;
 
            status = CSL_rtiHwsetup (hRti, &hwSetup);
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_rtiHwSetup, ".text:csl_section:rti");

CSL_Status CSL_rtiHwSetup (
    CSL_RtiHandle       hRti,
    CSL_RtiHwSetup      *hwSetup
)
{
    Uint32      clearIntFlag;

    if (hRti == NULL)
        return CSL_ESYS_BADHANDLE;

    if (hwSetup == NULL)
        return CSL_ESYS_INVPARAMS;

    /* configure RTI to stop/continue when device in suspend mode  */
    CSL_FINS (hRti->regs->RTIGCTRL, RTI_RTIGCTRL_COS, hwSetup->contOnSuspend);

    /* configure block1 for  capture event source0 and capture event source1 */
    CSL_FINS (hRti->regs->RTICAPCTRL, RTI_RTICAPCTRL_CAPCNTR1, \
                hwSetup->blk1ExtnCntl);

    /* configure block0 for  capture event source0 and capture event source1 */
    CSL_FINS (hRti->regs->RTICAPCTRL, RTI_RTICAPCTRL_CAPCNTR0,
        hwSetup->blk0ExtnCntl);

    /* configure compare counter as FRC0/FRC1 */
    CSL_FINS (hRti->regs->RTICOMPCTRL, RTI_RTICOMPCTRL_COMPSEL3, \
                hwSetup->compare3Cntl);
    CSL_FINS (hRti->regs->RTICOMPCTRL, RTI_RTICOMPCTRL_COMPSEL2, \
                hwSetup->compare2Cntl);
    CSL_FINS (hRti->regs->RTICOMPCTRL, RTI_RTICOMPCTRL_COMPSEL1, \
                hwSetup->compare1Cntl);
    CSL_FINS (hRti->regs->RTICOMPCTRL, RTI_RTICOMPCTRL_COMPSEL0, \
                hwSetup->compare0Cntl);

    /* Configure the Counters values */
    hRti->regs->RTIFRC0 = (Uint32) hwSetup->counters.frc0Counter;
    hRti->regs->RTIUC0  = (Uint32) hwSetup->counters.uc0Counter;
    hRti->regs->RTIFRC1 = (Uint32) hwSetup->counters.frc1Counter;
    hRti->regs->RTIUC1  = (Uint32) hwSetup->counters.uc1Counter;

    /* Configure the Compare upcounters values */
    hRti->regs->RTICPUC0 = (Uint32) hwSetup->compareUpCntrs.compareUpCntr0;
    hRti->regs->RTICPUC1 = (Uint32) hwSetup->compareUpCntrs.compareUpCntr1;

    /* configure compare register values */
    hRti->regs->RTICOMP0 = (Uint32) hwSetup->compVal.comp0Val;
    hRti->regs->RTICOMP1 = (Uint32) hwSetup->compVal.comp1Val;
    hRti->regs->RTICOMP2 = (Uint32) hwSetup->compVal.comp2Val;
    hRti->regs->RTICOMP3 = (Uint32) hwSetup->compVal.comp3Val;

    /* configure update Compare register values */
    hRti->regs->RTIUDCP0 = (Uint32) hwSetup->updateCompVal.updateComp0Val;
    hRti->regs->RTIUDCP1 = (Uint32) hwSetup->updateCompVal.updateComp1Val;
    hRti->regs->RTIUDCP2 = (Uint32) hwSetup->updateCompVal.updateComp2Val;
    hRti->regs->RTIUDCP3 = (Uint32) hwSetup->updateCompVal.updateComp3Val;

    /* clear the interrup flag before enable the interrupts */
    clearIntFlag = (Uint32) hRti->regs->RTIINTFLAG;
    hRti->regs->RTIINTFLAG = clearIntFlag;
    hRti->regs->RTICLEARINT = (Uint32) 0xFFFFFFFF;

    /* Configuration for enable/disable overflow1 interrupt generation */
    if (hwSetup->intConfig.ovlIntr1En == TRUE)
        CSL_FINS (hRti->regs->RTISETINT, RTI_RTISETINT_SETOVL1INT, \
                    hwSetup->intConfig.ovlIntr1En);

    /* Configuration for enable/disable overflow0 interrupt generation */
    if (hwSetup->intConfig.ovlIntr0En == TRUE)
        CSL_FINS (hRti->regs->RTISETINT, RTI_RTISETINT_SETOVL0INT, \
                    hwSetup->intConfig.ovlIntr0En);

    /* Configuration for enable/disable compare3 interrupt generation */
    if (hwSetup->intConfig.compIntr3En == TRUE)
        CSL_FINS (hRti->regs->RTISETINT, RTI_RTISETINT_SETINT3, \
                    hwSetup->intConfig.compIntr3En);

    /* Configuration for enable/disable compare2 interrupt generation */
    if (hwSetup->intConfig.compIntr2En == TRUE)
        CSL_FINS (hRti->regs->RTISETINT, RTI_RTISETINT_SETINT2, \
                    hwSetup->intConfig.compIntr2En);

    /* Configuration for enable/disable compare1 interrupt generation */
    if (hwSetup->intConfig.compIntr1En == TRUE)
        CSL_FINS (hRti->regs->RTISETINT, RTI_RTISETINT_SETINT1, \
                    hwSetup->intConfig.compIntr1En);

    /* Configuration for enable/disable compare0 interrupt generation */
    if (hwSetup->intConfig.compIntr0En == TRUE)
        CSL_FINS (hRti->regs->RTISETINT, RTI_RTISETINT_SETINT0, \
                    hwSetup->intConfig.compIntr0En);

    /* Configuration for enable/disable the dma Request3 */
    if (hwSetup->dmaReqEn.dmaReq3En == TRUE)
        CSL_FINS (hRti->regs->RTISETINT, RTI_RTISETINT_SETDMA3, \
                    hwSetup->dmaReqEn.dmaReq3En);

    /* Configuration for enable/disable the dma Request2 */
    if (hwSetup->dmaReqEn.dmaReq2En == TRUE)
        CSL_FINS (hRti->regs->RTISETINT, RTI_RTISETINT_SETDMA2, \
                    hwSetup->dmaReqEn.dmaReq2En);

    /* Configuration for enable/disable the dma Request1 */
    if (hwSetup->dmaReqEn.dmaReq1En == TRUE)
        CSL_FINS (hRti->regs->RTISETINT, RTI_RTISETINT_SETDMA1, \
                    hwSetup->dmaReqEn.dmaReq1En);

    /* Configuration for enable/disable the dma Request0 */
    if (hwSetup->dmaReqEn.dmaReq0En == TRUE)
        CSL_FINS (hRti->regs->RTISETINT, RTI_RTISETINT_SETDMA0, \
                    hwSetup->dmaReqEn.dmaReq0En);

    /* Configure Preload value for Digital Watchdog */
    hRti->regs->RTIDWDPRLD = (Uint16) hwSetup->preLoadWatchdog;

    return CSL_SOK;

}
