/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_rtiOpen.c
 *
 *   @path  $(CSLPATH)\ipmodules\rti\src
 *
 *   @desc  Real time interrupt CSL implementation for module open
 *
 */
 
/* =============================================================================
 *  Revision History
 *  ===============
 *  1-Dec-2004 Sd File Created.
 *  
 * =============================================================================
 */
 
#include <csl_rti.h>


/** ============================================================================
 *   @n@b CSL_rtiOpen
 *
 *   @b Description
 *   @n This function returns the handle to the Real time interrupt controller
 *      instance. This handle is passed to all other CSL APIs.
 *
 *   @b Arguments
 *   @verbatim
            rtiObj      Pointer to Real time interrupt object.
 
            rtiNum      Instance of Real time interrupt CSL to be opened. 
                        There is only one instance of the Real time 
                        interrupt available. So, the value for this  
                        parameter will be CSL_RTI always.
 
            pRtiParam   Module specific parameters.
 
            status      Status of the function call
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_RtiHandle
 *   @n                     Valid Real time interrupt handle will be returned if
 *                          status value is equal to CSL_SOK.
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n   1.    The status is returned in the status variable. If status
 *              returned is
 *   @li            CSL_SOK         Valid Real time interrupt handle is returned
 *   @li            CSL_ESYS_FAIL   The Real time interrupt instance is invalid
 *
 *        2.    Real time interrupt object structure is populated
 *
 *   @b Modifies
 *   @n    1. The status variable
 *
 *         2. Real time interrupt object structure
 *
 *   @b Example
 *   @verbatim
            CSL_status              status;
            CSL_RtiObj              rtiObj;
            CSL_RtiHandle           hRti;

            ...
                
            hRti = CSL_rtiOpen (&rtiObj, CSL_RTI, NULL, &status);
            
            ...
    @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_rtiOpen, ".text:csl_section:rti");
CSL_RtiHandle CSL_rtiOpen (
    CSL_RtiObj      *pRtiObj,
    CSL_InstNum     rtiNum,
    CSL_RtiParam    *pRtiParam,
    CSL_Status      *pStatus
)
{
    CSL_Status               status;
    CSL_RtiHandle            hRti;
    CSL_RtiBaseAddress       baseAddress;

    status = CSL_rtiGetBaseAddress (rtiNum, pRtiParam, &baseAddress);

    if (status == CSL_SOK) {
        pRtiObj->regs = baseAddress.regs;
        pRtiObj->perNum = (CSL_InstNum) rtiNum;
        hRti = (CSL_RtiHandle) pRtiObj;
    }
    else {
        pRtiObj->regs = (CSL_RtiRegsOvly) NULL;
        pRtiObj->perNum = (CSL_InstNum) - 1;
        hRti = (CSL_RtiHandle) NULL;
    }

    if (pStatus) {
        *pStatus = status;
    }

    return hRti;
}
