 /*  ============================================================================
  *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
  *
  *   Use of this software is controlled by the terms and conditions found
  *   in the license agreement under which this software has been supplied.
  *   ===========================================================================
  */

/** @file  csl_spiGetHwSetup.c
 *
 *  @path $(CSLPATH)\spi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_spiGetHwSetup()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  24-Jan-2005 Ganeshk File Created.
 * =============================================================================
 */

#include <csl_spi.h>
#include <csl_spiAux.h>
#define CSL_SPI_FMT_NO	4
/** ============================================================================
 *   @n@b CSL_spiGetHwSetup
 *
 *   @b Description
 *   @n It retrives the hardware setup parameters of the SPI instance
 *      specified by the given handle.
 *
 *   @b Arguments
 *   @verbatim
            hSpi        Handle to the SPI intance
 
            hwSetup      Pointer to the harware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Retrieving the hardware setup
 *                                                parameters is successful
 *   @li                    CSL_ESYS_BADHANDLE  - The handle is passed is
 *                                                invalid
 *   @li                    CSL_ESYS_INVPARAMS  - Invalid parameter
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  Hardware setup parameters are returned in the hwSetup variable
 *
 *   @b Modifies
 *   @n hwSetup variables
 *
 *   @b Example
 *   @verbatim
            CSL_SpiHandle   hSpi;
            CSL_SpiHwSetup  hwSetup;

            ...
            
            status = CSL_SpiGetHwSetup(hSpi, &hwSetup);
            
            ...
            
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_spiGetHwSetup, ".text:csl_section:spi");
CSL_Status CSL_spiGetHwSetup (
    /* 
     * Pointer to the object that holds reference to the
     * instance of SPI requested after the call 
     */
    CSL_SpiHandle hSpi,
    /* 
     * The query to this API which indicates the status/setup
     * to be returned 
     */
    CSL_SpiHwSetup * hwSetup
)
{

    int                      fmtNo;
    CSL_Status               status = CSL_SOK;
    CSL_SpiHwSetupPins      *pinsPtr;
    CSL_SpiHwSetupCpt       *cptPtr;
    CSL_SpiHwSetupPri       *priPtr;
    CSL_SpiHwSetupPriFmt    **fmt;

    if (hSpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }

    else if ((hwSetup == NULL)         || 
             (hwSetup->cptPtr == NULL) ||
             (hwSetup->genPtr == NULL) || 
             (hwSetup->pinsPtr == NULL)|| 
             (hwSetup->priPtr == NULL)) {
        status = CSL_ESYS_INVPARAMS;
    }

    else{
        /* pinsPtr */
        pinsPtr = hwSetup->pinsPtr;

        if (pinsPtr->func) {
            CSL_spiGetHwSetupGpio (hSpi, CSL_SPI_GPIOTYPE_FUNC,
            (Uint16 *) pinsPtr->func);
        }
        if (pinsPtr->dir) {
            CSL_spiGetHwSetupGpio (hSpi, CSL_SPI_GPIOTYPE_DIR,
            (Uint16 *) pinsPtr->dir);
        }

        /* cptPtr */
        cptPtr = hwSetup->cptPtr;

        if (cptPtr->lvl) {
            CSL_spiGetHwSetupCptInt (hSpi, cptPtr->lvl);
        }
        if (cptPtr->fmtCtrlPtr) {
            CSL_spiGetHwSetupCptFmtCtrl (hSpi, cptPtr->fmtCtrlPtr);
        }

        /* priPtr */
        priPtr = hwSetup->priPtr;
        fmt = priPtr->fmt;

        for (fmtNo = 0; fmtNo < CSL_SPI_FMT_NO; fmtNo++) {
            if (*fmt) {
                CSL_spiGetHwSetupPriFmt (hSpi, fmtNo, *fmt);
            }
            fmt++;
        }

        if (hwSetup->genPtr) {
            CSL_spiGetHwSetupGen (hSpi, hwSetup->genPtr);
        }
    }

    return status;
}
