/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_spiGetHwStatus.c
 *
 *  @path $(CSLPATH)\spi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_spiGetHwStatus()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  24-Jan-2005 GaneshK File Created.	                 
 * =============================================================================
 */

#include <csl_spi.h>
#include <csl_spiAux.h>

/** ============================================================================
 *   @n@b CSL_spiGetHwStatus
 *
 *   @b Description
 *   @n Gets the status of the different settings of SPI instance.
 *
 *   @b Arguments
 *   @verbatim
            hSpi      Handle to the SPI instance

            query      The query to this API of SPI which indicates the
                       status to be returned.

            response   Placeholder to return the status.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Status info return successful
 *   @li                    CSL_ESYS_BADHANDLE   - Invalid handle
 *   @li                    CSL_ESYS_INVQUERY    - Invalid query command
 *   @li                    CSL_ESYS_INVPARAMS   - Invalid parameter
 *   @li                    CSL_ESYS_NOTSUPPORTED- Action Not Supported
 *  
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n None
 *
 *   @b Example
 *   @verbatim
        CSL_SpiHandle          hSpi;
        CSL_SpiHwStatusQuery   query=CSL_SPI_QUERY_INT_VECTOR0;
        CSL_SpiIntVec          reponse;

        status = CSL_spiGetHwStatus (hSpi, query, &response);

     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_spiGetHwStatus, ".text:csl_section:spi")
CSL_Status CSL_spiGetHwStatus (
    /*
     * Pointer to the object that holds reference to the
     * instance of SPI requested after the call 
     */
    CSL_SpiHandle hSpi,
    /*
     * The query to this API which indicates the status/setup
     * to be returned 
     */
    CSL_SpiHwStatusQuery query,
    /* 
     * Placeholder to return the status; @a void* casted 
     */
    void *response
)
{

    CSL_Status               status = CSL_SOK;

    if (hSpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    
    else if (response == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch (query) {
            case CSL_SPI_QUERY_PINS_VALUE:
                CSL_spiPinVal (hSpi, (Uint32 *) response);
                break;

            case CSL_SPI_QUERY_EVT_STATUS:
                CSL_spiEvtStatus(hSpi,(Uint8 *)response);
                break;

            case CSL_SPI_QUERY_INT_VECTOR0:
                CSL_spiIntVector (hSpi,
                    CSL_SPI_QUERY_INT_VECTOR0, (CSL_SpiIntVec *) response);
                break;

            case CSL_SPI_QUERY_INT_VECTOR1:
                CSL_spiIntVector (hSpi,
                    CSL_SPI_QUERY_INT_VECTOR1, (CSL_SpiIntVec *) response);
                break;

            case CSL_SPI_QUERY_INT_ENABLED:
                CSL_spiIntEnabled (hSpi, (Uint32 *) response);
                break;

            case CSL_SPI_QUERY_CPT_DMA_ENABLED:
                CSL_spiCptDmaEnabled (hSpi, (Uint16 *) response);
                break;

            default:
                status = CSL_ESYS_INVQUERY;
        }
    }
    return status;
}
