/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_spiClose.c
 *
 *  @path $(CSLPATH)\spi\src\CSL_spiHwControl.c
 *
 *  @brief File for functional layer of CSL API @a CSL_spiHwContorl.c()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  24-Jan-2005 GaneshK File Created.	                 
 * =============================================================================
 */

#include <csl_spi.h>
#include <csl_spiAux.h>

/** ============================================================================
 *   @n@b CSL_spiHwControl
 *
 *   @b Description
 *   @n Controls the different operations that can be performed by SPI
 *      Takes a command of SPI with an optional argument & implements it.
 *
 *   @b Arguments
 *   @verbatim
            hSpi        Handle to the SPI instance

            cmd         The command to this API indicates the action to be
                        taken on SPI.

            arg         An optional argument.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li         CSL_SOK               - Status info return successful.
 *   @li         CSL_ESYS_BADHANDLE    - Invalid handle
 *   @li         CSL_ESYS_INVCMD       - Invalid command
 *   @li         CSL_ESYS_INVPARAMS    - Invalid parameter
 *   @li         CSL_ESYS_NOTSUPPORTED - Action Not Supported
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  SPI hardware register depending on the command passed
 *
 *   @b Modifies
 *   @n The hardware registers of SPI.
 *
 *   @b Example
 *   @verbatim
        CSL_SpiHandle         hSpi;
        CSL_SpiHwControlCmd   cmd=CSL_SPI_CMD_CPT_DMA_ENABLE;
        void                  arg;

        status = CSL_spiHwControl (hSpi, cmd, &arg);

     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_spiHwControl, ".text:csl_section:spi")

CSL_Status CSL_spiHwControl (
    /*
     * Pointer to the object that holds reference to the
     * instance of SPI requested after the call 
     */
    CSL_SpiHandle hSpi,
    /* 
     * The command to this API which indicates the action to be taken 
     */
    CSL_SpiHwControlCmd cmd,
    /*
     * An optional argument @a void* casted 
     */
    void *arg
)
{
    CSL_Status               status = CSL_SOK;

    if (hSpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }

    else if (cmd == NULL) {
        status = CSL_ESYS_INVCMD;
    }
    else {
        switch (cmd) {
            case CSL_SPI_CMD_PRI_RESET:
                CSL_spiPriResetOut (hSpi);
                break;

            case CSL_SPI_CMD_CPT_DMA_ENABLE:
                CSL_spiCptDma (hSpi, CSL_SPI_CPTDMA_ENABLE);
                break;

            case CSL_SPI_CMD_CPT_DMA_DISABLE:
                CSL_spiCptDma (hSpi, CSL_SPI_CPTDMA_DISABLE);
                break;

            case CSL_SPI_CMD_CPT_WRITE0:
                CSL_spiCptWrite0 (hSpi, *(Uint16 *) arg);
                break;

            case CSL_SPI_CMD_CPT_WRITE1:
                CSL_spiCptWrite1 (hSpi, *(Uint16 *) arg);
                break;

            case CSL_SPI_CMD_CPT_READ:
                CSL_spiCptRead (hSpi,
                    &(((CSL_SpiCptData *) arg)->data),
                    ((CSL_SpiCptData *) arg)->bufStat);
                break;

            case CSL_SPI_CMD_INT_ENABLE:
            case CSL_SPI_CMD_INT_DISABLE:
                CSL_spiInt (hSpi, cmd, *(Uint16 *) arg);
                break;

            case CSL_SPI_CMD_PINS_SET:
            case CSL_SPI_CMD_PINS_CLEAR:
            case CSL_SPI_CMD_PINS_VALUE:
                CSL_spiPins (hSpi, cmd, *(Uint32 *) arg);
                break;

            case CSL_SPI_CMD_XFER_ENABLE:
                CSL_spiXferCtrl (hSpi, CSL_SPI_XFEREN_ENABLE);
                break;

            case CSL_SPI_CMD_XFER_DISABLE:
                CSL_spiXferCtrl (hSpi, CSL_SPI_XFEREN_DISABLE);
                break;

            default:
                status = CSL_ESYS_INVCMD;
        }
    }
    return status;
}
