/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** @file  csl_spiHwSetup.c
 *
 *  @path $(CSLPATH)\spi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_spiHwSetup()
 *
 */
 
/* =============================================================================
 *  Revision History
 *  ===============
 *  25-Jan-2005 GaneshK File Created.	                 
 * =============================================================================
 */

#include <csl_spi.h>
#include <csl_spiAux.h>

#define CSL_SPI_FMT_NO  4

/** ============================================================================
 *   @n@b CSL_spiHwSetup
 *
 *   @b Description
 *   @n It configures the SPI registers as per the values passed
 *      in the hardware setup structure.
 *
 *   @b Arguments
 *   @verbatim
            hSpi            Handle to the Spi instance
 
            setup         Pointer to harware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Hardware setup successful
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVPARAMS  - Hardware structure is not
                                                  properly initialized
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  SPI controller registers are configured according 
 *       to the hardware setup parameters
 *
 *   @b Modifies
 *   @n SPI controller registers
 *
 *   @b Example
 *   @verbatim
            CSL_SpiHandle   hSpi;
            CSL_SpiHwSetup  hwSetup;
            CSL_status      status;

            ...
            
            status = CSL_spiHwSetup(hSpi, &hwSetup);
            
            
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_spiHwSetup, ".text:csl_section:spi")
CSL_Status CSL_spiHwSetup (
    CSL_SpiHandle hSpi,
    CSL_SpiHwSetup * setup
)
{
    Uint32                   fmtNo;
    CSL_Status               status = CSL_SOK;
    CSL_SpiHwSetupPins      *pinsPtr;
    CSL_SpiHwSetupCpt       *cptPtr;
    CSL_SpiHwSetupPri       *priPtr;
    CSL_SpiHwSetupPriFmt    **fmt;
    CSL_SpiHwSetupPriFmt    *check;

    if (hSpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if ((setup == NULL) || 
             (setup->cptPtr == NULL) || 
             (setup->genPtr == NULL) || 
             (setup->pinsPtr == NULL)|| 
             (setup->priPtr == NULL)) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        /* genPtr */
//		printf("Configuring SPI module\n");

        CSL_spiHwSetupGen (hSpi, setup->genPtr);
        
        /* priPtr */
        priPtr = setup->priPtr;
        fmt = priPtr->fmt;
        
        for (fmtNo = 0; fmtNo < CSL_SPI_FMT_NO; fmtNo++) {
            if (*fmt) {
                check = (CSL_SpiHwSetupPriFmt   *)*fmt;
                //The module can not be programmed for nothing below /7
                if(check->preScale < 7){
                    status = CSL_ESYS_INVPARAMS;
                }
                CSL_spiHwSetupPriFmt (hSpi, fmtNo, *fmt);
        
                fmt++;
            }
        }

        /* priPtr */

        pinsPtr = setup->pinsPtr;

        if (pinsPtr->func) {
              CSL_spiHwSetupGpio (hSpi, CSL_SPI_GPIOTYPE_FUNC, (pinsPtr->func));
        }
        if (pinsPtr->dir) {
              CSL_spiHwSetupGpio (hSpi, CSL_SPI_GPIOTYPE_DIR, (pinsPtr->dir));
        }

        /* cptPtr */
        cptPtr = setup->cptPtr;
        if (cptPtr->lvl) {
            CSL_spiHwSetupCptInt (hSpi, *(cptPtr->lvl));
        }

        if (cptPtr->fmtCtrlPtr) {
            CSL_spiHwSetupCptFmtCtrl (hSpi, cptPtr->fmtCtrlPtr);
        }

    }
    return status;
}


