/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_spiHwSetupRaw.c
 *
 *  @path $(CSLPATH)\spi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_spiHwSetupRaw()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  25-Jan-2005 GaneshK  File Created.
 * =============================================================================
 */

#include <csl_spi.h>

/** ============================================================================
 *   @n@b CSL_spiHwSetupRaw
 *
 *   @b Description
 *   @n This function initializes the device registers with the register-values
 *      provided through the Config Data structure. This configures registers 
 *      based on a structure of register values, as compared to HwSetup, which 
 *      configures registers based on structure of bit field values and 
 *      may perform other functions (delays, etc.) 
 *
 *   @b Arguments
 *   @verbatim
            hSpi            Handle to the SPI

            config          Pointer to config structure
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Configuration successful
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVPARAMS  - Configuration is not
 *                                                properly initialized
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  The registers of the specified SPI instance will be setup
 *       according to value passed.
 *
 *   @b Modifies
 *   @n Hardware registers of the specified SPI instance.
 *
 *   @b Example
 *   @verbatim
        CSL_SpiHandle       hSpi;
        CSL_SpiConfig       config = CSL_SPI_CONFIG_DEFAULTS;
        CSL_Status          status;

        status = CSL_spiHwSetupRaw (hSpi, &config);

     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_spiHwSetupRaw, ".text:csl_section:spi");
CSL_Status CSL_spiHwSetupRaw (
    CSL_SpiHandle hSpi,
    CSL_SpiConfig * config
)
{
    CSL_Status status = CSL_SOK;

    if (hSpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (config == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        hSpi->regs->SPIGCR0 = config->SPIGCR0;
        hSpi->regs->SPIGCR1 = config->SPIGCR1;
        hSpi->regs->SPIINT0 = config->SPIINT0;
        hSpi->regs->SPILVL = config->SPILVL;
        hSpi->regs->SPIFLG = config->SPIFLG;
        hSpi->regs->SPIPC0 = config->SPIPC0;
        hSpi->regs->SPIPC1 = config->SPIPC1;
        hSpi->regs->SPIPC2 = config->SPIPC2;
        hSpi->regs->SPIPC3 = config->SPIPC3;
        hSpi->regs->SPIPC4 = config->SPIPC4;
        hSpi->regs->SPIPC5 = config->SPIPC5;
        hSpi->regs->SPIDAT0 = config->SPIDAT0;
        hSpi->regs->SPIDAT1 = config->SPIDAT1;
        hSpi->regs->SPIBUF = config->SPIBUF;
        hSpi->regs->SPIDELAY = config->SPIDELAY;
        hSpi->regs->SPIDEF = config->SPIDEF;
        hSpi->regs->SPIFMT[0] = config->SPIFMT[0];
        hSpi->regs->SPIFMT[1] = config->SPIFMT[1];
        hSpi->regs->SPIFMT[2] = config->SPIFMT[2];
        hSpi->regs->SPIFMT[3] = config->SPIFMT[3];
        hSpi->regs->TGINTVECT[0] = config->TGINTVEC[0];
        hSpi->regs->TGINTVECT[1] = config->TGINTVEC[1];
    }
    return status;
}
