
/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_spiOpen.c
 *
 *  @path $(CSLPATH)\spi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_spiOpen()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  25-Jan-2005 GaneshK author  File Created.
 * =============================================================================
 */

#include <csl_spi.h>

/** ===========================================================================
 *   @func CSL_spiOpen
 *
 *   @desc
 *        This function populates the peripheral data object for the instance
 *        and returns a handle to the instance.
 *        The open call sets up the data structures for the particular instance
 *        of SPI device. Reserves the specified spi for use. The deviced can be
 *        re-opened anytime after it has been normally closed if so required.
 *        The handle returned by this call is input as an essential argument
 *        for rest of the APIs described for this module.
 *        The CSL system as well as SPI must be succesfully initialized  via
 *        CSL_sysInit() and CSL_spiInit() before calling this function. Memory
 *        for the CSL_SpiObj must be allocated outside this call.
 *
 *   @arg pSpiObj
 *        Pointer to the SPI instance object
 *
 *   @arg spiNum
 *        Instance of the SPI to be opened.
 *
 *   @arg pSpiParam
 *        Pointer to module specific parameters
 *
 *   @arg pStatus
 *        pointer for returning status of the function call
 *
 *   @ret CSL_SpiHandle
 *        Valid SPI instance handle will be returned if status value is
 *        equal to CSL_SOK.
 *
 *   @b Example:
 *   @verbatim

       CSL_SpiObj     spiObj;
       CSL_SpiHwSetup spiSetup;
       CSL_Status     status;
       ...
       hSpi = CSL_spiOpen(&spiobj,
                          CSL_SPI_0,
                          NULL,
                          &status);
       @endverbatim
 *
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_spiOpen, ".text:csl_section:spi");

CSL_SpiHandle
CSL_spiOpen (
    CSL_SpiObj * pSpiObj,
    CSL_InstNum spiNum,
    CSL_SpiParam * pSpiParam,
    CSL_Status * pStatus
)
{
    CSL_SpiHandle            hSpi = (CSL_SpiHandle) NULL;
    CSL_SpiBaseAddress       baseAddress;

    if (*pStatus == NULL) {
        hSpi = (CSL_SpiHandle) NULL;
    }
    else if (pSpiObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }
    else {
        *pStatus = CSL_spiGetBaseAddress (spiNum, pSpiParam, &baseAddress);

        if (*pStatus == CSL_SOK) {
            pSpiObj->regs = baseAddress.regs;
            pSpiObj->perNum = (CSL_InstNum) spiNum;
            hSpi = (CSL_SpiHandle) pSpiObj;
        }
        else {
            pSpiObj->regs = (CSL_SpiRegsOvly) NULL;
            pSpiObj->perNum = (CSL_InstNum) - 1;
            hSpi = (CSL_SpiHandle) NULL;
        }
    }
    return (hSpi);
}
