/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_uhpiGetHwSetup.c
 *
 *  @path $(CSLPATH)\uhpi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_uhpiGetHwSetup()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 asr File Created.
 * =============================================================================
 */

#include <csl_uhpi.h>
#include <string.h>

/** ============================================================================
 *   @n@b CSL_uhpiGetHwSetup
 *
 *   @b Description
 *   @n It retrives the hardware setup parameters of the uhpi
 *      specified by the given handle.
 *
 *   @b Arguments
 *   @verbatim
            hUhpi           Handle to the uhpi
 
            hwSetup         Pointer to the harware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Retrieving the hardware setup
 *                                                parameters is successful
 *   @li                    CSL_ESYS_BADHANDLE  - The handle is passed is
 *                                                invalid
 *   @li                    CSL_ESYS_INVPARAMS  - Invalid parameter
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  The hardware setup structure is populated with the hardware setup
 *       parameters
 *
 *   @b Modifies
 *   @n hwSetup variable
 *
 *   @b Example
 *   @verbatim
            CSL_UhpiHandle   hUhpi;
            CSL_UhpiHwSetup  hwSetup;

            ...
            
            status = CSL_uhpiGetHwSetup (hUhpi, &hwSetup);
            
            ...
            
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_uhpiGetHwSetup, ".text:csl_section:uhpi");

CSL_Status CSL_uhpiGetHwSetup (
    CSL_UhpiHandle 		hUhpi,
    CSL_UhpiHwSetup 	*hwSetup
)
{
    CSL_Status	status = CSL_SOK;
    CSL_UhpiRegsOvly	uhpiRegs = hUhpi->regs;

    if (hUhpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (hwSetup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        memset (hwSetup, 0, sizeof (CSL_UhpiHwSetup));
        hwSetup->gpIntCtrl.gpIntEnable =
            (CSL_UhpiGpIntEnable) (uhpiRegs->GPIOINT & 0x7);
        hwSetup->gpIntCtrl.gpIntInvEnable =
            (CSL_UhpiGpIntInvEnable) ((uhpiRegs->GPIOINT & 0x70000) >> 16);
        hwSetup->gpioEnable = (CSL_UhpiGpioEnable) uhpiRegs->GPIOEN;
        hwSetup->gpioDir.gpioDir1 = uhpiRegs->GPIODIR1;
        hwSetup->gpioDir.gpioDir2 = (CSL_UhpiGpioDir2) uhpiRegs->GPIODIR2;
        hwSetup->gpioDir.gpioDir3 = uhpiRegs->GPIODIR3;
        hwSetup->gpioData.gpioData1 = uhpiRegs->GPIODAT1;
        hwSetup->gpioData.gpioData2 = (CSL_UhpiGpioDat2) uhpiRegs->GPIODAT2;
        hwSetup->gpioData.gpioData3 = uhpiRegs->GPIODAT3;
        hwSetup->hpiCtrl = (CSL_UhpiCtrl) uhpiRegs->HPIC;
        hwSetup->hpiAddr.hpiaWrtAddr = uhpiRegs->HPIAW;
        hwSetup->hpiAddr.hpiaReadAddr = uhpiRegs->HPIAR;
    }
    return (status);
}
