/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_uhpiGetHwStatus.c
 *
 *  @path $(CSLPATH)\uhpi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_uhpiGetHwStatus()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 asr asr File Created.
 * =============================================================================
 */

#include <csl_uhpi.h>
#include <csl_uhpiAux.h>

/** ============================================================================
 *   @n@b CSL_uhpiGetHwStatus
 *
 *   @b Description
 *   @n Gets the status of the different operations of UHPI.
 *
 *   @b Arguments
 *   @verbatim
            hUhpi         Handle to the UHPI instance

            query         The query to this API of UHPI which indicates the
                          status to be returned.

            response      Placeholder to return the status.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Status info return successful
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVQUERY   - Invalid query command
 *   @li                    CSL_ESYS_INVPARAMS  - Invalid parameter
 *  
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n None
 *
 *   @b Example
 *   @verbatim
        CSL_UhpiHandle          hUhpi;
        CSL_UhpiHwStatusQuery   query;
        void                    reponse;

        status = CSL_uhpiGetHwStatus (hUhpi, CSL_UHPI_QUERY_HRDY, &response);

     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_uhpiGetHwStatus, ".text:csl_section:uhpi");
CSL_Status CSL_uhpiGetHwStatus (
    CSL_UhpiHandle 			hUhpi,
    CSL_UhpiHwStatusQuery 	query,
    void 					*response
)
{
    CSL_Status	status = CSL_SOK;

    if (hUhpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (response == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch (query) {
            case CSL_UHPI_QUERY_PID_REV:
                    CSL_uhpiGetPidRev (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_PID_CLASS:
                    CSL_uhpiGetPidClass (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_PID_TYPE:
                    CSL_uhpiGetPidType (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_GPINT_EN0:
                    CSL_uhpiGetGpintEn0 (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_GPINT_EN1:
                    CSL_uhpiGetGpintEn1 (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_GPINT_EN2:
                    CSL_uhpiGetGpintEn2 (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_GPIO_DIR1:
                    CSL_uhpiGetGpioDir1 (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_GPIO_DIR2:
                    CSL_uhpiGetGpioDir2 (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_GPIO_DIR3:
                    CSL_uhpiGetGpioDir3 (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_HRDY:
                    CSL_uhpiGetHpicHrdy (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_FETCH:
                    CSL_uhpiGetHpicFetch (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_HPI_RST:
                    CSL_uhpiGetHpicHpiRst (hUhpi, response);
                    break;

            case CSL_UHPI_QUERY_HWOB_STAT:
                    CSL_uhpiGetHpicHwobStat (hUhpi, response);
                    break;

            default:
                status = CSL_ESYS_INVQUERY;
                break;
        }
    }
    return (status);
}

