/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_uhpiHwControl.c
 *
 *  @path $(CSLPATH)\uhpi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_uhpiHwControl()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 asr asr File Created.
 * =============================================================================
 */

#include <csl_uhpi.h>
#include <csl_uhpiAux.h>

/** ============================================================================
 *   @n@b CSL_uhpiHwControl
 *
 *   @b Description
 *   @n Takes a command of UHPI with an optional argument & implements it.
 *
 *   @b Arguments
 *   @verbatim
            hUhpi           Handle to the UHPI instance

            cmd             The command to this API indicates the action to be
                            taken on UHPI.

            arg             An optional argument.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li         CSL_SOK               - Status info return successful.
 *   @li         CSL_ESYS_BADHANDLE    - Invalid handle
 *   @li         CSL_ESYS_INVCMD       - Invalid command
 *   @li         CSL_ESYS_INVPARAMS    - Invalid parameter
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n The hardware registers of UHPI.
 *
 *   @b Example
 *   @verbatim
        CSL_UhpiHandle        hUhpi;
        CSL_UhpiHwControlCmd   cmd;
        void                  arg;

        status = CSL_uhpiHwControl (hUhpi, CSL_UHPI_CMD_SET_HINT, &arg);

     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_uhpiHwControl, ".text:csl_section:uhpi");
CSL_Status CSL_uhpiHwControl (
    CSL_UhpiHandle 			hUhpi,
    CSL_UhpiHwControlCmd 	cmd,
    void 					*arg
)
{
    CSL_Status	status = CSL_SOK;

    if (hUhpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (arg == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch (cmd) {
            /* set the GP Interrupt */
            case CSL_UHPI_CMD_GPINT_SET:
                CSL_uhpiSetGpint (hUhpi, *(Uint32 *) arg);
                break;

            /* set the GP Interrupt Invert */
            case CSL_UHPI_CMD_SET_GPINT_INV:
                CSL_uhpiSetGpintInv (hUhpi, *(Uint32 *) arg);
                break;

            /* set the GPIO Enable */
            case CSL_UHPI_CMD_SET_GPIO_EN:
                CSL_uhpiGpioEnable (hUhpi, *(Uint32 *) arg);
                break;

            /* set the GPIO Direction1 */
            case CSL_UHPI_CMD_SET_GPIO_DIR1:
                CSL_uhpiSetGpioDir1 (hUhpi, *(Uint32 *) arg);
                break;

            /* set the GPIO Direction2 */
            case CSL_UHPI_CMD_SET_GPIO_DIR2:
                CSL_uhpiSetGpioDir2 (hUhpi, *(Uint16 *) arg);
                break;

            /* set the GPIO Direction3 */
            case CSL_UHPI_CMD_SET_GPIO_DIR3:
                CSL_uhpiSetGpioDir3 (hUhpi, *(Uint32 *) arg);
                break;

            /* Set the Host-to-DSP Interrupt */
            case CSL_UHPI_CMD_SET_DSP_INT:
                CSL_uhpiSetDspInt (hUhpi);
                break;

            /* Reset the Host-to-DSP Interrupt */
            case CSL_UHPI_CMD_RESET_DSP_INT:
                CSL_uhpiResetDspInt (hUhpi);
                break;

            /* Set the HPIC Host Interrupt */
            case CSL_UHPI_CMD_SET_HINT:
                CSL_uhpiSetHint (hUhpi);
                break;

            /* Reset the HPIC Host Interrupt */
            case CSL_UHPI_CMD_RESET_HINT:
                CSL_uhpiResetHint (hUhpi);
                break;

            default:
                status = CSL_ESYS_INVCMD;
                break;
        }
    }
    return status;
}

