/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_uhpiHwSetup.c
 *
 *  @path $(CSLPATH)\uhpi\src
 * 
 *  @brief File for functional layer of CSL API @a CSL_uhpiHwSetup()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 asr asr File Created.
 * =============================================================================
 */

#include <csl_uhpi.h>

/** ============================================================================
 *   @n@b CSL_uhpiHwSetup
 *
 *   @b Description
 *   @n It configures the uhpi registers as per the values passed
 *      in the hardware setup structure.
 *
 *   @b Arguments
 *   @verbatim
            hUhpi               Handle to the uhpi
 
            hwSetup             Pointer to harware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Hardware setup successful
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *   @li                    CSL_ESYS_INVPARAMS  - Hardware structure is not
                                                  properly initialized
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  DSP UHPI controller registers are configured according 
 *       to the hardware setup parameters
 *
 *   @b Modifies
 *   @n DSP UHPI controller registers
 *
 *   @b Example
 *   @verbatim
            CSL_status          status;
            CSL_UhpiHwSetup     myHwSetup;            
            CSL_UhpiHandle      hUhpi;

            myHwSetup.gpIntCtrl.gpIntEnable = CSL_UHPI_GPINT_EN0_ENABLE;
            myHwSetup.gpIntCtrl.gpIntInvEnable = CSL_UHPI_GPINT_INV_ENABLE;

            .....
            
            status = CSL_uhpiHwSetup (hUhpi, &hwSetup);
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_uhpiHwSetup, ".text:csl_section:uhpi");

CSL_Status CSL_uhpiHwSetup (
    CSL_UhpiHandle 	hUhpi,
    CSL_UhpiHwSetup	*hwSetup
)
{
    CSL_Status               status = CSL_SOK;
    CSL_UhpiRegsOvly         uhpiRegs = hUhpi->regs;

    if (hUhpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (hwSetup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        /* Configure the GPINT_ENx */
        CSL_FINSR (uhpiRegs->GPIOINT, 2, 0, hwSetup->gpIntCtrl.gpIntEnable);

        /* Configure the GPINT_INVx */
        CSL_FINSR (uhpiRegs->GPIOINT, 18, 16, hwSetup->gpIntCtrl.gpIntInvEnable);

        /* Configure the GPIO Enable register */
        uhpiRegs->GPIOEN = hwSetup->gpioEnable;

        /* Configure the GPIO Direction Register */
        uhpiRegs->GPIODIR1 = hwSetup->gpioDir.gpioDir1;
        uhpiRegs->GPIODIR2 = hwSetup->gpioDir.gpioDir2;
        uhpiRegs->GPIODIR3 = hwSetup->gpioDir.gpioDir3;

        /* Configure the GPIO Data Register */
        uhpiRegs->GPIODAT1 = hwSetup->gpioData.gpioData1;
        uhpiRegs->GPIODAT2 = hwSetup->gpioData.gpioData2;
        uhpiRegs->GPIODAT3 = hwSetup->gpioData.gpioData3;

        /* Configure the Control Register */
        uhpiRegs->HPIC = hwSetup->hpiCtrl;
    }
    return (status);
}
