/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_uhpiHwSetupRaw.c
 *
 *  @path $(CSLPATH)\uhpi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_uhpiHwSetupRaw()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  04-Feb-2005 asr  File Created.
 * =============================================================================
 */

#include <csl_uhpi.h>

/** ============================================================================
 *   @n@b CSL_uhpiHwSetupRaw
 *
 *   @b Description
 *   @n This function initializes the device registers with the register-values
 *      provided through the Config Data structure. This configures registers 
 *		based on a structure of register values, as compared to HwSetup, which 
 *		configures registers based on structure of bit field values and may 
 *		perform other functions (delays, etc.) 
 *
 *   @b Arguments
 *   @verbatim
 *          hUhpi        Handle to the UHPI instance
 *
 *          config       Pointer to config structure
 *   @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li            CSL_SOK               - Configuration successful
 *   @li            CSL_ESYS_BADHANDLE    - Invalid handle
 *   @li            CSL_ESYS_INVPARAMS    - Configuration is not
 *                                          properly initialized
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  The registers of the specified UHPI instance will be setup
 *       according to input configuration structure values.
 *
 *   @b Modifies
 *   @n Hardware registers of the specified UHPI instance.
 *
 *   @b Example
 *   @verbatim
 *      CSL_UhpiHandle       hUhpi;
 *      CSL_UhpiConfig       config = CSL_UHPI_CONFIG_DEFAULTS;
 *      CSL_Status           status;
 *
 *       status = CSL_uhpiHwSetupRaw (hUhpi, &config);
 *
 *    @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_uhpiHwSetupRaw, ".text:csl_section:uhpi");
CSL_Status CSL_uhpiHwSetupRaw (
    CSL_UhpiHandle 	hUhpi,
    CSL_UhpiConfig 	*config
)
{
    CSL_Status	status = CSL_SOK;

    if (hUhpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (config == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        hUhpi->regs->PWREMU_MGMT = config->PWREMU_MGMT;
        hUhpi->regs->GPIOINT = config->GPIOINT;
        hUhpi->regs->GPIOEN = config->GPIOEN;
        hUhpi->regs->GPIODIR1 = config->GPIODIR1;
        hUhpi->regs->GPIODAT1 = config->GPIODAT1;
        hUhpi->regs->GPIODIR2 = config->GPIODIR2;
        hUhpi->regs->GPIODAT2 = config->GPIODAT2;
        hUhpi->regs->GPIODIR3 = config->GPIODIR3;
        hUhpi->regs->GPIODAT3 = config->GPIODAT3;
        hUhpi->regs->HPIC = config->HPIC;   
        hUhpi->regs->HPIAW = config->HPIAW;
        hUhpi->regs->HPIAR = config->HPIAR;
    }
    return (status);
}
