/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_uhpiInit.c
 *
 *  @path $(CSLPATH)\uhpi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_uhpiInit()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  10-Sep-2004 asr  File Created.
 * =============================================================================
 */

#include <csl_uhpi.h>
#include <csl_chip.h>
#include <csl_mcasp.h>

/** ============================================================================
 *   @n@b CSL_uhpiInit
 *
 *   @b Description
 *   @n This is the initialization function for the uhpi CSL. The function 
 *      must be called before calling any other API from this CSL. 
 *      This function reset the SYNC bridge and also configure the HPI HINT as
 *		output which is muxed with McASP. It returns status CSL_SOK.
 *
 *   @b Arguments
 *   @verbatim
 *      pContext    Pointer to module-context. As uhpi doesn't have
 *                  any context based information user is expected to pass NULL.
 *   @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                        CSL_SOK - Always returns
 *
 *   <b> Pre Condition </b>
 *   @n  CSL_sysInit() must be called. 
 *
 *   <b> Post Condition </b>
 *   @n  The CSL for uhpi is initialized 
 *
 *   @b Modifies
 *   @n  None  
 *
 *   @b Example
 *   @verbatim
 *          CSL_uhpiInit (NULL);
 *   @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_uhpiInit, ".text:csl_section:uhpi");

CSL_Status CSL_uhpiInit (
    CSL_UhpiContext 	*pContext
)
{
    Uint32     val;
    pContext = pContext;

    /* Reset Syncbridge */
    val = CSL_FMK (CHIP_CFGBRIDGE_CSPRST, 1);
    CSL_chipWriteReg (CSL_CHIP_REG_CFGBRIDGE, val);
    val = CSL_FMK (CHIP_CFGBRIDGE_CSPRST, 0);
    CSL_chipWriteReg (CSL_CHIP_REG_CFGBRIDGE, val);

    /* 
     *  HINT pin is muxed with McASP2 AMUTE pin, 
     *  configure it as input pin so that it does not cause 
     *  conflict with uhpi HINT output 
     */
    CSL_FINST (CSL_MCASP_2_REGS->PFUNC, MCASP_PFUNC_AMUTE, GPIO);
    CSL_FINST (CSL_MCASP_2_REGS->PDIR, MCASP_PDIR_AMUTE, INPUT);

    return CSL_SOK;
}
