/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_uhpiOpen.c
 *
 *  @path $(CSLPATH)\uhpi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_uhpiOpen()
 *
 */

/* =============================================================================
 *
 *
 *  31-Jan-2005 asr Author File Created.
 * =============================================================================
 */

#include <csl_uhpi.h>

/** ============================================================================
 *   @n@b CSL_uhpiOpen
 *
 *   @b Description
 *   @n This function returns the handle to the UHPI controller
 *      instance. This handle is passed to all other CSL APIs.
 *
 *   @b Arguments
 *   @verbatim
 *          pUhpiObj     Pointer to uhpi object.
 *
 *          uhpiNum     Instance of  DSP UHPI to be opened. 
 *                      There is only one instance of the uhpi available.
 *                      So, the value for this parameter will be 
 *                      CSL_UHPI always.
 *
 *          pUhpiParam  Module specific parameters.
 *
 *          pStatus     Status of the function call
 *    @endverbatim
 *
 *   <b> Return Value </b>  CSL_UhpiHandle
 *   @n                         Valid uhpi handle will be returned if
 *                              status value is equal to CSL_SOK.
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n   1.    The status is returned in the status variable. If status
 *              returned is
 *   @li            CSL_SOK             Valid uhpi handle is returned
 *   @li            CSL_ESYS_FAIL       The uhpi instance is invalid
 *   @li            CSL_ESYS_INVPARAMS  Invalid parameter
 *
 *        2.    UHPI object structure is populated
 *
 *   @b Modifies
 *   @n    1. The status variable
 *
 *         2. UHPI object structure
 *
 *   @b Example
 *   @verbatim
 *          CSL_status          status;
 *          CSL_UhpiObj         uhpiObj;
 *          CSL_UhpiHandle      hUhpi;
 *
 *          ...
 *               
 *          hUhpi = CSL_uhpiOpen (
 * 								&uhpiObj, 
 *								CSL_UHPI, 
 *								NULL, 
 *								&status
 *								);
 *           
 *          ...
 *  @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_uhpiOpen, ".text:csl_section:uhpi");

CSL_UhpiHandle CSL_uhpiOpen (
    CSL_UhpiObj 	*pUhpiObj,
    CSL_InstNum 	uhpiNum,
    CSL_UhpiParam 	*pUhpiParam,
    CSL_Status 		*pStatus
)
{
    CSL_UhpiBaseAddress      baseAddress;
    CSL_UhpiHandle           hUhpi = (CSL_UhpiHandle) NULL;

    if (pStatus == NULL) {
        /* do nothing : module handle is already initialized to NULL */
    }
    else if (pUhpiObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }
    else {
        *pStatus = CSL_uhpiGetBaseAddress (uhpiNum, pUhpiParam, &baseAddress);

        if (*pStatus == CSL_SOK) {
            pUhpiObj->regs = baseAddress.regs;
            pUhpiObj->uhpiNum = (CSL_InstNum) uhpiNum;
            hUhpi = (CSL_UhpiHandle) pUhpiObj;
        }
        else {
            pUhpiObj->regs = (CSL_UhpiRegsOvly) NULL;
            pUhpiObj->uhpiNum = (CSL_InstNum) -1;
        }
    }
    return (hUhpi);
}

